--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET lock_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Name: sqlex; Type: COMMENT; Schema: -; Owner: postgres
--

COMMENT ON DATABASE sqlex IS 'Exercises for SQL ';


--
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


SET search_path = public, pg_catalog;

--
-- Name: box2d; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE box2d;


ALTER TYPE public.box2d OWNER TO postgres;

--
-- Name: box2df; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE box2df;


ALTER TYPE public.box2df OWNER TO postgres;

--
-- Name: box3d; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE box3d;


ALTER TYPE public.box3d OWNER TO postgres;

--
-- Name: geography; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE geography;


ALTER TYPE public.geography OWNER TO postgres;

--
-- Name: geometry; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE geometry;


ALTER TYPE public.geometry OWNER TO postgres;

--
-- Name: gidx; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE gidx;


ALTER TYPE public.gidx OWNER TO postgres;

--
-- Name: histogram; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE histogram AS (
	min double precision,
	max double precision,
	count bigint,
	percent double precision
);


ALTER TYPE public.histogram OWNER TO postgres;

--
-- Name: TYPE histogram; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE histogram IS 'postgis raster type: A composite type used as record output of the ST_Histogram and ST_ApproxHistogram functions.';


--
-- Name: pgis_abs; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE pgis_abs;


ALTER TYPE public.pgis_abs OWNER TO postgres;

--
-- Name: quantile; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE quantile AS (
	quantile double precision,
	value double precision
);


ALTER TYPE public.quantile OWNER TO postgres;

--
-- Name: raster; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE raster;


ALTER TYPE public.raster OWNER TO postgres;

--
-- Name: TYPE raster; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE raster IS 'postgis raster type: raster spatial data type.';


--
-- Name: reclassarg; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE reclassarg AS (
	nband integer,
	reclassexpr text,
	pixeltype text,
	nodataval double precision
);


ALTER TYPE public.reclassarg OWNER TO postgres;

--
-- Name: TYPE reclassarg; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE reclassarg IS 'postgis raster type: A composite type used as input into the ST_Reclass function defining the behavior of reclassification.';


--
-- Name: spheroid; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE spheroid;


ALTER TYPE public.spheroid OWNER TO postgres;

--
-- Name: summarystats; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE summarystats AS (
	count bigint,
	sum double precision,
	mean double precision,
	stddev double precision,
	min double precision,
	max double precision
);


ALTER TYPE public.summarystats OWNER TO postgres;

--
-- Name: TYPE summarystats; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE summarystats IS 'postgis raster type: A composite type used as output of the ST_SummaryStats function.';


--
-- Name: valuecount; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE valuecount AS (
	value double precision,
	count integer,
	percent double precision
);


ALTER TYPE public.valuecount OWNER TO postgres;

--
-- Name: _add_overview_constraint(name, name, name, name, name, name, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_overview_constraint(ovschema name, ovtable name, ovcolumn name, refschema name, reftable name, refcolumn name, factor integer) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
		cn name;
		sql text;
	BEGIN
		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		cn := 'enforce_overview_' || $3;

		sql := 'ALTER TABLE ' || fqtn
			|| ' ADD CONSTRAINT ' || quote_ident(cn)
			|| ' CHECK (_overview_constraint(' || quote_ident($3)
			|| ',' || $7
			|| ',' || quote_literal($4)
			|| ',' || quote_literal($5)
			|| ',' || quote_literal($6)
			|| '))';

		RETURN _add_raster_constraint(cn, sql);
	END;
	$_$;


ALTER FUNCTION public._add_overview_constraint(ovschema name, ovtable name, ovcolumn name, refschema name, reftable name, refcolumn name, factor integer) OWNER TO postgres;

--
-- Name: _add_raster_constraint(name, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_raster_constraint(cn name, sql text) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $$
	BEGIN
		BEGIN
			EXECUTE sql;
		EXCEPTION
			WHEN duplicate_object THEN
				RAISE NOTICE 'The constraint "%" already exists.  To replace the existing constraint, delete the constraint and call ApplyRasterConstraints again', cn;
			WHEN OTHERS THEN
				RAISE NOTICE 'Unable to add constraint "%"', cn;
				RETURN FALSE;
		END;

		RETURN TRUE;
	END;
	$$;


ALTER FUNCTION public._add_raster_constraint(cn name, sql text) OWNER TO postgres;

--
-- Name: _add_raster_constraint_alignment(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_raster_constraint_alignment(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
		cn name;
		sql text;
		attr text;
	BEGIN
		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		cn := 'enforce_same_alignment_' || $3;

		sql := 'SELECT st_makeemptyraster(1, 1, upperleftx, upperlefty, scalex, scaley, skewx, skewy, srid) FROM st_metadata((SELECT '
			|| quote_ident($3)
			|| ' FROM ' || fqtn || ' LIMIT 1))';
		BEGIN
			EXECUTE sql INTO attr;
		EXCEPTION WHEN OTHERS THEN
			RAISE NOTICE 'Unable to get the alignment of a sample raster';
			RETURN FALSE;
		END;

		sql := 'ALTER TABLE ' || fqtn ||
			' ADD CONSTRAINT ' || quote_ident(cn) ||
			' CHECK (st_samealignment(' || quote_ident($3) || ', ''' || attr || '''::raster))';
		RETURN _add_raster_constraint(cn, sql);
	END;
	$_$;


ALTER FUNCTION public._add_raster_constraint_alignment(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _add_raster_constraint_blocksize(name, name, name, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_raster_constraint_blocksize(rastschema name, rasttable name, rastcolumn name, axis text) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
		cn name;
		sql text;
		attr int;
	BEGIN
		IF lower($4) != 'width' AND lower($4) != 'height' THEN
			RAISE EXCEPTION 'axis must be either "width" or "height"';
			RETURN FALSE;
		END IF;

		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		cn := 'enforce_' || $4 || '_' || $3;

		sql := 'SELECT st_' || $4 || '('
			|| quote_ident($3)
			|| ') FROM ' || fqtn
			|| ' LIMIT 1';
		BEGIN
			EXECUTE sql INTO attr;
		EXCEPTION WHEN OTHERS THEN
			RAISE NOTICE 'Unable to get the % of a sample raster', $4;
			RETURN FALSE;
		END;

		sql := 'ALTER TABLE ' || fqtn
			|| ' ADD CONSTRAINT ' || quote_ident(cn)
			|| ' CHECK (st_' || $4 || '('
			|| quote_ident($3)
			|| ') = ' || attr || ')';
		RETURN _add_raster_constraint(cn, sql);
	END;
	$_$;


ALTER FUNCTION public._add_raster_constraint_blocksize(rastschema name, rasttable name, rastcolumn name, axis text) OWNER TO postgres;

--
-- Name: _add_raster_constraint_extent(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_raster_constraint_extent(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
		cn name;
		sql text;
		attr text;
	BEGIN
		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		cn := 'enforce_max_extent_' || $3;

		sql := 'SELECT st_ashexewkb(st_convexhull(st_collect(st_convexhull('
			|| quote_ident($3)
			|| ')))) FROM '
			|| fqtn;
		BEGIN
			EXECUTE sql INTO attr;
		EXCEPTION WHEN OTHERS THEN
			RAISE NOTICE 'Unable to get the extent of a sample raster';
			RETURN FALSE;
		END;

		sql := 'ALTER TABLE ' || fqtn
			|| ' ADD CONSTRAINT ' || quote_ident(cn)
			|| ' CHECK (st_coveredby(st_convexhull('
			|| quote_ident($3)
			|| '), ''' || attr || '''::geometry))';
		RETURN _add_raster_constraint(cn, sql);
	END;
	$_$;


ALTER FUNCTION public._add_raster_constraint_extent(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _add_raster_constraint_nodata_values(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_raster_constraint_nodata_values(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
		cn name;
		sql text;
		attr double precision[];
		max int;
	BEGIN
		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		cn := 'enforce_nodata_values_' || $3;

		sql := 'SELECT _raster_constraint_nodata_values(' || quote_ident($3)
			|| ') FROM ' || fqtn
			|| ' LIMIT 1';
		BEGIN
			EXECUTE sql INTO attr;
		EXCEPTION WHEN OTHERS THEN
			RAISE NOTICE 'Unable to get the nodata values of a sample raster';
			RETURN FALSE;
		END;
		max := array_length(attr, 1);
		IF max < 1 OR max IS NULL THEN
			RAISE NOTICE 'Unable to get the nodata values of a sample raster';
			RETURN FALSE;
		END IF;

		sql := 'ALTER TABLE ' || fqtn
			|| ' ADD CONSTRAINT ' || quote_ident(cn)
			|| ' CHECK (_raster_constraint_nodata_values(' || quote_ident($3)
			|| ')::numeric(16,10)[] = ''{';
		FOR x in 1..max LOOP
			IF attr[x] IS NULL THEN
				sql := sql || 'NULL';
			ELSE
				sql := sql || attr[x];
			END IF;
			IF x < max THEN
				sql := sql || ',';
			END IF;
		END LOOP;
		sql := sql || '}''::numeric(16,10)[])';

		RETURN _add_raster_constraint(cn, sql);
	END;
	$_$;


ALTER FUNCTION public._add_raster_constraint_nodata_values(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _add_raster_constraint_num_bands(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_raster_constraint_num_bands(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
		cn name;
		sql text;
		attr int;
	BEGIN
		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		cn := 'enforce_num_bands_' || $3;

		sql := 'SELECT st_numbands(' || quote_ident($3)
			|| ') FROM ' || fqtn
			|| ' LIMIT 1';
		BEGIN
			EXECUTE sql INTO attr;
		EXCEPTION WHEN OTHERS THEN
			RAISE NOTICE 'Unable to get the number of bands of a sample raster';
			RETURN FALSE;
		END;

		sql := 'ALTER TABLE ' || fqtn
			|| ' ADD CONSTRAINT ' || quote_ident(cn)
			|| ' CHECK (st_numbands(' || quote_ident($3)
			|| ') = ' || attr
			|| ')';
		RETURN _add_raster_constraint(cn, sql);
	END;
	$_$;


ALTER FUNCTION public._add_raster_constraint_num_bands(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _add_raster_constraint_out_db(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_raster_constraint_out_db(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
		cn name;
		sql text;
		attr boolean[];
		max int;
	BEGIN
		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		cn := 'enforce_out_db_' || $3;

		sql := 'SELECT _raster_constraint_out_db(' || quote_ident($3)
			|| ') FROM ' || fqtn
			|| ' LIMIT 1';
		BEGIN
			EXECUTE sql INTO attr;
		EXCEPTION WHEN OTHERS THEN
			RAISE NOTICE 'Unable to get the out-of-database bands of a sample raster';
			RETURN FALSE;
		END;
		max := array_length(attr, 1);
		IF max < 1 OR max IS NULL THEN
			RAISE NOTICE 'Unable to get the out-of-database bands of a sample raster';
			RETURN FALSE;
		END IF;

		sql := 'ALTER TABLE ' || fqtn
			|| ' ADD CONSTRAINT ' || quote_ident(cn)
			|| ' CHECK (_raster_constraint_out_db(' || quote_ident($3)
			|| ') = ''{';
		FOR x in 1..max LOOP
			IF attr[x] IS FALSE THEN
				sql := sql || 'FALSE';
			ELSE
				sql := sql || 'TRUE';
			END IF;
			IF x < max THEN
				sql := sql || ',';
			END IF;
		END LOOP;
		sql := sql || '}''::boolean[])';

		RETURN _add_raster_constraint(cn, sql);
	END;
	$_$;


ALTER FUNCTION public._add_raster_constraint_out_db(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _add_raster_constraint_pixel_types(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_raster_constraint_pixel_types(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
		cn name;
		sql text;
		attr text[];
		max int;
	BEGIN
		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		cn := 'enforce_pixel_types_' || $3;

		sql := 'SELECT _raster_constraint_pixel_types(' || quote_ident($3)
			|| ') FROM ' || fqtn
			|| ' LIMIT 1';
		BEGIN
			EXECUTE sql INTO attr;
		EXCEPTION WHEN OTHERS THEN
			RAISE NOTICE 'Unable to get the pixel types of a sample raster';
			RETURN FALSE;
		END;
		max := array_length(attr, 1);
		IF max < 1 OR max IS NULL THEN
			RAISE NOTICE 'Unable to get the pixel types of a sample raster';
			RETURN FALSE;
		END IF;

		sql := 'ALTER TABLE ' || fqtn
			|| ' ADD CONSTRAINT ' || quote_ident(cn)
			|| ' CHECK (_raster_constraint_pixel_types(' || quote_ident($3)
			|| ') = ''{';
		FOR x in 1..max LOOP
			sql := sql || '"' || attr[x] || '"';
			IF x < max THEN
				sql := sql || ',';
			END IF;
		END LOOP;
		sql := sql || '}''::text[])';

		RETURN _add_raster_constraint(cn, sql);
	END;
	$_$;


ALTER FUNCTION public._add_raster_constraint_pixel_types(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _add_raster_constraint_regular_blocking(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_raster_constraint_regular_blocking(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
		cn name;
		sql text;
	BEGIN

		RAISE INFO 'The regular_blocking constraint is just a flag indicating that the column "%" is regularly blocked.  It is up to the end-user to ensure that the column is truely regularly blocked.', quote_ident($3);

		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		cn := 'enforce_regular_blocking_' || $3;

		sql := 'ALTER TABLE ' || fqtn
			|| ' ADD CONSTRAINT ' || quote_ident(cn)
			|| ' CHECK (TRUE)';
		RETURN _add_raster_constraint(cn, sql);
	END;
	$_$;


ALTER FUNCTION public._add_raster_constraint_regular_blocking(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _add_raster_constraint_scale(name, name, name, character); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_raster_constraint_scale(rastschema name, rasttable name, rastcolumn name, axis character) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
		cn name;
		sql text;
		attr double precision;
	BEGIN
		IF lower($4) != 'x' AND lower($4) != 'y' THEN
			RAISE EXCEPTION 'axis must be either "x" or "y"';
			RETURN FALSE;
		END IF;

		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		cn := 'enforce_scale' || $4 || '_' || $3;

		sql := 'SELECT st_scale' || $4 || '('
			|| quote_ident($3)
			|| ') FROM '
			|| fqtn
			|| ' LIMIT 1';
		BEGIN
			EXECUTE sql INTO attr;
		EXCEPTION WHEN OTHERS THEN
			RAISE NOTICE 'Unable to get the %-scale of a sample raster', upper($4);
			RETURN FALSE;
		END;

		sql := 'ALTER TABLE ' || fqtn
			|| ' ADD CONSTRAINT ' || quote_ident(cn)
			|| ' CHECK (st_scale' || $4 || '('
			|| quote_ident($3)
			|| ')::numeric(16,10) = (' || attr || ')::numeric(16,10))';
		RETURN _add_raster_constraint(cn, sql);
	END;
	$_$;


ALTER FUNCTION public._add_raster_constraint_scale(rastschema name, rasttable name, rastcolumn name, axis character) OWNER TO postgres;

--
-- Name: _add_raster_constraint_srid(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _add_raster_constraint_srid(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
		cn name;
		sql text;
		attr int;
	BEGIN
		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		cn := 'enforce_srid_' || $3;

		sql := 'SELECT st_srid('
			|| quote_ident($3)
			|| ') FROM ' || fqtn
			|| ' LIMIT 1';
		BEGIN
			EXECUTE sql INTO attr;
		EXCEPTION WHEN OTHERS THEN
			RAISE NOTICE 'Unable to get the SRID of a sample raster';
			RETURN FALSE;
		END;

		sql := 'ALTER TABLE ' || fqtn
			|| ' ADD CONSTRAINT ' || quote_ident(cn)
			|| ' CHECK (st_srid('
			|| quote_ident($3)
			|| ') = ' || attr || ')';

		RETURN _add_raster_constraint(cn, sql);
	END;
	$_$;


ALTER FUNCTION public._add_raster_constraint_srid(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _drop_overview_constraint(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_overview_constraint(ovschema name, ovtable name, ovcolumn name) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT _drop_raster_constraint($1, $2, 'enforce_overview_' || $3) $_$;


ALTER FUNCTION public._drop_overview_constraint(ovschema name, ovtable name, ovcolumn name) OWNER TO postgres;

--
-- Name: _drop_raster_constraint(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_raster_constraint(rastschema name, rasttable name, cn name) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		fqtn text;
	BEGIN
		fqtn := '';
		IF length($1) > 0 THEN
			fqtn := quote_ident($1) || '.';
		END IF;
		fqtn := fqtn || quote_ident($2);

		BEGIN
			EXECUTE 'ALTER TABLE '
				|| fqtn
				|| ' DROP CONSTRAINT '
				|| quote_ident(cn);
			RETURN TRUE;
		EXCEPTION
			WHEN undefined_object THEN
				RAISE NOTICE 'The constraint "%" does not exist.  Skipping', cn;
			WHEN OTHERS THEN
				RAISE NOTICE 'Unable to drop constraint "%"', cn;
				RETURN FALSE;
		END;

		RETURN TRUE;
	END;
	$_$;


ALTER FUNCTION public._drop_raster_constraint(rastschema name, rasttable name, cn name) OWNER TO postgres;

--
-- Name: _drop_raster_constraint_alignment(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_raster_constraint_alignment(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT _drop_raster_constraint($1, $2, 'enforce_same_alignment_' || $3) $_$;


ALTER FUNCTION public._drop_raster_constraint_alignment(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _drop_raster_constraint_blocksize(name, name, name, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_raster_constraint_blocksize(rastschema name, rasttable name, rastcolumn name, axis text) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	BEGIN
		IF lower($4) != 'width' AND lower($4) != 'height' THEN
			RAISE EXCEPTION 'axis must be either "width" or "height"';
			RETURN FALSE;
		END IF;

		RETURN _drop_raster_constraint($1, $2, 'enforce_' || $4 || '_' || $3);
	END;
	$_$;


ALTER FUNCTION public._drop_raster_constraint_blocksize(rastschema name, rasttable name, rastcolumn name, axis text) OWNER TO postgres;

--
-- Name: _drop_raster_constraint_extent(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_raster_constraint_extent(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT _drop_raster_constraint($1, $2, 'enforce_max_extent_' || $3) $_$;


ALTER FUNCTION public._drop_raster_constraint_extent(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _drop_raster_constraint_nodata_values(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_raster_constraint_nodata_values(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT _drop_raster_constraint($1, $2, 'enforce_nodata_values_' || $3) $_$;


ALTER FUNCTION public._drop_raster_constraint_nodata_values(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _drop_raster_constraint_num_bands(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_raster_constraint_num_bands(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT _drop_raster_constraint($1, $2, 'enforce_num_bands_' || $3) $_$;


ALTER FUNCTION public._drop_raster_constraint_num_bands(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _drop_raster_constraint_out_db(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_raster_constraint_out_db(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT _drop_raster_constraint($1, $2, 'enforce_out_db_' || $3) $_$;


ALTER FUNCTION public._drop_raster_constraint_out_db(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _drop_raster_constraint_pixel_types(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_raster_constraint_pixel_types(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT _drop_raster_constraint($1, $2, 'enforce_pixel_types_' || $3) $_$;


ALTER FUNCTION public._drop_raster_constraint_pixel_types(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _drop_raster_constraint_regular_blocking(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_raster_constraint_regular_blocking(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT _drop_raster_constraint($1, $2, 'enforce_regular_blocking_' || $3) $_$;


ALTER FUNCTION public._drop_raster_constraint_regular_blocking(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _drop_raster_constraint_scale(name, name, name, character); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_raster_constraint_scale(rastschema name, rasttable name, rastcolumn name, axis character) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	BEGIN
		IF lower($4) != 'x' AND lower($4) != 'y' THEN
			RAISE EXCEPTION 'axis must be either "x" or "y"';
			RETURN FALSE;
		END IF;

		RETURN _drop_raster_constraint($1, $2, 'enforce_scale' || $4 || '_' || $3);
	END;
	$_$;


ALTER FUNCTION public._drop_raster_constraint_scale(rastschema name, rasttable name, rastcolumn name, axis character) OWNER TO postgres;

--
-- Name: _drop_raster_constraint_srid(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _drop_raster_constraint_srid(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT _drop_raster_constraint($1, $2, 'enforce_srid_' || $3) $_$;


ALTER FUNCTION public._drop_raster_constraint_srid(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _overview_constraint_info(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _overview_constraint_info(ovschema name, ovtable name, ovcolumn name, OUT refschema name, OUT reftable name, OUT refcolumn name, OUT factor integer) RETURNS record
    LANGUAGE sql STABLE STRICT
    AS $_$
	SELECT
		split_part(split_part(s.consrc, '''::name', 1), '''', 2)::name,
		split_part(split_part(s.consrc, '''::name', 2), '''', 2)::name,
		split_part(split_part(s.consrc, '''::name', 3), '''', 2)::name,
		trim(both from split_part(s.consrc, ',', 2))::integer
	FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
	WHERE n.nspname = $1
		AND c.relname = $2
		AND a.attname = $3
		AND a.attrelid = c.oid
		AND s.connamespace = n.oid
		AND s.conrelid = c.oid
		AND a.attnum = ANY (s.conkey)
		AND s.consrc LIKE '%_overview_constraint(%'
	$_$;


ALTER FUNCTION public._overview_constraint_info(ovschema name, ovtable name, ovcolumn name, OUT refschema name, OUT reftable name, OUT refcolumn name, OUT factor integer) OWNER TO postgres;

--
-- Name: _raster_constraint_info_alignment(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _raster_constraint_info_alignment(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE sql STABLE STRICT
    AS $_$
	SELECT
		TRUE
	FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
	WHERE n.nspname = $1
		AND c.relname = $2
		AND a.attname = $3
		AND a.attrelid = c.oid
		AND s.connamespace = n.oid
		AND s.conrelid = c.oid
		AND a.attnum = ANY (s.conkey)
		AND s.consrc LIKE '%st_samealignment(%';
	$_$;


ALTER FUNCTION public._raster_constraint_info_alignment(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _raster_constraint_info_blocksize(name, name, name, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _raster_constraint_info_blocksize(rastschema name, rasttable name, rastcolumn name, axis text) RETURNS integer
    LANGUAGE sql STABLE STRICT
    AS $_$
	SELECT
		replace(replace(split_part(s.consrc, ' = ', 2), ')', ''), '(', '')::integer
	FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
	WHERE n.nspname = $1
		AND c.relname = $2
		AND a.attname = $3
		AND a.attrelid = c.oid
		AND s.connamespace = n.oid
		AND s.conrelid = c.oid
		AND a.attnum = ANY (s.conkey)
		AND s.consrc LIKE '%st_' || $4 || '(% = %';
	$_$;


ALTER FUNCTION public._raster_constraint_info_blocksize(rastschema name, rasttable name, rastcolumn name, axis text) OWNER TO postgres;

--
-- Name: _raster_constraint_info_nodata_values(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _raster_constraint_info_nodata_values(rastschema name, rasttable name, rastcolumn name) RETURNS double precision[]
    LANGUAGE sql STABLE STRICT
    AS $_$
	SELECT
		trim(both '''' from split_part(replace(replace(split_part(s.consrc, ' = ', 2), ')', ''), '(', ''), '::', 1))::double precision[]
	FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
	WHERE n.nspname = $1
		AND c.relname = $2
		AND a.attname = $3
		AND a.attrelid = c.oid
		AND s.connamespace = n.oid
		AND s.conrelid = c.oid
		AND a.attnum = ANY (s.conkey)
		AND s.consrc LIKE '%_raster_constraint_nodata_values(%';
	$_$;


ALTER FUNCTION public._raster_constraint_info_nodata_values(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _raster_constraint_info_num_bands(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _raster_constraint_info_num_bands(rastschema name, rasttable name, rastcolumn name) RETURNS integer
    LANGUAGE sql STABLE STRICT
    AS $_$
	SELECT
		replace(replace(split_part(s.consrc, ' = ', 2), ')', ''), '(', '')::integer
	FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
	WHERE n.nspname = $1
		AND c.relname = $2
		AND a.attname = $3
		AND a.attrelid = c.oid
		AND s.connamespace = n.oid
		AND s.conrelid = c.oid
		AND a.attnum = ANY (s.conkey)
		AND s.consrc LIKE '%st_numbands(%';
	$_$;


ALTER FUNCTION public._raster_constraint_info_num_bands(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _raster_constraint_info_out_db(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _raster_constraint_info_out_db(rastschema name, rasttable name, rastcolumn name) RETURNS boolean[]
    LANGUAGE sql STABLE STRICT
    AS $_$
	SELECT
		trim(both '''' from split_part(replace(replace(split_part(s.consrc, ' = ', 2), ')', ''), '(', ''), '::', 1))::boolean[]
	FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
	WHERE n.nspname = $1
		AND c.relname = $2
		AND a.attname = $3
		AND a.attrelid = c.oid
		AND s.connamespace = n.oid
		AND s.conrelid = c.oid
		AND a.attnum = ANY (s.conkey)
		AND s.consrc LIKE '%_raster_constraint_out_db(%';
	$_$;


ALTER FUNCTION public._raster_constraint_info_out_db(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _raster_constraint_info_pixel_types(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _raster_constraint_info_pixel_types(rastschema name, rasttable name, rastcolumn name) RETURNS text[]
    LANGUAGE sql STABLE STRICT
    AS $_$
	SELECT
		trim(both '''' from split_part(replace(replace(split_part(s.consrc, ' = ', 2), ')', ''), '(', ''), '::', 1))::text[]
	FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
	WHERE n.nspname = $1
		AND c.relname = $2
		AND a.attname = $3
		AND a.attrelid = c.oid
		AND s.connamespace = n.oid
		AND s.conrelid = c.oid
		AND a.attnum = ANY (s.conkey)
		AND s.consrc LIKE '%_raster_constraint_pixel_types(%';
	$_$;


ALTER FUNCTION public._raster_constraint_info_pixel_types(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _raster_constraint_info_regular_blocking(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _raster_constraint_info_regular_blocking(rastschema name, rasttable name, rastcolumn name) RETURNS boolean
    LANGUAGE plpgsql STABLE STRICT
    AS $_$
	DECLARE
		cn text;
		sql text;
		rtn boolean;
	BEGIN
		cn := 'enforce_regular_blocking_' || $3;

		sql := 'SELECT TRUE FROM pg_class c, pg_namespace n, pg_constraint s'
			|| ' WHERE n.nspname = ' || quote_literal($1)
			|| ' AND c.relname = ' || quote_literal($2)
			|| ' AND s.connamespace = n.oid AND s.conrelid = c.oid'
			|| ' AND s.conname = ' || quote_literal(cn);
		EXECUTE sql INTO rtn;
		RETURN rtn;
	END;
	$_$;


ALTER FUNCTION public._raster_constraint_info_regular_blocking(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _raster_constraint_info_scale(name, name, name, character); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _raster_constraint_info_scale(rastschema name, rasttable name, rastcolumn name, axis character) RETURNS double precision
    LANGUAGE sql STABLE STRICT
    AS $_$
	SELECT
		replace(replace(split_part(split_part(s.consrc, ' = ', 2), '::', 1), ')', ''), '(', '')::double precision
	FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
	WHERE n.nspname = $1
		AND c.relname = $2
		AND a.attname = $3
		AND a.attrelid = c.oid
		AND s.connamespace = n.oid
		AND s.conrelid = c.oid
		AND a.attnum = ANY (s.conkey)
		AND s.consrc LIKE '%st_scale' || $4 || '(% = %';
	$_$;


ALTER FUNCTION public._raster_constraint_info_scale(rastschema name, rasttable name, rastcolumn name, axis character) OWNER TO postgres;

--
-- Name: _raster_constraint_info_srid(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _raster_constraint_info_srid(rastschema name, rasttable name, rastcolumn name) RETURNS integer
    LANGUAGE sql STABLE STRICT
    AS $_$
	SELECT
		replace(replace(split_part(s.consrc, ' = ', 2), ')', ''), '(', '')::integer
	FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
	WHERE n.nspname = $1
		AND c.relname = $2
		AND a.attname = $3
		AND a.attrelid = c.oid
		AND s.connamespace = n.oid
		AND s.conrelid = c.oid
		AND a.attnum = ANY (s.conkey)
		AND s.consrc LIKE '%st_srid(% = %';
	$_$;


ALTER FUNCTION public._raster_constraint_info_srid(rastschema name, rasttable name, rastcolumn name) OWNER TO postgres;

--
-- Name: _st_aspect4ma(double precision[], text, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _st_aspect4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) RETURNS double precision
    LANGUAGE plpgsql IMMUTABLE
    AS $$
    DECLARE
        pwidth float;
        pheight float;
        dz_dx float;
        dz_dy float;
        aspect float;
    BEGIN
        pwidth := args[1]::float;
        pheight := args[2]::float;
        dz_dx := ((matrix[3][1] + 2.0 * matrix[3][2] + matrix[3][3]) - (matrix[1][1] + 2.0 * matrix[1][2] + matrix[1][3])) / (8.0 * pwidth);
        dz_dy := ((matrix[1][3] + 2.0 * matrix[2][3] + matrix[3][3]) - (matrix[1][1] + 2.0 * matrix[2][1] + matrix[3][1])) / (8.0 * pheight);
        IF abs(dz_dx) = 0::float AND abs(dz_dy) = 0::float THEN
            RETURN -1;
        END IF;

        aspect := atan2(dz_dy, -dz_dx);
        IF aspect > (pi() / 2.0) THEN
            RETURN (5.0 * pi() / 2.0) - aspect;
        ELSE
            RETURN (pi() / 2.0) - aspect;
        END IF;
    END;
    $$;


ALTER FUNCTION public._st_aspect4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) OWNER TO postgres;

--
-- Name: _st_count(text, text, integer, boolean, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _st_count(rastertable text, rastercolumn text, nband integer DEFAULT 1, exclude_nodata_value boolean DEFAULT true, sample_percent double precision DEFAULT 1) RETURNS bigint
    LANGUAGE plpgsql STABLE STRICT
    AS $_$
	DECLARE
		curs refcursor;

		ctable text;
		ccolumn text;
		rast raster;
		stats summarystats;

		rtn bigint;
		tmp bigint;
	BEGIN
		-- nband
		IF nband < 1 THEN
			RAISE WARNING 'Invalid band index (must use 1-based). Returning NULL';
			RETURN NULL;
		END IF;

		-- sample percent
		IF sample_percent < 0 OR sample_percent > 1 THEN
			RAISE WARNING 'Invalid sample percentage (must be between 0 and 1). Returning NULL';
			RETURN NULL;
		END IF;

		-- exclude_nodata_value IS TRUE
		IF exclude_nodata_value IS TRUE THEN
			SELECT count INTO rtn FROM _st_summarystats($1, $2, $3, $4, $5);
			RETURN rtn;
		END IF;

		-- clean rastertable and rastercolumn
		ctable := quote_ident(rastertable);
		ccolumn := quote_ident(rastercolumn);

		BEGIN
			OPEN curs FOR EXECUTE 'SELECT '
					|| ccolumn
					|| ' FROM '
					|| ctable
					|| ' WHERE '
					|| ccolumn
					|| ' IS NOT NULL';
		EXCEPTION
			WHEN OTHERS THEN
				RAISE WARNING 'Invalid table or column name. Returning NULL';
				RETURN NULL;
		END;

		rtn := 0;
		LOOP
			FETCH curs INTO rast;
			EXIT WHEN NOT FOUND;

			SELECT (width * height) INTO tmp FROM ST_Metadata(rast);
			rtn := rtn + tmp;
		END LOOP;

		CLOSE curs;

		RETURN rtn;
	END;
	$_$;


ALTER FUNCTION public._st_count(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision) OWNER TO postgres;

--
-- Name: _st_hillshade4ma(double precision[], text, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _st_hillshade4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) RETURNS double precision
    LANGUAGE plpgsql IMMUTABLE
    AS $$
    DECLARE
        pwidth float;
        pheight float;
        dz_dx float;
        dz_dy float;
        zenith float;
        azimuth float;
        slope float;
        aspect float;
        max_bright float;
        elevation_scale float;
    BEGIN
        pwidth := args[1]::float;
        pheight := args[2]::float;
        azimuth := (5.0 * pi() / 2.0) - args[3]::float;
        zenith := (pi() / 2.0) - args[4]::float;
        dz_dx := ((matrix[3][1] + 2.0 * matrix[3][2] + matrix[3][3]) - (matrix[1][1] + 2.0 * matrix[1][2] + matrix[1][3])) / (8.0 * pwidth);
        dz_dy := ((matrix[1][3] + 2.0 * matrix[2][3] + matrix[3][3]) - (matrix[1][1] + 2.0 * matrix[2][1] + matrix[3][1])) / (8.0 * pheight);
        elevation_scale := args[6]::float;
        slope := atan(sqrt(elevation_scale * pow(dz_dx, 2.0) + pow(dz_dy, 2.0)));
        -- handle special case of 0, 0
        IF abs(dz_dy) = 0::float AND abs(dz_dy) = 0::float THEN
            -- set to pi as that is the expected PostgreSQL answer in Linux
            aspect := pi();
        ELSE
            aspect := atan2(dz_dy, -dz_dx);
        END IF;
        max_bright := args[5]::float;

        IF aspect < 0 THEN
            aspect := aspect + (2.0 * pi());
        END IF;

        RETURN max_bright * ( (cos(zenith)*cos(slope)) + (sin(zenith)*sin(slope)*cos(azimuth - aspect)) );
    END;
    $$;


ALTER FUNCTION public._st_hillshade4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) OWNER TO postgres;

--
-- Name: _st_slope4ma(double precision[], text, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _st_slope4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) RETURNS double precision
    LANGUAGE plpgsql IMMUTABLE
    AS $$
    DECLARE
        pwidth float;
        pheight float;
        dz_dx float;
        dz_dy float;
    BEGIN
        pwidth := args[1]::float;
        pheight := args[2]::float;
        dz_dx := ((matrix[3][1] + 2.0 * matrix[3][2] + matrix[3][3]) - (matrix[1][1] + 2.0 * matrix[1][2] + matrix[1][3])) / (8.0 * pwidth);
        dz_dy := ((matrix[1][3] + 2.0 * matrix[2][3] + matrix[3][3]) - (matrix[1][1] + 2.0 * matrix[2][1] + matrix[3][1])) / (8.0 * pheight);
        RETURN atan(sqrt(pow(dz_dx, 2.0) + pow(dz_dy, 2.0)));
    END;
    $$;


ALTER FUNCTION public._st_slope4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) OWNER TO postgres;

--
-- Name: addauth(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION addauth(text) RETURNS boolean
    LANGUAGE plpgsql
    AS $_$ 
DECLARE
	lockid alias for $1;
	okay boolean;
	myrec record;
BEGIN
	-- check to see if table exists
	--  if not, CREATE TEMP TABLE mylock (transid xid, lockcode text)
	okay := 'f';
	FOR myrec IN SELECT * FROM pg_class WHERE relname = 'temp_lock_have_table' LOOP
		okay := 't';
	END LOOP; 
	IF (okay <> 't') THEN 
		CREATE TEMP TABLE temp_lock_have_table (transid xid, lockcode text);
			-- this will only work from pgsql7.4 up
			-- ON COMMIT DELETE ROWS;
	END IF;

	--  INSERT INTO mylock VALUES ( $1)
--	EXECUTE 'INSERT INTO temp_lock_have_table VALUES ( '||
--		quote_literal(getTransactionID()) || ',' ||
--		quote_literal(lockid) ||')';

	INSERT INTO temp_lock_have_table VALUES (getTransactionID(), lockid);

	RETURN true::boolean;
END;
$_$;


ALTER FUNCTION public.addauth(text) OWNER TO postgres;

--
-- Name: addgeometrycolumn(character varying, character varying, integer, character varying, integer, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION addgeometrycolumn(table_name character varying, column_name character varying, new_srid integer, new_type character varying, new_dim integer, use_typmod boolean DEFAULT true) RETURNS text
    LANGUAGE plpgsql STRICT
    AS $_$
DECLARE
	ret  text;
BEGIN
	SELECT AddGeometryColumn('','',$1,$2,$3,$4,$5, $6) into ret;
	RETURN ret;
END;
$_$;


ALTER FUNCTION public.addgeometrycolumn(table_name character varying, column_name character varying, new_srid integer, new_type character varying, new_dim integer, use_typmod boolean) OWNER TO postgres;

--
-- Name: addgeometrycolumn(character varying, character varying, character varying, integer, character varying, integer, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION addgeometrycolumn(schema_name character varying, table_name character varying, column_name character varying, new_srid integer, new_type character varying, new_dim integer, use_typmod boolean DEFAULT true) RETURNS text
    LANGUAGE plpgsql STABLE STRICT
    AS $_$
DECLARE
	ret  text;
BEGIN
	SELECT AddGeometryColumn('',$1,$2,$3,$4,$5,$6,$7) into ret;
	RETURN ret;
END;
$_$;


ALTER FUNCTION public.addgeometrycolumn(schema_name character varying, table_name character varying, column_name character varying, new_srid integer, new_type character varying, new_dim integer, use_typmod boolean) OWNER TO postgres;

--
-- Name: addgeometrycolumn(character varying, character varying, character varying, character varying, integer, character varying, integer, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION addgeometrycolumn(catalog_name character varying, schema_name character varying, table_name character varying, column_name character varying, new_srid_in integer, new_type character varying, new_dim integer, use_typmod boolean DEFAULT true) RETURNS text
    LANGUAGE plpgsql STRICT
    AS $$
DECLARE
	rec RECORD;
	sr varchar;
	real_schema name;
	sql text;
	new_srid integer;

BEGIN

	-- Verify geometry type
	IF (postgis_type_name(new_type,new_dim) IS NULL )
	THEN
		RAISE EXCEPTION 'Invalid type name "%(%)" - valid ones are:
	POINT, MULTIPOINT,
	LINESTRING, MULTILINESTRING,
	POLYGON, MULTIPOLYGON,
	CIRCULARSTRING, COMPOUNDCURVE, MULTICURVE,
	CURVEPOLYGON, MULTISURFACE,
	GEOMETRY, GEOMETRYCOLLECTION,
	POINTM, MULTIPOINTM,
	LINESTRINGM, MULTILINESTRINGM,
	POLYGONM, MULTIPOLYGONM,
	CIRCULARSTRINGM, COMPOUNDCURVEM, MULTICURVEM
	CURVEPOLYGONM, MULTISURFACEM, TRIANGLE, TRIANGLEM,
	POLYHEDRALSURFACE, POLYHEDRALSURFACEM, TIN, TINM
	or GEOMETRYCOLLECTIONM', new_type, new_dim;
		RETURN 'fail';
	END IF;


	-- Verify dimension
	IF ( (new_dim >4) OR (new_dim <2) ) THEN
		RAISE EXCEPTION 'invalid dimension';
		RETURN 'fail';
	END IF;

	IF ( (new_type LIKE '%M') AND (new_dim!=3) ) THEN
		RAISE EXCEPTION 'TypeM needs 3 dimensions';
		RETURN 'fail';
	END IF;


	-- Verify SRID
	IF ( new_srid_in > 0 ) THEN
		IF new_srid_in > 998999 THEN
			RAISE EXCEPTION 'AddGeometryColumn() - SRID must be <= %', 998999;
		END IF;
		new_srid := new_srid_in;
		SELECT SRID INTO sr FROM spatial_ref_sys WHERE SRID = new_srid;
		IF NOT FOUND THEN
			RAISE EXCEPTION 'AddGeometryColumn() - invalid SRID';
			RETURN 'fail';
		END IF;
	ELSE
		new_srid := ST_SRID('POINT EMPTY'::geometry);
		IF ( new_srid_in != new_srid ) THEN
			RAISE NOTICE 'SRID value % converted to the officially unknown SRID value %', new_srid_in, new_srid;
		END IF;
	END IF;


	-- Verify schema
	IF ( schema_name IS NOT NULL AND schema_name != '' ) THEN
		sql := 'SELECT nspname FROM pg_namespace ' ||
			'WHERE text(nspname) = ' || quote_literal(schema_name) ||
			'LIMIT 1';
		RAISE DEBUG '%', sql;
		EXECUTE sql INTO real_schema;

		IF ( real_schema IS NULL ) THEN
			RAISE EXCEPTION 'Schema % is not a valid schemaname', quote_literal(schema_name);
			RETURN 'fail';
		END IF;
	END IF;

	IF ( real_schema IS NULL ) THEN
		RAISE DEBUG 'Detecting schema';
		sql := 'SELECT n.nspname AS schemaname ' ||
			'FROM pg_catalog.pg_class c ' ||
			  'JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace ' ||
			'WHERE c.relkind = ' || quote_literal('r') ||
			' AND n.nspname NOT IN (' || quote_literal('pg_catalog') || ', ' || quote_literal('pg_toast') || ')' ||
			' AND pg_catalog.pg_table_is_visible(c.oid)' ||
			' AND c.relname = ' || quote_literal(table_name);
		RAISE DEBUG '%', sql;
		EXECUTE sql INTO real_schema;

		IF ( real_schema IS NULL ) THEN
			RAISE EXCEPTION 'Table % does not occur in the search_path', quote_literal(table_name);
			RETURN 'fail';
		END IF;
	END IF;


	-- Add geometry column to table
	IF use_typmod THEN
	     sql := 'ALTER TABLE ' ||
            quote_ident(real_schema) || '.' || quote_ident(table_name)
            || ' ADD COLUMN ' || quote_ident(column_name) ||
            ' geometry(' || postgis_type_name(new_type, new_dim) || ', ' || new_srid::text || ')';
        RAISE DEBUG '%', sql;
	ELSE
        sql := 'ALTER TABLE ' ||
            quote_ident(real_schema) || '.' || quote_ident(table_name)
            || ' ADD COLUMN ' || quote_ident(column_name) ||
            ' geometry ';
        RAISE DEBUG '%', sql;
    END IF;
	EXECUTE sql;

	IF NOT use_typmod THEN
        -- Add table CHECKs
        sql := 'ALTER TABLE ' ||
            quote_ident(real_schema) || '.' || quote_ident(table_name)
            || ' ADD CONSTRAINT '
            || quote_ident('enforce_srid_' || column_name)
            || ' CHECK (st_srid(' || quote_ident(column_name) ||
            ') = ' || new_srid::text || ')' ;
        RAISE DEBUG '%', sql;
        EXECUTE sql;
    
        sql := 'ALTER TABLE ' ||
            quote_ident(real_schema) || '.' || quote_ident(table_name)
            || ' ADD CONSTRAINT '
            || quote_ident('enforce_dims_' || column_name)
            || ' CHECK (st_ndims(' || quote_ident(column_name) ||
            ') = ' || new_dim::text || ')' ;
        RAISE DEBUG '%', sql;
        EXECUTE sql;
    
        IF ( NOT (new_type = 'GEOMETRY')) THEN
            sql := 'ALTER TABLE ' ||
                quote_ident(real_schema) || '.' || quote_ident(table_name) || ' ADD CONSTRAINT ' ||
                quote_ident('enforce_geotype_' || column_name) ||
                ' CHECK (GeometryType(' ||
                quote_ident(column_name) || ')=' ||
                quote_literal(new_type) || ' OR (' ||
                quote_ident(column_name) || ') is null)';
            RAISE DEBUG '%', sql;
            EXECUTE sql;
        END IF;
    END IF;

	RETURN
		real_schema || '.' ||
		table_name || '.' || column_name ||
		' SRID:' || new_srid::text ||
		' TYPE:' || new_type ||
		' DIMS:' || new_dim::text || ' ';
END;
$$;


ALTER FUNCTION public.addgeometrycolumn(catalog_name character varying, schema_name character varying, table_name character varying, column_name character varying, new_srid_in integer, new_type character varying, new_dim integer, use_typmod boolean) OWNER TO postgres;

--
-- Name: addoverviewconstraints(name, name, name, name, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION addoverviewconstraints(ovtable name, ovcolumn name, reftable name, refcolumn name, ovfactor integer) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT AddOverviewConstraints('', $1, $2, '', $3, $4, $5) $_$;


ALTER FUNCTION public.addoverviewconstraints(ovtable name, ovcolumn name, reftable name, refcolumn name, ovfactor integer) OWNER TO postgres;

--
-- Name: addoverviewconstraints(name, name, name, name, name, name, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION addoverviewconstraints(ovschema name, ovtable name, ovcolumn name, refschema name, reftable name, refcolumn name, ovfactor integer) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		x int;
		s name;
		t name;
		oschema name;
		rschema name;
		sql text;
		rtn boolean;
	BEGIN
		FOR x IN 1..2 LOOP
			s := '';

			IF x = 1 THEN
				s := $1;
				t := $2;
			ELSE
				s := $4;
				t := $5;
			END IF;

			-- validate user-provided schema
			IF length(s) > 0 THEN
				sql := 'SELECT nspname FROM pg_namespace '
					|| 'WHERE nspname = ' || quote_literal(s)
					|| 'LIMIT 1';
				EXECUTE sql INTO s;

				IF s IS NULL THEN
					RAISE EXCEPTION 'The value % is not a valid schema', quote_literal(s);
					RETURN FALSE;
				END IF;
			END IF;

			-- no schema, determine what it could be using the table
			IF length(s) < 1 THEN
				sql := 'SELECT n.nspname AS schemaname '
					|| 'FROM pg_catalog.pg_class c '
					|| 'JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace '
					|| 'WHERE c.relkind = ' || quote_literal('r')
					|| ' AND n.nspname NOT IN (' || quote_literal('pg_catalog')
					|| ', ' || quote_literal('pg_toast')
					|| ') AND pg_catalog.pg_table_is_visible(c.oid)'
					|| ' AND c.relname = ' || quote_literal(t);
				EXECUTE sql INTO s;

				IF s IS NULL THEN
					RAISE EXCEPTION 'The table % does not occur in the search_path', quote_literal(t);
					RETURN FALSE;
				END IF;
			END IF;

			IF x = 1 THEN
				oschema := s;
			ELSE
				rschema := s;
			END IF;
		END LOOP;

		-- reference raster
		rtn := _add_overview_constraint(oschema, $2, $3, rschema, $5, $6, $7);
		IF rtn IS FALSE THEN
			RAISE EXCEPTION 'Unable to add the overview constraint.  Is the schema name, table name or column name incorrect?';
			RETURN FALSE;
		END IF;

		RETURN TRUE;
	END;
	$_$;


ALTER FUNCTION public.addoverviewconstraints(ovschema name, ovtable name, ovcolumn name, refschema name, reftable name, refcolumn name, ovfactor integer) OWNER TO postgres;

--
-- Name: addrasterconstraints(name, name, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION addrasterconstraints(rasttable name, rastcolumn name, VARIADIC constraints text[]) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT AddRasterConstraints('', $1, $2, VARIADIC $3) $_$;


ALTER FUNCTION public.addrasterconstraints(rasttable name, rastcolumn name, VARIADIC constraints text[]) OWNER TO postgres;

--
-- Name: FUNCTION addrasterconstraints(rasttable name, rastcolumn name, VARIADIC constraints text[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION addrasterconstraints(rasttable name, rastcolumn name, VARIADIC constraints text[]) IS 'args: rasttable, rastcolumn, VARIADIC constraints - Adds raster constraints to a loaded raster table for a specific column that constrains spatial ref, scaling, blocksize, alignment, bands, band type and a flag to denote if raster column is regularly blocked. The table must be loaded with data for the constraints to be inferred. Returns true of the constraint setting was accomplished and if issues a notice.';


--
-- Name: addrasterconstraints(name, name, name, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION addrasterconstraints(rastschema name, rasttable name, rastcolumn name, VARIADIC constraints text[]) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		max int;
		cnt int;
		sql text;
		schema name;
		x int;
		kw text;
		rtn boolean;
	BEGIN
		cnt := 0;
		max := array_length(constraints, 1);
		IF max < 1 THEN
			RAISE NOTICE 'No constraints indicated to be added.  Doing nothing';
			RETURN TRUE;
		END IF;

		-- validate schema
		schema := NULL;
		IF length($1) > 0 THEN
			sql := 'SELECT nspname FROM pg_namespace '
				|| 'WHERE nspname = ' || quote_literal($1)
				|| 'LIMIT 1';
			EXECUTE sql INTO schema;

			IF schema IS NULL THEN
				RAISE EXCEPTION 'The value provided for schema is invalid';
				RETURN FALSE;
			END IF;
		END IF;

		IF schema IS NULL THEN
			sql := 'SELECT n.nspname AS schemaname '
				|| 'FROM pg_catalog.pg_class c '
				|| 'JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace '
				|| 'WHERE c.relkind = ' || quote_literal('r')
				|| ' AND n.nspname NOT IN (' || quote_literal('pg_catalog')
				|| ', ' || quote_literal('pg_toast')
				|| ') AND pg_catalog.pg_table_is_visible(c.oid)'
				|| ' AND c.relname = ' || quote_literal($2);
			EXECUTE sql INTO schema;

			IF schema IS NULL THEN
				RAISE EXCEPTION 'The table % does not occur in the search_path', quote_literal($2);
				RETURN FALSE;
			END IF;
		END IF;

		<<kwloop>>
		FOR x in 1..max LOOP
			kw := trim(both from lower(constraints[x]));

			BEGIN
				CASE
					WHEN kw = 'srid' THEN
						RAISE NOTICE 'Adding SRID constraint';
						rtn := _add_raster_constraint_srid(schema, $2, $3);
					WHEN kw IN ('scale_x', 'scalex') THEN
						RAISE NOTICE 'Adding scale-X constraint';
						rtn := _add_raster_constraint_scale(schema, $2, $3, 'x');
					WHEN kw IN ('scale_y', 'scaley') THEN
						RAISE NOTICE 'Adding scale-Y constraint';
						rtn := _add_raster_constraint_scale(schema, $2, $3, 'y');
					WHEN kw = 'scale' THEN
						RAISE NOTICE 'Adding scale-X constraint';
						rtn := _add_raster_constraint_scale(schema, $2, $3, 'x');
						RAISE NOTICE 'Adding scale-Y constraint';
						rtn := _add_raster_constraint_scale(schema, $2, $3, 'y');
					WHEN kw IN ('blocksize_x', 'blocksizex', 'width') THEN
						RAISE NOTICE 'Adding blocksize-X constraint';
						rtn := _add_raster_constraint_blocksize(schema, $2, $3, 'width');
					WHEN kw IN ('blocksize_y', 'blocksizey', 'height') THEN
						RAISE NOTICE 'Adding blocksize-Y constraint';
						rtn := _add_raster_constraint_blocksize(schema, $2, $3, 'height');
					WHEN kw = 'blocksize' THEN
						RAISE NOTICE 'Adding blocksize-X constraint';
						rtn := _add_raster_constraint_blocksize(schema, $2, $3, 'width');
						RAISE NOTICE 'Adding blocksize-Y constraint';
						rtn := _add_raster_constraint_blocksize(schema, $2, $3, 'height');
					WHEN kw IN ('same_alignment', 'samealignment', 'alignment') THEN
						RAISE NOTICE 'Adding alignment constraint';
						rtn := _add_raster_constraint_alignment(schema, $2, $3);
					WHEN kw IN ('regular_blocking', 'regularblocking') THEN
						RAISE NOTICE 'Adding regular blocking constraint';
						rtn := _add_raster_constraint_regular_blocking(schema, $2, $3);
					WHEN kw IN ('num_bands', 'numbands') THEN
						RAISE NOTICE 'Adding number of bands constraint';
						rtn := _add_raster_constraint_num_bands(schema, $2, $3);
					WHEN kw IN ('pixel_types', 'pixeltypes') THEN
						RAISE NOTICE 'Adding pixel type constraint';
						rtn := _add_raster_constraint_pixel_types(schema, $2, $3);
					WHEN kw IN ('nodata_values', 'nodatavalues', 'nodata') THEN
						RAISE NOTICE 'Adding nodata value constraint';
						rtn := _add_raster_constraint_nodata_values(schema, $2, $3);
					WHEN kw IN ('out_db', 'outdb') THEN
						RAISE NOTICE 'Adding out-of-database constraint';
						rtn := _add_raster_constraint_out_db(schema, $2, $3);
					WHEN kw = 'extent' THEN
						RAISE NOTICE 'Adding maximum extent constraint';
						rtn := _add_raster_constraint_extent(schema, $2, $3);
					ELSE
						RAISE NOTICE 'Unknown constraint: %.  Skipping', quote_literal(constraints[x]);
						CONTINUE kwloop;
				END CASE;
			END;

			IF rtn IS FALSE THEN
				cnt := cnt + 1;
				RAISE WARNING 'Unable to add constraint: %.  Skipping', quote_literal(constraints[x]);
			END IF;

		END LOOP kwloop;

		IF cnt = max THEN
			RAISE EXCEPTION 'None of the constraints specified could be added.  Is the schema name, table name or column name incorrect?';
			RETURN FALSE;
		END IF;

		RETURN TRUE;
	END;
	$_$;


ALTER FUNCTION public.addrasterconstraints(rastschema name, rasttable name, rastcolumn name, VARIADIC constraints text[]) OWNER TO postgres;

--
-- Name: FUNCTION addrasterconstraints(rastschema name, rasttable name, rastcolumn name, VARIADIC constraints text[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION addrasterconstraints(rastschema name, rasttable name, rastcolumn name, VARIADIC constraints text[]) IS 'args: rastschema, rasttable, rastcolumn, VARIADIC constraints - Adds raster constraints to a loaded raster table for a specific column that constrains spatial ref, scaling, blocksize, alignment, bands, band type and a flag to denote if raster column is regularly blocked. The table must be loaded with data for the constraints to be inferred. Returns true of the constraint setting was accomplished and if issues a notice.';


--
-- Name: addrasterconstraints(name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION addrasterconstraints(rasttable name, rastcolumn name, srid boolean DEFAULT true, scale_x boolean DEFAULT true, scale_y boolean DEFAULT true, blocksize_x boolean DEFAULT true, blocksize_y boolean DEFAULT true, same_alignment boolean DEFAULT true, regular_blocking boolean DEFAULT false, num_bands boolean DEFAULT true, pixel_types boolean DEFAULT true, nodata_values boolean DEFAULT true, out_db boolean DEFAULT true, extent boolean DEFAULT true) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT AddRasterConstraints('', $1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, $14) $_$;


ALTER FUNCTION public.addrasterconstraints(rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean) OWNER TO postgres;

--
-- Name: FUNCTION addrasterconstraints(rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION addrasterconstraints(rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean) IS 'args: rasttable, rastcolumn, srid, scale_x, scale_y, blocksize_x, blocksize_y, same_alignment, regular_blocking, num_bands=true, pixel_types=true, nodata_values=true, out_db=true, extent=true - Adds raster constraints to a loaded raster table for a specific column that constrains spatial ref, scaling, blocksize, alignment, bands, band type and a flag to denote if raster column is regularly blocked. The table must be loaded with data for the constraints to be inferred. Returns true of the constraint setting was accomplished and if issues a notice.';


--
-- Name: addrasterconstraints(name, name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION addrasterconstraints(rastschema name, rasttable name, rastcolumn name, srid boolean DEFAULT true, scale_x boolean DEFAULT true, scale_y boolean DEFAULT true, blocksize_x boolean DEFAULT true, blocksize_y boolean DEFAULT true, same_alignment boolean DEFAULT true, regular_blocking boolean DEFAULT false, num_bands boolean DEFAULT true, pixel_types boolean DEFAULT true, nodata_values boolean DEFAULT true, out_db boolean DEFAULT true, extent boolean DEFAULT true) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		constraints text[];
	BEGIN
		IF srid IS TRUE THEN
			constraints := constraints || 'srid'::text;
		END IF;

		IF scale_x IS TRUE THEN
			constraints := constraints || 'scale_x'::text;
		END IF;

		IF scale_y IS TRUE THEN
			constraints := constraints || 'scale_y'::text;
		END IF;

		IF blocksize_x IS TRUE THEN
			constraints := constraints || 'blocksize_x'::text;
		END IF;

		IF blocksize_y IS TRUE THEN
			constraints := constraints || 'blocksize_y'::text;
		END IF;

		IF same_alignment IS TRUE THEN
			constraints := constraints || 'same_alignment'::text;
		END IF;

		IF regular_blocking IS TRUE THEN
			constraints := constraints || 'regular_blocking'::text;
		END IF;

		IF num_bands IS TRUE THEN
			constraints := constraints || 'num_bands'::text;
		END IF;

		IF pixel_types IS TRUE THEN
			constraints := constraints || 'pixel_types'::text;
		END IF;

		IF nodata_values IS TRUE THEN
			constraints := constraints || 'nodata_values'::text;
		END IF;

		IF out_db IS TRUE THEN
			constraints := constraints || 'out_db'::text;
		END IF;

		IF extent IS TRUE THEN
			constraints := constraints || 'extent'::text;
		END IF;

		RETURN AddRasterConstraints($1, $2, $3, VARIADIC constraints);
	END;
	$_$;


ALTER FUNCTION public.addrasterconstraints(rastschema name, rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean) OWNER TO postgres;

--
-- Name: FUNCTION addrasterconstraints(rastschema name, rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION addrasterconstraints(rastschema name, rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean) IS 'args: rastschema, rasttable, rastcolumn, srid=true, scale_x=true, scale_y=true, blocksize_x=true, blocksize_y=true, same_alignment=true, regular_blocking=true, num_bands=true, pixel_types=true, nodata_values=true, out_db=true, extent=true - Adds raster constraints to a loaded raster table for a specific column that constrains spatial ref, scaling, blocksize, alignment, bands, band type and a flag to denote if raster column is regularly blocked. The table must be loaded with data for the constraints to be inferred. Returns true of the constraint setting was accomplished and if issues a notice.';


--
-- Name: checkauth(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION checkauth(text, text) RETURNS integer
    LANGUAGE sql
    AS $_$ SELECT CheckAuth('', $1, $2) $_$;


ALTER FUNCTION public.checkauth(text, text) OWNER TO postgres;

--
-- Name: checkauth(text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION checkauth(text, text, text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$ 
DECLARE
	schema text;
BEGIN
	IF NOT LongTransactionsEnabled() THEN
		RAISE EXCEPTION 'Long transaction support disabled, use EnableLongTransaction() to enable.';
	END IF;

	if ( $1 != '' ) THEN
		schema = $1;
	ELSE
		SELECT current_schema() into schema;
	END IF;

	-- TODO: check for an already existing trigger ?

	EXECUTE 'CREATE TRIGGER check_auth BEFORE UPDATE OR DELETE ON ' 
		|| quote_ident(schema) || '.' || quote_ident($2)
		||' FOR EACH ROW EXECUTE PROCEDURE CheckAuthTrigger('
		|| quote_literal($3) || ')';

	RETURN 0;
END;
$_$;


ALTER FUNCTION public.checkauth(text, text, text) OWNER TO postgres;

--
-- Name: disablelongtransactions(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION disablelongtransactions() RETURNS text
    LANGUAGE plpgsql
    AS $$ 
DECLARE
	rec RECORD;

BEGIN

	--
	-- Drop all triggers applied by CheckAuth()
	--
	FOR rec IN
		SELECT c.relname, t.tgname, t.tgargs FROM pg_trigger t, pg_class c, pg_proc p
		WHERE p.proname = 'checkauthtrigger' and t.tgfoid = p.oid and t.tgrelid = c.oid
	LOOP
		EXECUTE 'DROP TRIGGER ' || quote_ident(rec.tgname) ||
			' ON ' || quote_ident(rec.relname);
	END LOOP;

	--
	-- Drop the authorization_table table
	--
	FOR rec IN SELECT * FROM pg_class WHERE relname = 'authorization_table' LOOP
		DROP TABLE authorization_table;
	END LOOP;

	--
	-- Drop the authorized_tables view
	--
	FOR rec IN SELECT * FROM pg_class WHERE relname = 'authorized_tables' LOOP
		DROP VIEW authorized_tables;
	END LOOP;

	RETURN 'Long transactions support disabled';
END;
$$;


ALTER FUNCTION public.disablelongtransactions() OWNER TO postgres;

--
-- Name: dropgeometrycolumn(character varying, character varying); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dropgeometrycolumn(table_name character varying, column_name character varying) RETURNS text
    LANGUAGE plpgsql STRICT
    AS $_$
DECLARE
	ret text;
BEGIN
	SELECT DropGeometryColumn('','',$1,$2) into ret;
	RETURN ret;
END;
$_$;


ALTER FUNCTION public.dropgeometrycolumn(table_name character varying, column_name character varying) OWNER TO postgres;

--
-- Name: dropgeometrycolumn(character varying, character varying, character varying); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dropgeometrycolumn(schema_name character varying, table_name character varying, column_name character varying) RETURNS text
    LANGUAGE plpgsql STRICT
    AS $_$
DECLARE
	ret text;
BEGIN
	SELECT DropGeometryColumn('',$1,$2,$3) into ret;
	RETURN ret;
END;
$_$;


ALTER FUNCTION public.dropgeometrycolumn(schema_name character varying, table_name character varying, column_name character varying) OWNER TO postgres;

--
-- Name: dropgeometrycolumn(character varying, character varying, character varying, character varying); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dropgeometrycolumn(catalog_name character varying, schema_name character varying, table_name character varying, column_name character varying) RETURNS text
    LANGUAGE plpgsql STRICT
    AS $$
DECLARE
	myrec RECORD;
	okay boolean;
	real_schema name;

BEGIN


	-- Find, check or fix schema_name
	IF ( schema_name != '' ) THEN
		okay = false;

		FOR myrec IN SELECT nspname FROM pg_namespace WHERE text(nspname) = schema_name LOOP
			okay := true;
		END LOOP;

		IF ( okay <>  true ) THEN
			RAISE NOTICE 'Invalid schema name - using current_schema()';
			SELECT current_schema() into real_schema;
		ELSE
			real_schema = schema_name;
		END IF;
	ELSE
		SELECT current_schema() into real_schema;
	END IF;

	-- Find out if the column is in the geometry_columns table
	okay = false;
	FOR myrec IN SELECT * from geometry_columns where f_table_schema = text(real_schema) and f_table_name = table_name and f_geometry_column = column_name LOOP
		okay := true;
	END LOOP;
	IF (okay <> true) THEN
		RAISE EXCEPTION 'column not found in geometry_columns table';
		RETURN false;
	END IF;

	-- Remove table column
	EXECUTE 'ALTER TABLE ' || quote_ident(real_schema) || '.' ||
		quote_ident(table_name) || ' DROP COLUMN ' ||
		quote_ident(column_name);

	RETURN real_schema || '.' || table_name || '.' || column_name ||' effectively removed.';

END;
$$;


ALTER FUNCTION public.dropgeometrycolumn(catalog_name character varying, schema_name character varying, table_name character varying, column_name character varying) OWNER TO postgres;

--
-- Name: dropgeometrytable(character varying); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dropgeometrytable(table_name character varying) RETURNS text
    LANGUAGE sql STRICT
    AS $_$ SELECT DropGeometryTable('','',$1) $_$;


ALTER FUNCTION public.dropgeometrytable(table_name character varying) OWNER TO postgres;

--
-- Name: dropgeometrytable(character varying, character varying); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dropgeometrytable(schema_name character varying, table_name character varying) RETURNS text
    LANGUAGE sql STRICT
    AS $_$ SELECT DropGeometryTable('',$1,$2) $_$;


ALTER FUNCTION public.dropgeometrytable(schema_name character varying, table_name character varying) OWNER TO postgres;

--
-- Name: dropgeometrytable(character varying, character varying, character varying); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dropgeometrytable(catalog_name character varying, schema_name character varying, table_name character varying) RETURNS text
    LANGUAGE plpgsql STRICT
    AS $$
DECLARE
	real_schema name;

BEGIN

	IF ( schema_name = '' ) THEN
		SELECT current_schema() into real_schema;
	ELSE
		real_schema = schema_name;
	END IF;

	-- TODO: Should we warn if table doesn't exist probably instead just saying dropped
	-- Remove table
	EXECUTE 'DROP TABLE IF EXISTS '
		|| quote_ident(real_schema) || '.' ||
		quote_ident(table_name) || ' RESTRICT';

	RETURN
		real_schema || '.' ||
		table_name ||' dropped.';

END;
$$;


ALTER FUNCTION public.dropgeometrytable(catalog_name character varying, schema_name character varying, table_name character varying) OWNER TO postgres;

--
-- Name: dropoverviewconstraints(name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dropoverviewconstraints(ovtable name, ovcolumn name) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT DropOverviewConstraints('', $1, $2) $_$;


ALTER FUNCTION public.dropoverviewconstraints(ovtable name, ovcolumn name) OWNER TO postgres;

--
-- Name: dropoverviewconstraints(name, name, name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dropoverviewconstraints(ovschema name, ovtable name, ovcolumn name) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		schema name;
		sql text;
		rtn boolean;
	BEGIN
		-- validate schema
		schema := NULL;
		IF length($1) > 0 THEN
			sql := 'SELECT nspname FROM pg_namespace '
				|| 'WHERE nspname = ' || quote_literal($1)
				|| 'LIMIT 1';
			EXECUTE sql INTO schema;

			IF schema IS NULL THEN
				RAISE EXCEPTION 'The value provided for schema is invalid';
				RETURN FALSE;
			END IF;
		END IF;

		IF schema IS NULL THEN
			sql := 'SELECT n.nspname AS schemaname '
				|| 'FROM pg_catalog.pg_class c '
				|| 'JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace '
				|| 'WHERE c.relkind = ' || quote_literal('r')
				|| ' AND n.nspname NOT IN (' || quote_literal('pg_catalog')
				|| ', ' || quote_literal('pg_toast')
				|| ') AND pg_catalog.pg_table_is_visible(c.oid)'
				|| ' AND c.relname = ' || quote_literal($2);
			EXECUTE sql INTO schema;

			IF schema IS NULL THEN
				RAISE EXCEPTION 'The table % does not occur in the search_path', quote_literal($2);
				RETURN FALSE;
			END IF;
		END IF;

		rtn := _drop_overview_constraint(schema, $2, $3);
		IF rtn IS FALSE THEN
			RAISE EXCEPTION 'Unable to drop the overview constraint .  Is the schema name, table name or column name incorrect?';
			RETURN FALSE;
		END IF;

		RETURN TRUE;
	END;
	$_$;


ALTER FUNCTION public.dropoverviewconstraints(ovschema name, ovtable name, ovcolumn name) OWNER TO postgres;

--
-- Name: droprasterconstraints(name, name, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION droprasterconstraints(rasttable name, rastcolumn name, VARIADIC constraints text[]) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT DropRasterConstraints('', $1, $2, VARIADIC $3) $_$;


ALTER FUNCTION public.droprasterconstraints(rasttable name, rastcolumn name, VARIADIC constraints text[]) OWNER TO postgres;

--
-- Name: droprasterconstraints(name, name, name, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION droprasterconstraints(rastschema name, rasttable name, rastcolumn name, VARIADIC constraints text[]) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		max int;
		x int;
		schema name;
		sql text;
		kw text;
		rtn boolean;
		cnt int;
	BEGIN
		cnt := 0;
		max := array_length(constraints, 1);
		IF max < 1 THEN
			RAISE NOTICE 'No constraints indicated to be dropped.  Doing nothing';
			RETURN TRUE;
		END IF;

		-- validate schema
		schema := NULL;
		IF length($1) > 0 THEN
			sql := 'SELECT nspname FROM pg_namespace '
				|| 'WHERE nspname = ' || quote_literal($1)
				|| 'LIMIT 1';
			EXECUTE sql INTO schema;

			IF schema IS NULL THEN
				RAISE EXCEPTION 'The value provided for schema is invalid';
				RETURN FALSE;
			END IF;
		END IF;

		IF schema IS NULL THEN
			sql := 'SELECT n.nspname AS schemaname '
				|| 'FROM pg_catalog.pg_class c '
				|| 'JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace '
				|| 'WHERE c.relkind = ' || quote_literal('r')
				|| ' AND n.nspname NOT IN (' || quote_literal('pg_catalog')
				|| ', ' || quote_literal('pg_toast')
				|| ') AND pg_catalog.pg_table_is_visible(c.oid)'
				|| ' AND c.relname = ' || quote_literal($2);
			EXECUTE sql INTO schema;

			IF schema IS NULL THEN
				RAISE EXCEPTION 'The table % does not occur in the search_path', quote_literal($2);
				RETURN FALSE;
			END IF;
		END IF;

		<<kwloop>>
		FOR x in 1..max LOOP
			kw := trim(both from lower(constraints[x]));

			BEGIN
				CASE
					WHEN kw = 'srid' THEN
						RAISE NOTICE 'Dropping SRID constraint';
						rtn := _drop_raster_constraint_srid(schema, $2, $3);
					WHEN kw IN ('scale_x', 'scalex') THEN
						RAISE NOTICE 'Dropping scale-X constraint';
						rtn := _drop_raster_constraint_scale(schema, $2, $3, 'x');
					WHEN kw IN ('scale_y', 'scaley') THEN
						RAISE NOTICE 'Dropping scale-Y constraint';
						rtn := _drop_raster_constraint_scale(schema, $2, $3, 'y');
					WHEN kw = 'scale' THEN
						RAISE NOTICE 'Dropping scale-X constraint';
						rtn := _drop_raster_constraint_scale(schema, $2, $3, 'x');
						RAISE NOTICE 'Dropping scale-Y constraint';
						rtn := _drop_raster_constraint_scale(schema, $2, $3, 'y');
					WHEN kw IN ('blocksize_x', 'blocksizex', 'width') THEN
						RAISE NOTICE 'Dropping blocksize-X constraint';
						rtn := _drop_raster_constraint_blocksize(schema, $2, $3, 'width');
					WHEN kw IN ('blocksize_y', 'blocksizey', 'height') THEN
						RAISE NOTICE 'Dropping blocksize-Y constraint';
						rtn := _drop_raster_constraint_blocksize(schema, $2, $3, 'height');
					WHEN kw = 'blocksize' THEN
						RAISE NOTICE 'Dropping blocksize-X constraint';
						rtn := _drop_raster_constraint_blocksize(schema, $2, $3, 'width');
						RAISE NOTICE 'Dropping blocksize-Y constraint';
						rtn := _drop_raster_constraint_blocksize(schema, $2, $3, 'height');
					WHEN kw IN ('same_alignment', 'samealignment', 'alignment') THEN
						RAISE NOTICE 'Dropping alignment constraint';
						rtn := _drop_raster_constraint_alignment(schema, $2, $3);
					WHEN kw IN ('regular_blocking', 'regularblocking') THEN
						RAISE NOTICE 'Dropping regular blocking constraint';
						rtn := _drop_raster_constraint_regular_blocking(schema, $2, $3);
					WHEN kw IN ('num_bands', 'numbands') THEN
						RAISE NOTICE 'Dropping number of bands constraint';
						rtn := _drop_raster_constraint_num_bands(schema, $2, $3);
					WHEN kw IN ('pixel_types', 'pixeltypes') THEN
						RAISE NOTICE 'Dropping pixel type constraint';
						rtn := _drop_raster_constraint_pixel_types(schema, $2, $3);
					WHEN kw IN ('nodata_values', 'nodatavalues', 'nodata') THEN
						RAISE NOTICE 'Dropping nodata value constraint';
						rtn := _drop_raster_constraint_nodata_values(schema, $2, $3);
					WHEN kw IN ('out_db', 'outdb') THEN
						RAISE NOTICE 'Dropping out-of-database constraint';
						rtn := _drop_raster_constraint_out_db(schema, $2, $3);
					WHEN kw = 'extent' THEN
						RAISE NOTICE 'Dropping maximum extent constraint';
						rtn := _drop_raster_constraint_extent(schema, $2, $3);
					ELSE
						RAISE NOTICE 'Unknown constraint: %.  Skipping', quote_literal(constraints[x]);
						CONTINUE kwloop;
				END CASE;
			END;

			IF rtn IS FALSE THEN
				cnt := cnt + 1;
				RAISE WARNING 'Unable to drop constraint: %.  Skipping', quote_literal(constraints[x]);
			END IF;

		END LOOP kwloop;

		IF cnt = max THEN
			RAISE EXCEPTION 'None of the constraints specified could be dropped.  Is the schema name, table name or column name incorrect?';
			RETURN FALSE;
		END IF;

		RETURN TRUE;
	END;
	$_$;


ALTER FUNCTION public.droprasterconstraints(rastschema name, rasttable name, rastcolumn name, VARIADIC constraints text[]) OWNER TO postgres;

--
-- Name: FUNCTION droprasterconstraints(rastschema name, rasttable name, rastcolumn name, VARIADIC constraints text[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION droprasterconstraints(rastschema name, rasttable name, rastcolumn name, VARIADIC constraints text[]) IS 'args: rastschema, rasttable, rastcolumn, constraints - Drops PostGIS raster constraints that refer to a raster table column. Useful if you need to reload data or update your raster column data.';


--
-- Name: droprasterconstraints(name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION droprasterconstraints(rasttable name, rastcolumn name, srid boolean DEFAULT true, scale_x boolean DEFAULT true, scale_y boolean DEFAULT true, blocksize_x boolean DEFAULT true, blocksize_y boolean DEFAULT true, same_alignment boolean DEFAULT true, regular_blocking boolean DEFAULT true, num_bands boolean DEFAULT true, pixel_types boolean DEFAULT true, nodata_values boolean DEFAULT true, out_db boolean DEFAULT true, extent boolean DEFAULT true) RETURNS boolean
    LANGUAGE sql STRICT
    AS $_$ SELECT DropRasterConstraints('', $1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, $14) $_$;


ALTER FUNCTION public.droprasterconstraints(rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean) OWNER TO postgres;

--
-- Name: FUNCTION droprasterconstraints(rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION droprasterconstraints(rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean) IS 'args: rasttable, rastcolumn, srid, scale_x, scale_y, blocksize_x, blocksize_y, same_alignment, regular_blocking, num_bands=true, pixel_types=true, nodata_values=true, out_db=true, extent=true - Drops PostGIS raster constraints that refer to a raster table column. Useful if you need to reload data or update your raster column data.';


--
-- Name: droprasterconstraints(name, name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION droprasterconstraints(rastschema name, rasttable name, rastcolumn name, srid boolean DEFAULT true, scale_x boolean DEFAULT true, scale_y boolean DEFAULT true, blocksize_x boolean DEFAULT true, blocksize_y boolean DEFAULT true, same_alignment boolean DEFAULT true, regular_blocking boolean DEFAULT true, num_bands boolean DEFAULT true, pixel_types boolean DEFAULT true, nodata_values boolean DEFAULT true, out_db boolean DEFAULT true, extent boolean DEFAULT true) RETURNS boolean
    LANGUAGE plpgsql STRICT
    AS $_$
	DECLARE
		constraints text[];
	BEGIN
		IF srid IS TRUE THEN
			constraints := constraints || 'srid'::text;
		END IF;

		IF scale_x IS TRUE THEN
			constraints := constraints || 'scale_x'::text;
		END IF;

		IF scale_y IS TRUE THEN
			constraints := constraints || 'scale_y'::text;
		END IF;

		IF blocksize_x IS TRUE THEN
			constraints := constraints || 'blocksize_x'::text;
		END IF;

		IF blocksize_y IS TRUE THEN
			constraints := constraints || 'blocksize_y'::text;
		END IF;

		IF same_alignment IS TRUE THEN
			constraints := constraints || 'same_alignment'::text;
		END IF;

		IF regular_blocking IS TRUE THEN
			constraints := constraints || 'regular_blocking'::text;
		END IF;

		IF num_bands IS TRUE THEN
			constraints := constraints || 'num_bands'::text;
		END IF;

		IF pixel_types IS TRUE THEN
			constraints := constraints || 'pixel_types'::text;
		END IF;

		IF nodata_values IS TRUE THEN
			constraints := constraints || 'nodata_values'::text;
		END IF;

		IF out_db IS TRUE THEN
			constraints := constraints || 'out_db'::text;
		END IF;

		IF extent IS TRUE THEN
			constraints := constraints || 'extent'::text;
		END IF;

		RETURN DropRasterConstraints($1, $2, $3, VARIADIC constraints);
	END;
	$_$;


ALTER FUNCTION public.droprasterconstraints(rastschema name, rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean) OWNER TO postgres;

--
-- Name: FUNCTION droprasterconstraints(rastschema name, rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION droprasterconstraints(rastschema name, rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean) IS 'args: rastschema, rasttable, rastcolumn, srid=true, scale_x=true, scale_y=true, blocksize_x=true, blocksize_y=true, same_alignment=true, regular_blocking=true, num_bands=true, pixel_types=true, nodata_values=true, out_db=true, extent=true - Drops PostGIS raster constraints that refer to a raster table column. Useful if you need to reload data or update your raster column data.';


--
-- Name: enablelongtransactions(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION enablelongtransactions() RETURNS text
    LANGUAGE plpgsql
    AS $$ 
DECLARE
	"query" text;
	exists bool;
	rec RECORD;

BEGIN

	exists = 'f';
	FOR rec IN SELECT * FROM pg_class WHERE relname = 'authorization_table'
	LOOP
		exists = 't';
	END LOOP;

	IF NOT exists
	THEN
		"query" = 'CREATE TABLE authorization_table (
			toid oid, -- table oid
			rid text, -- row id
			expires timestamp,
			authid text
		)';
		EXECUTE "query";
	END IF;

	exists = 'f';
	FOR rec IN SELECT * FROM pg_class WHERE relname = 'authorized_tables'
	LOOP
		exists = 't';
	END LOOP;

	IF NOT exists THEN
		"query" = 'CREATE VIEW authorized_tables AS ' ||
			'SELECT ' ||
			'n.nspname as schema, ' ||
			'c.relname as table, trim(' ||
			quote_literal(chr(92) || '000') ||
			' from t.tgargs) as id_column ' ||
			'FROM pg_trigger t, pg_class c, pg_proc p ' ||
			', pg_namespace n ' ||
			'WHERE p.proname = ' || quote_literal('checkauthtrigger') ||
			' AND c.relnamespace = n.oid' ||
			' AND t.tgfoid = p.oid and t.tgrelid = c.oid';
		EXECUTE "query";
	END IF;

	RETURN 'Long transactions support enabled';
END;
$$;


ALTER FUNCTION public.enablelongtransactions() OWNER TO postgres;

--
-- Name: find_srid(character varying, character varying, character varying); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION find_srid(character varying, character varying, character varying) RETURNS integer
    LANGUAGE plpgsql IMMUTABLE STRICT
    AS $_$
DECLARE
	schem text;
	tabl text;
	sr int4;
BEGIN
	IF $1 IS NULL THEN
	  RAISE EXCEPTION 'find_srid() - schema is NULL!';
	END IF;
	IF $2 IS NULL THEN
	  RAISE EXCEPTION 'find_srid() - table name is NULL!';
	END IF;
	IF $3 IS NULL THEN
	  RAISE EXCEPTION 'find_srid() - column name is NULL!';
	END IF;
	schem = $1;
	tabl = $2;
-- if the table contains a . and the schema is empty
-- split the table into a schema and a table
-- otherwise drop through to default behavior
	IF ( schem = '' and tabl LIKE '%.%' ) THEN
	 schem = substr(tabl,1,strpos(tabl,'.')-1);
	 tabl = substr(tabl,length(schem)+2);
	ELSE
	 schem = schem || '%';
	END IF;

	select SRID into sr from geometry_columns where f_table_schema like schem and f_table_name = tabl and f_geometry_column = $3;
	IF NOT FOUND THEN
	   RAISE EXCEPTION 'find_srid() - couldnt find the corresponding SRID - is the geometry registered in the GEOMETRY_COLUMNS table?  Is there an uppercase/lowercase missmatch?';
	END IF;
	return sr;
END;
$_$;


ALTER FUNCTION public.find_srid(character varying, character varying, character varying) OWNER TO postgres;

--
-- Name: get_proj4_from_srid(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION get_proj4_from_srid(integer) RETURNS text
    LANGUAGE plpgsql IMMUTABLE STRICT
    AS $_$
BEGIN
	RETURN proj4text::text FROM spatial_ref_sys WHERE srid= $1;
END;
$_$;


ALTER FUNCTION public.get_proj4_from_srid(integer) OWNER TO postgres;

--
-- Name: lockrow(text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lockrow(text, text, text) RETURNS integer
    LANGUAGE sql STRICT
    AS $_$ SELECT LockRow(current_schema(), $1, $2, $3, now()::timestamp+'1:00'); $_$;


ALTER FUNCTION public.lockrow(text, text, text) OWNER TO postgres;

--
-- Name: lockrow(text, text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lockrow(text, text, text, text) RETURNS integer
    LANGUAGE sql STRICT
    AS $_$ SELECT LockRow($1, $2, $3, $4, now()::timestamp+'1:00'); $_$;


ALTER FUNCTION public.lockrow(text, text, text, text) OWNER TO postgres;

--
-- Name: lockrow(text, text, text, timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lockrow(text, text, text, timestamp without time zone) RETURNS integer
    LANGUAGE sql STRICT
    AS $_$ SELECT LockRow(current_schema(), $1, $2, $3, $4); $_$;


ALTER FUNCTION public.lockrow(text, text, text, timestamp without time zone) OWNER TO postgres;

--
-- Name: lockrow(text, text, text, text, timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lockrow(text, text, text, text, timestamp without time zone) RETURNS integer
    LANGUAGE plpgsql STRICT
    AS $_$ 
DECLARE
	myschema alias for $1;
	mytable alias for $2;
	myrid   alias for $3;
	authid alias for $4;
	expires alias for $5;
	ret int;
	mytoid oid;
	myrec RECORD;
	
BEGIN

	IF NOT LongTransactionsEnabled() THEN
		RAISE EXCEPTION 'Long transaction support disabled, use EnableLongTransaction() to enable.';
	END IF;

	EXECUTE 'DELETE FROM authorization_table WHERE expires < now()'; 

	SELECT c.oid INTO mytoid FROM pg_class c, pg_namespace n
		WHERE c.relname = mytable
		AND c.relnamespace = n.oid
		AND n.nspname = myschema;

	-- RAISE NOTICE 'toid: %', mytoid;

	FOR myrec IN SELECT * FROM authorization_table WHERE 
		toid = mytoid AND rid = myrid
	LOOP
		IF myrec.authid != authid THEN
			RETURN 0;
		ELSE
			RETURN 1;
		END IF;
	END LOOP;

	EXECUTE 'INSERT INTO authorization_table VALUES ('||
		quote_literal(mytoid::text)||','||quote_literal(myrid)||
		','||quote_literal(expires::text)||
		','||quote_literal(authid) ||')';

	GET DIAGNOSTICS ret = ROW_COUNT;

	RETURN ret;
END;
$_$;


ALTER FUNCTION public.lockrow(text, text, text, text, timestamp without time zone) OWNER TO postgres;

--
-- Name: longtransactionsenabled(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION longtransactionsenabled() RETURNS boolean
    LANGUAGE plpgsql
    AS $$ 
DECLARE
	rec RECORD;
BEGIN
	FOR rec IN SELECT oid FROM pg_class WHERE relname = 'authorized_tables'
	LOOP
		return 't';
	END LOOP;
	return 'f';
END;
$$;


ALTER FUNCTION public.longtransactionsenabled() OWNER TO postgres;

--
-- Name: populate_geometry_columns(boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION populate_geometry_columns(use_typmod boolean DEFAULT true) RETURNS text
    LANGUAGE plpgsql
    AS $$
DECLARE
	inserted    integer;
	oldcount    integer;
	probed      integer;
	stale       integer;
	gcs         RECORD;
	gc          RECORD;
	gsrid       integer;
	gndims      integer;
	gtype       text;
	query       text;
	gc_is_valid boolean;

BEGIN
	SELECT count(*) INTO oldcount FROM geometry_columns;
	inserted := 0;

	-- Count the number of geometry columns in all tables and views
	SELECT count(DISTINCT c.oid) INTO probed
	FROM pg_class c,
		 pg_attribute a,
		 pg_type t,
		 pg_namespace n
	WHERE (c.relkind = 'r' OR c.relkind = 'v')
		AND t.typname = 'geometry'
		AND a.attisdropped = false
		AND a.atttypid = t.oid
		AND a.attrelid = c.oid
		AND c.relnamespace = n.oid
		AND n.nspname NOT ILIKE 'pg_temp%' AND c.relname != 'raster_columns' ;

	-- Iterate through all non-dropped geometry columns
	RAISE DEBUG 'Processing Tables.....';

	FOR gcs IN
	SELECT DISTINCT ON (c.oid) c.oid, n.nspname, c.relname
		FROM pg_class c,
			 pg_attribute a,
			 pg_type t,
			 pg_namespace n
		WHERE c.relkind = 'r'
		AND t.typname = 'geometry'
		AND a.attisdropped = false
		AND a.atttypid = t.oid
		AND a.attrelid = c.oid
		AND c.relnamespace = n.oid
		AND n.nspname NOT ILIKE 'pg_temp%' AND c.relname != 'raster_columns' 
	LOOP

		inserted := inserted + populate_geometry_columns(gcs.oid, use_typmod);
	END LOOP;

	IF oldcount > inserted THEN
	    stale = oldcount-inserted;
	ELSE
	    stale = 0;
	END IF;

	RETURN 'probed:' ||probed|| ' inserted:'||inserted;
END

$$;


ALTER FUNCTION public.populate_geometry_columns(use_typmod boolean) OWNER TO postgres;

--
-- Name: populate_geometry_columns(oid, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION populate_geometry_columns(tbl_oid oid, use_typmod boolean DEFAULT true) RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
	gcs         RECORD;
	gc          RECORD;
	gc_old      RECORD;
	gsrid       integer;
	gndims      integer;
	gtype       text;
	query       text;
	gc_is_valid boolean;
	inserted    integer;
	constraint_successful boolean := false;

BEGIN
	inserted := 0;

	-- Iterate through all geometry columns in this table
	FOR gcs IN
	SELECT n.nspname, c.relname, a.attname
		FROM pg_class c,
			 pg_attribute a,
			 pg_type t,
			 pg_namespace n
		WHERE c.relkind = 'r'
		AND t.typname = 'geometry'
		AND a.attisdropped = false
		AND a.atttypid = t.oid
		AND a.attrelid = c.oid
		AND c.relnamespace = n.oid
		AND n.nspname NOT ILIKE 'pg_temp%'
		AND c.oid = tbl_oid
	LOOP

        RAISE DEBUG 'Processing table %.%.%', gcs.nspname, gcs.relname, gcs.attname;
    
        gc_is_valid := true;
        -- Find the srid, coord_dimension, and type of current geometry
        -- in geometry_columns -- which is now a view
        
        SELECT type, srid, coord_dimension INTO gc_old 
            FROM geometry_columns 
            WHERE f_table_schema = gcs.nspname AND f_table_name = gcs.relname AND f_geometry_column = gcs.attname; 
            
        IF upper(gc_old.type) = 'GEOMETRY' THEN
        -- This is an unconstrained geometry we need to do something
        -- We need to figure out what to set the type by inspecting the data
            EXECUTE 'SELECT st_srid(' || quote_ident(gcs.attname) || ') As srid, GeometryType(' || quote_ident(gcs.attname) || ') As type, ST_NDims(' || quote_ident(gcs.attname) || ') As dims ' ||
                     ' FROM ONLY ' || quote_ident(gcs.nspname) || '.' || quote_ident(gcs.relname) || 
                     ' WHERE ' || quote_ident(gcs.attname) || ' IS NOT NULL LIMIT 1;'
                INTO gc;
            IF gc IS NULL THEN -- there is no data so we can not determine geometry type
            	RAISE WARNING 'No data in table %.%, so no information to determine geometry type and srid', gcs.nspname, gcs.relname;
            	RETURN 0;
            END IF;
            gsrid := gc.srid; gtype := gc.type; gndims := gc.dims;
            	
            IF use_typmod THEN
                BEGIN
                    EXECUTE 'ALTER TABLE ' || quote_ident(gcs.nspname) || '.' || quote_ident(gcs.relname) || ' ALTER COLUMN ' || quote_ident(gcs.attname) || 
                        ' TYPE geometry(' || postgis_type_name(gtype, gndims, true) || ', ' || gsrid::text  || ') ';
                    inserted := inserted + 1;
                EXCEPTION
                        WHEN invalid_parameter_value THEN
                        RAISE WARNING 'Could not convert ''%'' in ''%.%'' to use typmod with srid %, type: % ', quote_ident(gcs.attname), quote_ident(gcs.nspname), quote_ident(gcs.relname), gsrid, postgis_type_name(gtype, gndims, true);
                            gc_is_valid := false;
                END;
                
            ELSE
                -- Try to apply srid check to column
            	constraint_successful = false;
                IF (gsrid > 0 AND postgis_constraint_srid(gcs.nspname, gcs.relname,gcs.attname) IS NULL ) THEN
                    BEGIN
                        EXECUTE 'ALTER TABLE ONLY ' || quote_ident(gcs.nspname) || '.' || quote_ident(gcs.relname) || 
                                 ' ADD CONSTRAINT ' || quote_ident('enforce_srid_' || gcs.attname) || 
                                 ' CHECK (st_srid(' || quote_ident(gcs.attname) || ') = ' || gsrid || ')';
                        constraint_successful := true;
                    EXCEPTION
                        WHEN check_violation THEN
                            RAISE WARNING 'Not inserting ''%'' in ''%.%'' into geometry_columns: could not apply constraint CHECK (st_srid(%) = %)', quote_ident(gcs.attname), quote_ident(gcs.nspname), quote_ident(gcs.relname), quote_ident(gcs.attname), gsrid;
                            gc_is_valid := false;
                    END;
                END IF;
                
                -- Try to apply ndims check to column
                IF (gndims IS NOT NULL AND postgis_constraint_dims(gcs.nspname, gcs.relname,gcs.attname) IS NULL ) THEN
                    BEGIN
                        EXECUTE 'ALTER TABLE ONLY ' || quote_ident(gcs.nspname) || '.' || quote_ident(gcs.relname) || '
                                 ADD CONSTRAINT ' || quote_ident('enforce_dims_' || gcs.attname) || '
                                 CHECK (st_ndims(' || quote_ident(gcs.attname) || ') = '||gndims||')';
                        constraint_successful := true;
                    EXCEPTION
                        WHEN check_violation THEN
                            RAISE WARNING 'Not inserting ''%'' in ''%.%'' into geometry_columns: could not apply constraint CHECK (st_ndims(%) = %)', quote_ident(gcs.attname), quote_ident(gcs.nspname), quote_ident(gcs.relname), quote_ident(gcs.attname), gndims;
                            gc_is_valid := false;
                    END;
                END IF;
    
                -- Try to apply geometrytype check to column
                IF (gtype IS NOT NULL AND postgis_constraint_type(gcs.nspname, gcs.relname,gcs.attname) IS NULL ) THEN
                    BEGIN
                        EXECUTE 'ALTER TABLE ONLY ' || quote_ident(gcs.nspname) || '.' || quote_ident(gcs.relname) || '
                        ADD CONSTRAINT ' || quote_ident('enforce_geotype_' || gcs.attname) || '
                        CHECK ((geometrytype(' || quote_ident(gcs.attname) || ') = ' || quote_literal(gtype) || ') OR (' || quote_ident(gcs.attname) || ' IS NULL))';
                        constraint_successful := true;
                    EXCEPTION
                        WHEN check_violation THEN
                            -- No geometry check can be applied. This column contains a number of geometry types.
                            RAISE WARNING 'Could not add geometry type check (%) to table column: %.%.%', gtype, quote_ident(gcs.nspname),quote_ident(gcs.relname),quote_ident(gcs.attname);
                    END;
                END IF;
                 --only count if we were successful in applying at least one constraint
                IF constraint_successful THEN
                	inserted := inserted + 1;
                END IF;
            END IF;	        
	    END IF;

	END LOOP;

	RETURN inserted;
END

$$;


ALTER FUNCTION public.populate_geometry_columns(tbl_oid oid, use_typmod boolean) OWNER TO postgres;

--
-- Name: postgis_constraint_dims(text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION postgis_constraint_dims(geomschema text, geomtable text, geomcolumn text) RETURNS integer
    LANGUAGE sql STABLE STRICT
    AS $_$
SELECT  replace(split_part(s.consrc, ' = ', 2), ')', '')::integer
		 FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
		 WHERE n.nspname = $1
		 AND c.relname = $2
		 AND a.attname = $3
		 AND a.attrelid = c.oid
		 AND s.connamespace = n.oid
		 AND s.conrelid = c.oid
		 AND a.attnum = ANY (s.conkey)
		 AND s.consrc LIKE '%ndims(% = %';
$_$;


ALTER FUNCTION public.postgis_constraint_dims(geomschema text, geomtable text, geomcolumn text) OWNER TO postgres;

--
-- Name: postgis_constraint_srid(text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION postgis_constraint_srid(geomschema text, geomtable text, geomcolumn text) RETURNS integer
    LANGUAGE sql STABLE STRICT
    AS $_$
SELECT replace(replace(split_part(s.consrc, ' = ', 2), ')', ''), '(', '')::integer
		 FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
		 WHERE n.nspname = $1
		 AND c.relname = $2
		 AND a.attname = $3
		 AND a.attrelid = c.oid
		 AND s.connamespace = n.oid
		 AND s.conrelid = c.oid
		 AND a.attnum = ANY (s.conkey)
		 AND s.consrc LIKE '%srid(% = %';
$_$;


ALTER FUNCTION public.postgis_constraint_srid(geomschema text, geomtable text, geomcolumn text) OWNER TO postgres;

--
-- Name: postgis_constraint_type(text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION postgis_constraint_type(geomschema text, geomtable text, geomcolumn text) RETURNS character varying
    LANGUAGE sql STABLE STRICT
    AS $_$
SELECT  replace(split_part(s.consrc, '''', 2), ')', '')::varchar		
		 FROM pg_class c, pg_namespace n, pg_attribute a, pg_constraint s
		 WHERE n.nspname = $1
		 AND c.relname = $2
		 AND a.attname = $3
		 AND a.attrelid = c.oid
		 AND s.connamespace = n.oid
		 AND s.conrelid = c.oid
		 AND a.attnum = ANY (s.conkey)
		 AND s.consrc LIKE '%geometrytype(% = %';
$_$;


ALTER FUNCTION public.postgis_constraint_type(geomschema text, geomtable text, geomcolumn text) OWNER TO postgres;

--
-- Name: postgis_full_version(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION postgis_full_version() RETURNS text
    LANGUAGE plpgsql IMMUTABLE
    AS $$
DECLARE
	libver text;
	svnver text;
	projver text;
	geosver text;
	gdalver text;
	libxmlver text;
	dbproc text;
	relproc text;
	fullver text;
	rast_lib_ver text;
	rast_scr_ver text;
	topo_scr_ver text;
	json_lib_ver text;
BEGIN
	SELECT postgis_lib_version() INTO libver;
	SELECT postgis_proj_version() INTO projver;
	SELECT postgis_geos_version() INTO geosver;
	SELECT postgis_libjson_version() INTO json_lib_ver;
	BEGIN
		SELECT postgis_gdal_version() INTO gdalver;
	EXCEPTION
		WHEN undefined_function THEN
			gdalver := NULL;
			RAISE NOTICE 'Function postgis_gdal_version() not found.  Is raster support enabled and rtpostgis.sql installed?';
	END;
	SELECT postgis_libxml_version() INTO libxmlver;
	SELECT postgis_scripts_installed() INTO dbproc;
	SELECT postgis_scripts_released() INTO relproc;
	select postgis_svn_version() INTO svnver;
	BEGIN
		SELECT postgis_topology_scripts_installed() INTO topo_scr_ver;
	EXCEPTION
		WHEN undefined_function THEN
			topo_scr_ver := NULL;
			RAISE NOTICE 'Function postgis_topology_scripts_installed() not found. Is topology support enabled and topology.sql installed?';
	END;

	BEGIN
		SELECT postgis_raster_scripts_installed() INTO rast_scr_ver;
	EXCEPTION
		WHEN undefined_function THEN
			rast_scr_ver := NULL;
			RAISE NOTICE 'Function postgis_raster_scripts_installed() not found. Is raster support enabled and rtpostgis.sql installed?';
	END;

	BEGIN
		SELECT postgis_raster_lib_version() INTO rast_lib_ver;
	EXCEPTION
		WHEN undefined_function THEN
			rast_lib_ver := NULL;
			RAISE NOTICE 'Function postgis_raster_lib_version() not found. Is raster support enabled and rtpostgis.sql installed?';
	END;

	fullver = 'POSTGIS="' || libver;

	IF  svnver IS NOT NULL THEN
		fullver = fullver || ' r' || svnver;
	END IF;

	fullver = fullver || '"';

	IF  geosver IS NOT NULL THEN
		fullver = fullver || ' GEOS="' || geosver || '"';
	END IF;

	IF  projver IS NOT NULL THEN
		fullver = fullver || ' PROJ="' || projver || '"';
	END IF;

	IF  gdalver IS NOT NULL THEN
		fullver = fullver || ' GDAL="' || gdalver || '"';
	END IF;

	IF  libxmlver IS NOT NULL THEN
		fullver = fullver || ' LIBXML="' || libxmlver || '"';
	END IF;

	IF json_lib_ver IS NOT NULL THEN
		fullver = fullver || ' LIBJSON="' || json_lib_ver || '"';
	END IF;

	-- fullver = fullver || ' DBPROC="' || dbproc || '"';
	-- fullver = fullver || ' RELPROC="' || relproc || '"';

	IF dbproc != relproc THEN
		fullver = fullver || ' (core procs from "' || dbproc || '" need upgrade)';
	END IF;

	IF topo_scr_ver IS NOT NULL THEN
		fullver = fullver || ' TOPOLOGY';
		IF topo_scr_ver != relproc THEN
			fullver = fullver || ' (topology procs from "' || topo_scr_ver || '" need upgrade)';
		END IF;
	END IF;

	IF rast_lib_ver IS NOT NULL THEN
		fullver = fullver || ' RASTER';
		IF rast_lib_ver != relproc THEN
			fullver = fullver || ' (raster lib from "' || rast_lib_ver || '" need upgrade)';
		END IF;
	END IF;

	IF rast_scr_ver IS NOT NULL AND rast_scr_ver != relproc THEN
		fullver = fullver || ' (raster procs from "' || rast_scr_ver || '" need upgrade)';
	END IF;

	RETURN fullver;
END
$$;


ALTER FUNCTION public.postgis_full_version() OWNER TO postgres;

--
-- Name: postgis_raster_scripts_installed(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION postgis_raster_scripts_installed() RETURNS text
    LANGUAGE sql IMMUTABLE
    AS $$ SELECT '2.0.1'::text || ' r' || 9979::text AS version $$;


ALTER FUNCTION public.postgis_raster_scripts_installed() OWNER TO postgres;

--
-- Name: postgis_scripts_build_date(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION postgis_scripts_build_date() RETURNS text
    LANGUAGE sql IMMUTABLE
    AS $$SELECT '2012-11-16 18:39:39'::text AS version$$;


ALTER FUNCTION public.postgis_scripts_build_date() OWNER TO postgres;

--
-- Name: postgis_scripts_installed(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION postgis_scripts_installed() RETURNS text
    LANGUAGE sql IMMUTABLE
    AS $$ SELECT '2.0.1'::text || ' r' || 9979::text AS version $$;


ALTER FUNCTION public.postgis_scripts_installed() OWNER TO postgres;

--
-- Name: postgis_topology_scripts_installed(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION postgis_topology_scripts_installed() RETURNS text
    LANGUAGE sql IMMUTABLE
    AS $$ SELECT '2.0.1'::text || ' r' || 9979::text AS version $$;


ALTER FUNCTION public.postgis_topology_scripts_installed() OWNER TO postgres;

--
-- Name: postgis_type_name(character varying, integer, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION postgis_type_name(geomname character varying, coord_dimension integer, use_new_name boolean DEFAULT true) RETURNS character varying
    LANGUAGE sql IMMUTABLE STRICT COST 200
    AS $_$
 SELECT CASE WHEN $3 THEN new_name ELSE old_name END As geomname
 	FROM 
 	( VALUES
 		 ('GEOMETRY', 'Geometry', 2) ,
 		 	('GEOMETRY', 'GeometryZ', 3) ,
 		 	('GEOMETRY', 'GeometryZM', 4) ,
			('GEOMETRYCOLLECTION', 'GeometryCollection', 2) ,
			('GEOMETRYCOLLECTION', 'GeometryCollectionZ', 3) ,
			('GEOMETRYCOLLECTIONM', 'GeometryCollectionM', 3) ,
			('GEOMETRYCOLLECTION', 'GeometryCollectionZM', 4) ,
			
			('POINT', 'Point',2) ,
			('POINTM','PointM',3) ,
			('POINT', 'PointZ',3) ,
			('POINT', 'PointZM',4) ,
			
			('MULTIPOINT','MultiPoint',2) ,
			('MULTIPOINT','MultiPointZ',3) ,
			('MULTIPOINTM','MultiPointM',3) ,
			('MULTIPOINT','MultiPointZM',4) ,
			
			('POLYGON', 'Polygon',2) ,
			('POLYGON', 'PolygonZ',3) ,
			('POLYGONM', 'PolygonM',3) ,
			('POLYGON', 'PolygonZM',4) ,
			
			('MULTIPOLYGON', 'MultiPolygon',2) ,
			('MULTIPOLYGON', 'MultiPolygonZ',3) ,
			('MULTIPOLYGONM', 'MultiPolygonM',3) ,
			('MULTIPOLYGON', 'MultiPolygonZM',4) ,
			
			('MULTILINESTRING', 'MultiLineString',2) ,
			('MULTILINESTRING', 'MultiLineStringZ',3) ,
			('MULTILINESTRINGM', 'MultiLineStringM',3) ,
			('MULTILINESTRING', 'MultiLineStringZM',4) ,
			
			('LINESTRING', 'LineString',2) ,
			('LINESTRING', 'LineStringZ',3) ,
			('LINESTRINGM', 'LineStringM',3) ,
			('LINESTRING', 'LineStringZM',4) ,
			
			('CIRCULARSTRING', 'CircularString',2) ,
			('CIRCULARSTRING', 'CircularStringZ',3) ,
			('CIRCULARSTRINGM', 'CircularStringM',3) ,
			('CIRCULARSTRING', 'CircularStringZM',4) ,
			
			('COMPOUNDCURVE', 'CompoundCurve',2) ,
			('COMPOUNDCURVE', 'CompoundCurveZ',3) ,
			('COMPOUNDCURVEM', 'CompoundCurveM',3) ,
			('COMPOUNDCURVE', 'CompoundCurveZM',4) ,
			
			('CURVEPOLYGON', 'CurvePolygon',2) ,
			('CURVEPOLYGON', 'CurvePolygonZ',3) ,
			('CURVEPOLYGONM', 'CurvePolygonM',3) ,
			('CURVEPOLYGON', 'CurvePolygonZM',4) ,
			
			('MULTICURVE', 'MultiCurve',2 ) ,
			('MULTICURVE', 'MultiCurveZ',3 ) ,
			('MULTICURVEM', 'MultiCurveM',3 ) ,
			('MULTICURVE', 'MultiCurveZM',4 ) ,
			
			('MULTISURFACE', 'MultiSurface', 2) ,
			('MULTISURFACE', 'MultiSurfaceZ', 3) ,
			('MULTISURFACEM', 'MultiSurfaceM', 3) ,
			('MULTISURFACE', 'MultiSurfaceZM', 4) ,
			
			('POLYHEDRALSURFACE', 'PolyhedralSurface',2) ,
			('POLYHEDRALSURFACE', 'PolyhedralSurfaceZ',3) ,
			('POLYHEDRALSURFACEM', 'PolyhedralSurfaceM',3) ,
			('POLYHEDRALSURFACE', 'PolyhedralSurfaceZM',4) ,
			
			('TRIANGLE', 'Triangle',2) ,
			('TRIANGLE', 'TriangleZ',3) ,
			('TRIANGLEM', 'TriangleM',3) ,
			('TRIANGLE', 'TriangleZM',4) ,

			('TIN', 'Tin', 2),
			('TIN', 'TinZ', 3),
			('TIN', 'TinM', 3),
			('TIN', 'TinZM', 4) )
			 As g(old_name, new_name, coord_dimension)
		WHERE (upper(old_name) = upper($1) OR upper(new_name) = upper($1))
			AND coord_dimension = $2;
$_$;


ALTER FUNCTION public.postgis_type_name(geomname character varying, coord_dimension integer, use_new_name boolean) OWNER TO postgres;

--
-- Name: st_approxcount(text, text, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxcount(rastertable text, rastercolumn text, sample_percent double precision) RETURNS bigint
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_count($1, $2, 1, TRUE, $3) $_$;


ALTER FUNCTION public.st_approxcount(rastertable text, rastercolumn text, sample_percent double precision) OWNER TO postgres;

--
-- Name: st_approxcount(text, text, boolean, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxcount(rastertable text, rastercolumn text, exclude_nodata_value boolean, sample_percent double precision DEFAULT 0.1) RETURNS bigint
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_count($1, $2, 1, $3, $4) $_$;


ALTER FUNCTION public.st_approxcount(rastertable text, rastercolumn text, exclude_nodata_value boolean, sample_percent double precision) OWNER TO postgres;

--
-- Name: st_approxcount(text, text, integer, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxcount(rastertable text, rastercolumn text, nband integer, sample_percent double precision) RETURNS bigint
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_count($1, $2, $3, TRUE, $4) $_$;


ALTER FUNCTION public.st_approxcount(rastertable text, rastercolumn text, nband integer, sample_percent double precision) OWNER TO postgres;

--
-- Name: st_approxcount(text, text, integer, boolean, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxcount(rastertable text, rastercolumn text, nband integer DEFAULT 1, exclude_nodata_value boolean DEFAULT true, sample_percent double precision DEFAULT 0.1) RETURNS bigint
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_count($1, $2, $3, $4, $5) $_$;


ALTER FUNCTION public.st_approxcount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision) OWNER TO postgres;

--
-- Name: st_approxhistogram(text, text, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxhistogram(rastertable text, rastercolumn text, sample_percent double precision) RETURNS SETOF histogram
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_histogram($1, $2, 1, TRUE, $3, 0, NULL, FALSE) $_$;


ALTER FUNCTION public.st_approxhistogram(rastertable text, rastercolumn text, sample_percent double precision) OWNER TO postgres;

--
-- Name: st_approxhistogram(text, text, integer, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxhistogram(rastertable text, rastercolumn text, nband integer, sample_percent double precision) RETURNS SETOF histogram
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_histogram($1, $2, $3, TRUE, $4, 0, NULL, FALSE) $_$;


ALTER FUNCTION public.st_approxhistogram(rastertable text, rastercolumn text, nband integer, sample_percent double precision) OWNER TO postgres;

--
-- Name: st_approxhistogram(text, text, integer, double precision, integer, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxhistogram(rastertable text, rastercolumn text, nband integer, sample_percent double precision, bins integer, "right" boolean) RETURNS SETOF histogram
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_histogram($1, $2, $3, TRUE, $4, $5, NULL, $6) $_$;


ALTER FUNCTION public.st_approxhistogram(rastertable text, rastercolumn text, nband integer, sample_percent double precision, bins integer, "right" boolean) OWNER TO postgres;

--
-- Name: st_approxhistogram(text, text, integer, boolean, double precision, integer, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxhistogram(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision, bins integer, "right" boolean) RETURNS SETOF histogram
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_histogram($1, $2, $3, $4, $5, $6, NULL, $7) $_$;


ALTER FUNCTION public.st_approxhistogram(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision, bins integer, "right" boolean) OWNER TO postgres;

--
-- Name: st_approxhistogram(text, text, integer, double precision, integer, double precision[], boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxhistogram(rastertable text, rastercolumn text, nband integer, sample_percent double precision, bins integer, width double precision[] DEFAULT NULL::double precision[], "right" boolean DEFAULT false) RETURNS SETOF histogram
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_histogram($1, $2, $3, TRUE, $4, $5, $6, $7) $_$;


ALTER FUNCTION public.st_approxhistogram(rastertable text, rastercolumn text, nband integer, sample_percent double precision, bins integer, width double precision[], "right" boolean) OWNER TO postgres;

--
-- Name: st_approxhistogram(text, text, integer, boolean, double precision, integer, double precision[], boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxhistogram(rastertable text, rastercolumn text, nband integer DEFAULT 1, exclude_nodata_value boolean DEFAULT true, sample_percent double precision DEFAULT 0.1, bins integer DEFAULT 0, width double precision[] DEFAULT NULL::double precision[], "right" boolean DEFAULT false) RETURNS SETOF histogram
    LANGUAGE sql STABLE
    AS $_$ SELECT _st_histogram($1, $2, $3, $4, $5, $6, $7, $8) $_$;


ALTER FUNCTION public.st_approxhistogram(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision, bins integer, width double precision[], "right" boolean) OWNER TO postgres;

--
-- Name: st_approxquantile(text, text, double precision[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxquantile(rastertable text, rastercolumn text, quantiles double precision[]) RETURNS SETOF quantile
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_quantile($1, $2, 1, TRUE, 0.1, $3) $_$;


ALTER FUNCTION public.st_approxquantile(rastertable text, rastercolumn text, quantiles double precision[]) OWNER TO postgres;

--
-- Name: st_approxquantile(text, text, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxquantile(rastertable text, rastercolumn text, quantile double precision) RETURNS double precision
    LANGUAGE sql STABLE
    AS $_$ SELECT (_st_quantile($1, $2, 1, TRUE, 0.1, ARRAY[$3]::double precision[])).value $_$;


ALTER FUNCTION public.st_approxquantile(rastertable text, rastercolumn text, quantile double precision) OWNER TO postgres;

--
-- Name: st_approxquantile(text, text, boolean, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxquantile(rastertable text, rastercolumn text, exclude_nodata_value boolean, quantile double precision DEFAULT NULL::double precision) RETURNS double precision
    LANGUAGE sql STABLE
    AS $_$ SELECT (_st_quantile($1, $2, 1, $3, 0.1, ARRAY[$4]::double precision[])).value $_$;


ALTER FUNCTION public.st_approxquantile(rastertable text, rastercolumn text, exclude_nodata_value boolean, quantile double precision) OWNER TO postgres;

--
-- Name: st_approxquantile(text, text, double precision, double precision[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxquantile(rastertable text, rastercolumn text, sample_percent double precision, quantiles double precision[] DEFAULT NULL::double precision[]) RETURNS SETOF quantile
    LANGUAGE sql STABLE
    AS $_$ SELECT _st_quantile($1, $2, 1, TRUE, $3, $4) $_$;


ALTER FUNCTION public.st_approxquantile(rastertable text, rastercolumn text, sample_percent double precision, quantiles double precision[]) OWNER TO postgres;

--
-- Name: st_approxquantile(text, text, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxquantile(rastertable text, rastercolumn text, sample_percent double precision, quantile double precision) RETURNS double precision
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_quantile($1, $2, 1, TRUE, $3, ARRAY[$4]::double precision[])).value $_$;


ALTER FUNCTION public.st_approxquantile(rastertable text, rastercolumn text, sample_percent double precision, quantile double precision) OWNER TO postgres;

--
-- Name: st_approxquantile(text, text, integer, double precision, double precision[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxquantile(rastertable text, rastercolumn text, nband integer, sample_percent double precision, quantiles double precision[] DEFAULT NULL::double precision[]) RETURNS SETOF quantile
    LANGUAGE sql STABLE
    AS $_$ SELECT _st_quantile($1, $2, $3, TRUE, $4, $5) $_$;


ALTER FUNCTION public.st_approxquantile(rastertable text, rastercolumn text, nband integer, sample_percent double precision, quantiles double precision[]) OWNER TO postgres;

--
-- Name: st_approxquantile(text, text, integer, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxquantile(rastertable text, rastercolumn text, nband integer, sample_percent double precision, quantile double precision) RETURNS double precision
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_quantile($1, $2, $3, TRUE, $4, ARRAY[$5]::double precision[])).value $_$;


ALTER FUNCTION public.st_approxquantile(rastertable text, rastercolumn text, nband integer, sample_percent double precision, quantile double precision) OWNER TO postgres;

--
-- Name: st_approxquantile(text, text, integer, boolean, double precision, double precision[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxquantile(rastertable text, rastercolumn text, nband integer DEFAULT 1, exclude_nodata_value boolean DEFAULT true, sample_percent double precision DEFAULT 0.1, quantiles double precision[] DEFAULT NULL::double precision[]) RETURNS SETOF quantile
    LANGUAGE sql STABLE
    AS $_$ SELECT _st_quantile($1, $2, $3, $4, $5, $6) $_$;


ALTER FUNCTION public.st_approxquantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision, quantiles double precision[]) OWNER TO postgres;

--
-- Name: st_approxquantile(text, text, integer, boolean, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxquantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision, quantile double precision) RETURNS double precision
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_quantile($1, $2, $3, $4, $5, ARRAY[$6]::double precision[])).value $_$;


ALTER FUNCTION public.st_approxquantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision, quantile double precision) OWNER TO postgres;

--
-- Name: st_approxsummarystats(text, text, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxsummarystats(rastertable text, rastercolumn text, exclude_nodata_value boolean) RETURNS summarystats
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_summarystats($1, $2, 1, $3, 0.1) $_$;


ALTER FUNCTION public.st_approxsummarystats(rastertable text, rastercolumn text, exclude_nodata_value boolean) OWNER TO postgres;

--
-- Name: st_approxsummarystats(text, text, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxsummarystats(rastertable text, rastercolumn text, sample_percent double precision) RETURNS summarystats
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_summarystats($1, $2, 1, TRUE, $3) $_$;


ALTER FUNCTION public.st_approxsummarystats(rastertable text, rastercolumn text, sample_percent double precision) OWNER TO postgres;

--
-- Name: st_approxsummarystats(text, text, integer, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxsummarystats(rastertable text, rastercolumn text, nband integer, sample_percent double precision) RETURNS summarystats
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_summarystats($1, $2, $3, TRUE, $4) $_$;


ALTER FUNCTION public.st_approxsummarystats(rastertable text, rastercolumn text, nband integer, sample_percent double precision) OWNER TO postgres;

--
-- Name: st_approxsummarystats(text, text, integer, boolean, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_approxsummarystats(rastertable text, rastercolumn text, nband integer DEFAULT 1, exclude_nodata_value boolean DEFAULT true, sample_percent double precision DEFAULT 0.1) RETURNS summarystats
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_summarystats($1, $2, $3, $4, $5) $_$;


ALTER FUNCTION public.st_approxsummarystats(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision) OWNER TO postgres;

--
-- Name: st_area(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_area(text) RETURNS double precision
    LANGUAGE sql IMMUTABLE STRICT
    AS $_$ SELECT ST_Area($1::geometry);  $_$;


ALTER FUNCTION public.st_area(text) OWNER TO postgres;

--
-- Name: st_asewkt(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_asewkt(text) RETURNS text
    LANGUAGE sql IMMUTABLE STRICT
    AS $_$ SELECT ST_AsEWKT($1::geometry);  $_$;


ALTER FUNCTION public.st_asewkt(text) OWNER TO postgres;

--
-- Name: st_asgeojson(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_asgeojson(text) RETURNS text
    LANGUAGE sql IMMUTABLE STRICT
    AS $_$ SELECT _ST_AsGeoJson(1, $1::geometry,15,0);  $_$;


ALTER FUNCTION public.st_asgeojson(text) OWNER TO postgres;

--
-- Name: st_asgml(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_asgml(text) RETURNS text
    LANGUAGE sql IMMUTABLE STRICT
    AS $_$ SELECT _ST_AsGML(2,$1::geometry,15,0, NULL);  $_$;


ALTER FUNCTION public.st_asgml(text) OWNER TO postgres;

--
-- Name: st_askml(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_askml(text) RETURNS text
    LANGUAGE sql IMMUTABLE STRICT
    AS $_$ SELECT _ST_AsKML(2, $1::geometry, 15, null);  $_$;


ALTER FUNCTION public.st_askml(text) OWNER TO postgres;

--
-- Name: st_assvg(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_assvg(text) RETURNS text
    LANGUAGE sql IMMUTABLE STRICT
    AS $_$ SELECT ST_AsSVG($1::geometry,0,15);  $_$;


ALTER FUNCTION public.st_assvg(text) OWNER TO postgres;

--
-- Name: st_astext(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_astext(text) RETURNS text
    LANGUAGE sql IMMUTABLE STRICT
    AS $_$ SELECT ST_AsText($1::geometry);  $_$;


ALTER FUNCTION public.st_astext(text) OWNER TO postgres;

--
-- Name: st_count(text, text, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_count(rastertable text, rastercolumn text, exclude_nodata_value boolean) RETURNS bigint
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_count($1, $2, 1, $3, 1) $_$;


ALTER FUNCTION public.st_count(rastertable text, rastercolumn text, exclude_nodata_value boolean) OWNER TO postgres;

--
-- Name: FUNCTION st_count(rastertable text, rastercolumn text, exclude_nodata_value boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_count(rastertable text, rastercolumn text, exclude_nodata_value boolean) IS 'args: rastertable, rastercolumn, exclude_nodata_value - Returns the number of pixels in a given band of a raster or raster coverage. If no band is specified defaults to band 1. If exclude_nodata_value is set to true, will only count pixels that are not equal to the nodata value.';


--
-- Name: st_count(text, text, integer, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_count(rastertable text, rastercolumn text, nband integer DEFAULT 1, exclude_nodata_value boolean DEFAULT true) RETURNS bigint
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_count($1, $2, $3, $4, 1) $_$;


ALTER FUNCTION public.st_count(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean) OWNER TO postgres;

--
-- Name: FUNCTION st_count(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_count(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean) IS 'args: rastertable, rastercolumn, nband=1, exclude_nodata_value=true - Returns the number of pixels in a given band of a raster or raster coverage. If no band is specified defaults to band 1. If exclude_nodata_value is set to true, will only count pixels that are not equal to the nodata value.';


--
-- Name: st_coveredby(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_coveredby(text, text) RETURNS boolean
    LANGUAGE sql IMMUTABLE
    AS $_$ SELECT ST_CoveredBy($1::geometry, $2::geometry);  $_$;


ALTER FUNCTION public.st_coveredby(text, text) OWNER TO postgres;

--
-- Name: st_covers(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_covers(text, text) RETURNS boolean
    LANGUAGE sql IMMUTABLE
    AS $_$ SELECT ST_Covers($1::geometry, $2::geometry);  $_$;


ALTER FUNCTION public.st_covers(text, text) OWNER TO postgres;

--
-- Name: st_distance(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_distance(text, text) RETURNS double precision
    LANGUAGE sql IMMUTABLE STRICT
    AS $_$ SELECT ST_Distance($1::geometry, $2::geometry);  $_$;


ALTER FUNCTION public.st_distance(text, text) OWNER TO postgres;

--
-- Name: st_distinct4ma(double precision[], text, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_distinct4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) RETURNS double precision
    LANGUAGE sql IMMUTABLE
    AS $_$ SELECT COUNT(DISTINCT unnest)::float FROM unnest($1) $_$;


ALTER FUNCTION public.st_distinct4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) OWNER TO postgres;

--
-- Name: FUNCTION st_distinct4ma(matrix double precision[], nodatamode text, VARIADIC args text[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_distinct4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) IS 'args: matrix, nodatamode, VARIADIC args - Raster processing function that calculates the number of unique pixel values in a neighborhood.';


--
-- Name: st_dwithin(text, text, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_dwithin(text, text, double precision) RETURNS boolean
    LANGUAGE sql IMMUTABLE
    AS $_$ SELECT ST_DWithin($1::geometry, $2::geometry, $3);  $_$;


ALTER FUNCTION public.st_dwithin(text, text, double precision) OWNER TO postgres;

--
-- Name: st_histogram(text, text, integer, integer, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer, bins integer, "right" boolean) RETURNS SETOF histogram
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_histogram($1, $2, $3, TRUE, 1, $4, NULL, $5) $_$;


ALTER FUNCTION public.st_histogram(rastertable text, rastercolumn text, nband integer, bins integer, "right" boolean) OWNER TO postgres;

--
-- Name: FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer, bins integer, "right" boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer, bins integer, "right" boolean) IS 'args: rastertable, rastercolumn, nband, bins, right - Returns a set of histogram summarizing a raster or raster coverage data distribution separate bin ranges. Number of bins are autocomputed if not specified.';


--
-- Name: st_histogram(text, text, integer, boolean, integer, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, bins integer, "right" boolean) RETURNS SETOF histogram
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_histogram($1, $2, $3, $4, 1, $5, NULL, $6) $_$;


ALTER FUNCTION public.st_histogram(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, bins integer, "right" boolean) OWNER TO postgres;

--
-- Name: FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, bins integer, "right" boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, bins integer, "right" boolean) IS 'args: rastertable, rastercolumn, nband, exclude_nodata_value, bins, right - Returns a set of histogram summarizing a raster or raster coverage data distribution separate bin ranges. Number of bins are autocomputed if not specified.';


--
-- Name: st_histogram(text, text, integer, integer, double precision[], boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer, bins integer, width double precision[] DEFAULT NULL::double precision[], "right" boolean DEFAULT false) RETURNS SETOF histogram
    LANGUAGE sql STABLE
    AS $_$ SELECT _st_histogram($1, $2, $3, TRUE, 1, $4, $5, $6) $_$;


ALTER FUNCTION public.st_histogram(rastertable text, rastercolumn text, nband integer, bins integer, width double precision[], "right" boolean) OWNER TO postgres;

--
-- Name: FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer, bins integer, width double precision[], "right" boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer, bins integer, width double precision[], "right" boolean) IS 'args: rastertable, rastercolumn, nband=1, bins, width=NULL, right=false - Returns a set of histogram summarizing a raster or raster coverage data distribution separate bin ranges. Number of bins are autocomputed if not specified.';


--
-- Name: st_histogram(text, text, integer, boolean, integer, double precision[], boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer DEFAULT 1, exclude_nodata_value boolean DEFAULT true, bins integer DEFAULT 0, width double precision[] DEFAULT NULL::double precision[], "right" boolean DEFAULT false) RETURNS SETOF histogram
    LANGUAGE sql STABLE
    AS $_$ SELECT _st_histogram($1, $2, $3, $4, 1, $5, $6, $7) $_$;


ALTER FUNCTION public.st_histogram(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, bins integer, width double precision[], "right" boolean) OWNER TO postgres;

--
-- Name: FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, bins integer, width double precision[], "right" boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_histogram(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, bins integer, width double precision[], "right" boolean) IS 'args: rastertable, rastercolumn, nband=1, exclude_nodata_value=true, bins=autocomputed, width=NULL, right=false - Returns a set of histogram summarizing a raster or raster coverage data distribution separate bin ranges. Number of bins are autocomputed if not specified.';


--
-- Name: st_intersects(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_intersects(text, text) RETURNS boolean
    LANGUAGE sql IMMUTABLE
    AS $_$ SELECT ST_Intersects($1::geometry, $2::geometry);  $_$;


ALTER FUNCTION public.st_intersects(text, text) OWNER TO postgres;

--
-- Name: st_length(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_length(text) RETURNS double precision
    LANGUAGE sql IMMUTABLE STRICT
    AS $_$ SELECT ST_Length($1::geometry);  $_$;


ALTER FUNCTION public.st_length(text) OWNER TO postgres;

--
-- Name: st_max4ma(double precision[], text, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_max4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) RETURNS double precision
    LANGUAGE plpgsql IMMUTABLE
    AS $$
    DECLARE
        _matrix float[][];
        max float;
    BEGIN
        _matrix := matrix;
        max := '-Infinity'::float;
        FOR x in array_lower(_matrix, 1)..array_upper(_matrix, 1) LOOP
            FOR y in array_lower(_matrix, 2)..array_upper(_matrix, 2) LOOP
                IF _matrix[x][y] IS NULL THEN
                    IF NOT nodatamode = 'ignore' THEN
                        _matrix[x][y] := nodatamode::float;
                    END IF;
                END IF;
                IF max < _matrix[x][y] THEN
                    max := _matrix[x][y];
                END IF;
            END LOOP;
        END LOOP;
        RETURN max;
    END;
    $$;


ALTER FUNCTION public.st_max4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) OWNER TO postgres;

--
-- Name: FUNCTION st_max4ma(matrix double precision[], nodatamode text, VARIADIC args text[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_max4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) IS 'args: matrix, nodatamode, VARIADIC args - Raster processing function that calculates the maximum pixel value in a neighborhood.';


--
-- Name: st_mean4ma(double precision[], text, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_mean4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) RETURNS double precision
    LANGUAGE plpgsql IMMUTABLE
    AS $$
    DECLARE
        _matrix float[][];
        sum float;
        count float;
    BEGIN
        _matrix := matrix;
        sum := 0;
        count := 0;
        FOR x in array_lower(matrix, 1)..array_upper(matrix, 1) LOOP
            FOR y in array_lower(matrix, 2)..array_upper(matrix, 2) LOOP
                IF _matrix[x][y] IS NULL THEN
                    IF nodatamode = 'ignore' THEN
                        _matrix[x][y] := 0;
                    ELSE
                        _matrix[x][y] := nodatamode::float;
                        count := count + 1;
                    END IF;
                ELSE
                    count := count + 1;
                END IF;
                sum := sum + _matrix[x][y];
            END LOOP;
        END LOOP;
        IF count = 0 THEN
            RETURN NULL;
        END IF;
        RETURN sum / count;
    END;
    $$;


ALTER FUNCTION public.st_mean4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) OWNER TO postgres;

--
-- Name: FUNCTION st_mean4ma(matrix double precision[], nodatamode text, VARIADIC args text[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_mean4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) IS 'args: matrix, nodatamode, VARIADIC args - Raster processing function that calculates the mean pixel value in a neighborhood.';


--
-- Name: st_min4ma(double precision[], text, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_min4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) RETURNS double precision
    LANGUAGE plpgsql IMMUTABLE
    AS $$
    DECLARE
        _matrix float[][];
        min float;
    BEGIN
        _matrix := matrix;
        min := 'Infinity'::float;
        FOR x in array_lower(_matrix, 1)..array_upper(_matrix, 1) LOOP
            FOR y in array_lower(_matrix, 2)..array_upper(_matrix, 2) LOOP
                IF _matrix[x][y] IS NULL THEN
                    IF NOT nodatamode = 'ignore' THEN
                        _matrix[x][y] := nodatamode::float;
                    END IF;
                END IF;
                IF min > _matrix[x][y] THEN
                    min := _matrix[x][y];
                END IF;
            END LOOP;
        END LOOP;
        RETURN min;
    END;
    $$;


ALTER FUNCTION public.st_min4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) OWNER TO postgres;

--
-- Name: FUNCTION st_min4ma(matrix double precision[], nodatamode text, VARIADIC args text[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_min4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) IS 'args: matrix, nodatamode, VARIADIC args - Raster processing function that calculates the minimum pixel value in a neighborhood.';


--
-- Name: st_quantile(text, text, double precision[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_quantile(rastertable text, rastercolumn text, quantiles double precision[]) RETURNS SETOF quantile
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_quantile($1, $2, 1, TRUE, 1, $3) $_$;


ALTER FUNCTION public.st_quantile(rastertable text, rastercolumn text, quantiles double precision[]) OWNER TO postgres;

--
-- Name: st_quantile(text, text, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_quantile(rastertable text, rastercolumn text, quantile double precision) RETURNS double precision
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_quantile($1, $2, 1, TRUE, 1, ARRAY[$3]::double precision[])).value $_$;


ALTER FUNCTION public.st_quantile(rastertable text, rastercolumn text, quantile double precision) OWNER TO postgres;

--
-- Name: st_quantile(text, text, boolean, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_quantile(rastertable text, rastercolumn text, exclude_nodata_value boolean, quantile double precision DEFAULT NULL::double precision) RETURNS double precision
    LANGUAGE sql STABLE
    AS $_$ SELECT (_st_quantile($1, $2, 1, $3, 1, ARRAY[$4]::double precision[])).value $_$;


ALTER FUNCTION public.st_quantile(rastertable text, rastercolumn text, exclude_nodata_value boolean, quantile double precision) OWNER TO postgres;

--
-- Name: st_quantile(text, text, integer, double precision[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer, quantiles double precision[]) RETURNS SETOF quantile
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_quantile($1, $2, $3, TRUE, 1, $4) $_$;


ALTER FUNCTION public.st_quantile(rastertable text, rastercolumn text, nband integer, quantiles double precision[]) OWNER TO postgres;

--
-- Name: FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer, quantiles double precision[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer, quantiles double precision[]) IS 'args: rastertable, rastercolumn, nband, quantiles - Compute quantiles for a raster or raster table coverage in the context of the sample or population. Thus, a value could be examined to be at the rasters 25%, 50%, 75% percentile.';


--
-- Name: st_quantile(text, text, integer, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer, quantile double precision) RETURNS double precision
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_quantile($1, $2, $3, TRUE, 1, ARRAY[$4]::double precision[])).value $_$;


ALTER FUNCTION public.st_quantile(rastertable text, rastercolumn text, nband integer, quantile double precision) OWNER TO postgres;

--
-- Name: st_quantile(text, text, integer, boolean, double precision[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer DEFAULT 1, exclude_nodata_value boolean DEFAULT true, quantiles double precision[] DEFAULT NULL::double precision[]) RETURNS SETOF quantile
    LANGUAGE sql STABLE
    AS $_$ SELECT _st_quantile($1, $2, $3, $4, 1, $5) $_$;


ALTER FUNCTION public.st_quantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, quantiles double precision[]) OWNER TO postgres;

--
-- Name: FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, quantiles double precision[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, quantiles double precision[]) IS 'args: rastertable, rastercolumn, nband=1, exclude_nodata_value=true, quantiles=NULL - Compute quantiles for a raster or raster table coverage in the context of the sample or population. Thus, a value could be examined to be at the rasters 25%, 50%, 75% percentile.';


--
-- Name: st_quantile(text, text, integer, boolean, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, quantile double precision) RETURNS double precision
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_quantile($1, $2, $3, $4, 1, ARRAY[$5]::double precision[])).value $_$;


ALTER FUNCTION public.st_quantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, quantile double precision) OWNER TO postgres;

--
-- Name: st_range4ma(double precision[], text, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_range4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) RETURNS double precision
    LANGUAGE plpgsql IMMUTABLE
    AS $$
    DECLARE
        _matrix float[][];
        min float;
        max float;
    BEGIN
        _matrix := matrix;
        min := 'Infinity'::float;
        max := '-Infinity'::float;
        FOR x in array_lower(matrix, 1)..array_upper(matrix, 1) LOOP
            FOR y in array_lower(matrix, 2)..array_upper(matrix, 2) LOOP
                IF _matrix[x][y] IS NULL THEN
                    IF NOT nodatamode = 'ignore' THEN
                        _matrix[x][y] := nodatamode::float;
                    END IF;
                END IF;
                IF min > _matrix[x][y] THEN
                    min = _matrix[x][y];
                END IF;
                IF max < _matrix[x][y] THEN
                    max = _matrix[x][y];
                END IF;
            END LOOP;
        END LOOP;
        IF max = '-Infinity'::float OR min = 'Infinity'::float THEN
            RETURN NULL;
        END IF;
        RETURN max - min;
    END;
    $$;


ALTER FUNCTION public.st_range4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) OWNER TO postgres;

--
-- Name: FUNCTION st_range4ma(matrix double precision[], nodatamode text, VARIADIC args text[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_range4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) IS 'args: matrix, nodatamode, VARIADIC args - Raster processing function that calculates the range of pixel values in a neighborhood.';


--
-- Name: st_samealignment(double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_samealignment(ulx1 double precision, uly1 double precision, scalex1 double precision, scaley1 double precision, skewx1 double precision, skewy1 double precision, ulx2 double precision, uly2 double precision, scalex2 double precision, scaley2 double precision, skewx2 double precision, skewy2 double precision) RETURNS boolean
    LANGUAGE sql IMMUTABLE STRICT
    AS $_$ SELECT st_samealignment(st_makeemptyraster(1, 1, $1, $2, $3, $4, $5, $6), st_makeemptyraster(1, 1, $7, $8, $9, $10, $11, $12)) $_$;


ALTER FUNCTION public.st_samealignment(ulx1 double precision, uly1 double precision, scalex1 double precision, scaley1 double precision, skewx1 double precision, skewy1 double precision, ulx2 double precision, uly2 double precision, scalex2 double precision, scaley2 double precision, skewx2 double precision, skewy2 double precision) OWNER TO postgres;

--
-- Name: FUNCTION st_samealignment(ulx1 double precision, uly1 double precision, scalex1 double precision, scaley1 double precision, skewx1 double precision, skewy1 double precision, ulx2 double precision, uly2 double precision, scalex2 double precision, scaley2 double precision, skewx2 double precision, skewy2 double precision); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_samealignment(ulx1 double precision, uly1 double precision, scalex1 double precision, scaley1 double precision, skewx1 double precision, skewy1 double precision, ulx2 double precision, uly2 double precision, scalex2 double precision, scaley2 double precision, skewx2 double precision, skewy2 double precision) IS 'args: ulx1, uly1, scalex1, scaley1, skewx1, skewy1, ulx2, uly2, scalex2, scaley2, skewx2, skewy2 - Returns true if rasters have same skew, scale, spatial ref and false if they dont with notice detailing issue.';


--
-- Name: st_stddev4ma(double precision[], text, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_stddev4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) RETURNS double precision
    LANGUAGE sql IMMUTABLE
    AS $_$ SELECT stddev(unnest) FROM unnest($1) $_$;


ALTER FUNCTION public.st_stddev4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) OWNER TO postgres;

--
-- Name: FUNCTION st_stddev4ma(matrix double precision[], nodatamode text, VARIADIC args text[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_stddev4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) IS 'args: matrix, nodatamode, VARIADIC args - Raster processing function that calculates the standard deviation of pixel values in a neighborhood.';


--
-- Name: st_sum4ma(double precision[], text, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_sum4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) RETURNS double precision
    LANGUAGE plpgsql IMMUTABLE
    AS $$
    DECLARE
        _matrix float[][];
        sum float;
    BEGIN
        _matrix := matrix;
        sum := 0;
        FOR x in array_lower(matrix, 1)..array_upper(matrix, 1) LOOP
            FOR y in array_lower(matrix, 2)..array_upper(matrix, 2) LOOP
                IF _matrix[x][y] IS NULL THEN
                    IF nodatamode = 'ignore' THEN
                        _matrix[x][y] := 0;
                    ELSE
                        _matrix[x][y] := nodatamode::float;
                    END IF;
                END IF;
                sum := sum + _matrix[x][y];
            END LOOP;
        END LOOP;
        RETURN sum;
    END;
    $$;


ALTER FUNCTION public.st_sum4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) OWNER TO postgres;

--
-- Name: FUNCTION st_sum4ma(matrix double precision[], nodatamode text, VARIADIC args text[]); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_sum4ma(matrix double precision[], nodatamode text, VARIADIC args text[]) IS 'args: matrix, nodatamode, VARIADIC args - Raster processing function that calculates the sum of all pixel values in a neighborhood.';


--
-- Name: st_summarystats(text, text, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_summarystats(rastertable text, rastercolumn text, exclude_nodata_value boolean) RETURNS summarystats
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_summarystats($1, $2, 1, $3, 1) $_$;


ALTER FUNCTION public.st_summarystats(rastertable text, rastercolumn text, exclude_nodata_value boolean) OWNER TO postgres;

--
-- Name: FUNCTION st_summarystats(rastertable text, rastercolumn text, exclude_nodata_value boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_summarystats(rastertable text, rastercolumn text, exclude_nodata_value boolean) IS 'args: rastertable, rastercolumn, exclude_nodata_value - Returns summary stats consisting of count,sum,mean,stddev,min,max for a given raster band of a raster or raster coverage. Band 1 is assumed is no band is specified.';


--
-- Name: st_summarystats(text, text, integer, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_summarystats(rastertable text, rastercolumn text, nband integer DEFAULT 1, exclude_nodata_value boolean DEFAULT true) RETURNS summarystats
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT _st_summarystats($1, $2, $3, $4, 1) $_$;


ALTER FUNCTION public.st_summarystats(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean) OWNER TO postgres;

--
-- Name: FUNCTION st_summarystats(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_summarystats(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean) IS 'args: rastertable, rastercolumn, nband=1, exclude_nodata_value=true - Returns summary stats consisting of count,sum,mean,stddev,min,max for a given raster band of a raster or raster coverage. Band 1 is assumed is no band is specified.';


--
-- Name: st_valuecount(text, text, double precision[], double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuecount(rastertable text, rastercolumn text, searchvalues double precision[], roundto double precision DEFAULT 0, OUT value double precision, OUT count integer) RETURNS SETOF record
    LANGUAGE sql STABLE
    AS $_$ SELECT value, count FROM _st_valuecount($1, $2, 1, TRUE, $3, $4) $_$;


ALTER FUNCTION public.st_valuecount(rastertable text, rastercolumn text, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer) OWNER TO postgres;

--
-- Name: FUNCTION st_valuecount(rastertable text, rastercolumn text, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_valuecount(rastertable text, rastercolumn text, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer) IS 'args: rastertable, rastercolumn, searchvalues, roundto=0, OUT value, OUT count - Returns a set of records containing a pixel band value and count of the number of pixels in a given band of a raster (or a raster coverage) that have a given set of values. If no band is specified defaults to band 1. By default nodata value pixels are not counted. and all other values in the pixel are output and pixel band values are rounded to the nearest integer.';


--
-- Name: st_valuecount(text, text, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuecount(rastertable text, rastercolumn text, searchvalue double precision, roundto double precision DEFAULT 0) RETURNS integer
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_valuecount($1, $2, 1, TRUE, ARRAY[$3]::double precision[], $4)).count $_$;


ALTER FUNCTION public.st_valuecount(rastertable text, rastercolumn text, searchvalue double precision, roundto double precision) OWNER TO postgres;

--
-- Name: FUNCTION st_valuecount(rastertable text, rastercolumn text, searchvalue double precision, roundto double precision); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_valuecount(rastertable text, rastercolumn text, searchvalue double precision, roundto double precision) IS 'args: rastertable, rastercolumn, searchvalue, roundto=0 - Returns a set of records containing a pixel band value and count of the number of pixels in a given band of a raster (or a raster coverage) that have a given set of values. If no band is specified defaults to band 1. By default nodata value pixels are not counted. and all other values in the pixel are output and pixel band values are rounded to the nearest integer.';


--
-- Name: st_valuecount(text, text, integer, double precision[], double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, searchvalues double precision[], roundto double precision DEFAULT 0, OUT value double precision, OUT count integer) RETURNS SETOF record
    LANGUAGE sql STABLE
    AS $_$ SELECT value, count FROM _st_valuecount($1, $2, $3, TRUE, $4, $5) $_$;


ALTER FUNCTION public.st_valuecount(rastertable text, rastercolumn text, nband integer, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer) OWNER TO postgres;

--
-- Name: FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer) IS 'args: rastertable, rastercolumn, nband, searchvalues, roundto=0, OUT value, OUT count - Returns a set of records containing a pixel band value and count of the number of pixels in a given band of a raster (or a raster coverage) that have a given set of values. If no band is specified defaults to band 1. By default nodata value pixels are not counted. and all other values in the pixel are output and pixel band values are rounded to the nearest integer.';


--
-- Name: st_valuecount(text, text, integer, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, searchvalue double precision, roundto double precision DEFAULT 0) RETURNS integer
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_valuecount($1, $2, $3, TRUE, ARRAY[$4]::double precision[], $5)).count $_$;


ALTER FUNCTION public.st_valuecount(rastertable text, rastercolumn text, nband integer, searchvalue double precision, roundto double precision) OWNER TO postgres;

--
-- Name: FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, searchvalue double precision, roundto double precision); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, searchvalue double precision, roundto double precision) IS 'args: rastertable, rastercolumn, nband, searchvalue, roundto=0 - Returns a set of records containing a pixel band value and count of the number of pixels in a given band of a raster (or a raster coverage) that have a given set of values. If no band is specified defaults to band 1. By default nodata value pixels are not counted. and all other values in the pixel are output and pixel band values are rounded to the nearest integer.';


--
-- Name: st_valuecount(text, text, integer, boolean, double precision[], double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer DEFAULT 1, exclude_nodata_value boolean DEFAULT true, searchvalues double precision[] DEFAULT NULL::double precision[], roundto double precision DEFAULT 0, OUT value double precision, OUT count integer) RETURNS SETOF record
    LANGUAGE sql STABLE
    AS $_$ SELECT value, count FROM _st_valuecount($1, $2, $3, $4, $5, $6) $_$;


ALTER FUNCTION public.st_valuecount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer) OWNER TO postgres;

--
-- Name: FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer) IS 'args: rastertable, rastercolumn, nband=1, exclude_nodata_value=true, searchvalues=NULL, roundto=0, OUT value, OUT count - Returns a set of records containing a pixel band value and count of the number of pixels in a given band of a raster (or a raster coverage) that have a given set of values. If no band is specified defaults to band 1. By default nodata value pixels are not counted. and all other values in the pixel are output and pixel band values are rounded to the nearest integer.';


--
-- Name: st_valuecount(text, text, integer, boolean, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalue double precision, roundto double precision DEFAULT 0) RETURNS integer
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_valuecount($1, $2, $3, $4, ARRAY[$5]::double precision[], $6)).count $_$;


ALTER FUNCTION public.st_valuecount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalue double precision, roundto double precision) OWNER TO postgres;

--
-- Name: FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalue double precision, roundto double precision); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalue double precision, roundto double precision) IS 'args: rastertable, rastercolumn, nband, exclude_nodata_value, searchvalue, roundto=0 - Returns a set of records containing a pixel band value and count of the number of pixels in a given band of a raster (or a raster coverage) that have a given set of values. If no band is specified defaults to band 1. By default nodata value pixels are not counted. and all other values in the pixel are output and pixel band values are rounded to the nearest integer.';


--
-- Name: st_valuepercent(text, text, double precision[], double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuepercent(rastertable text, rastercolumn text, searchvalues double precision[], roundto double precision DEFAULT 0, OUT value double precision, OUT percent double precision) RETURNS SETOF record
    LANGUAGE sql STABLE
    AS $_$ SELECT value, percent FROM _st_valuecount($1, $2, 1, TRUE, $3, $4) $_$;


ALTER FUNCTION public.st_valuepercent(rastertable text, rastercolumn text, searchvalues double precision[], roundto double precision, OUT value double precision, OUT percent double precision) OWNER TO postgres;

--
-- Name: st_valuepercent(text, text, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuepercent(rastertable text, rastercolumn text, searchvalue double precision, roundto double precision DEFAULT 0) RETURNS double precision
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_valuecount($1, $2, 1, TRUE, ARRAY[$3]::double precision[], $4)).percent $_$;


ALTER FUNCTION public.st_valuepercent(rastertable text, rastercolumn text, searchvalue double precision, roundto double precision) OWNER TO postgres;

--
-- Name: st_valuepercent(text, text, integer, double precision[], double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuepercent(rastertable text, rastercolumn text, nband integer, searchvalues double precision[], roundto double precision DEFAULT 0, OUT value double precision, OUT percent double precision) RETURNS SETOF record
    LANGUAGE sql STABLE
    AS $_$ SELECT value, percent FROM _st_valuecount($1, $2, $3, TRUE, $4, $5) $_$;


ALTER FUNCTION public.st_valuepercent(rastertable text, rastercolumn text, nband integer, searchvalues double precision[], roundto double precision, OUT value double precision, OUT percent double precision) OWNER TO postgres;

--
-- Name: st_valuepercent(text, text, integer, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuepercent(rastertable text, rastercolumn text, nband integer, searchvalue double precision, roundto double precision DEFAULT 0) RETURNS double precision
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_valuecount($1, $2, $3, TRUE, ARRAY[$4]::double precision[], $5)).percent $_$;


ALTER FUNCTION public.st_valuepercent(rastertable text, rastercolumn text, nband integer, searchvalue double precision, roundto double precision) OWNER TO postgres;

--
-- Name: st_valuepercent(text, text, integer, boolean, double precision[], double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuepercent(rastertable text, rastercolumn text, nband integer DEFAULT 1, exclude_nodata_value boolean DEFAULT true, searchvalues double precision[] DEFAULT NULL::double precision[], roundto double precision DEFAULT 0, OUT value double precision, OUT percent double precision) RETURNS SETOF record
    LANGUAGE sql STABLE
    AS $_$ SELECT value, percent FROM _st_valuecount($1, $2, $3, $4, $5, $6) $_$;


ALTER FUNCTION public.st_valuepercent(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, OUT value double precision, OUT percent double precision) OWNER TO postgres;

--
-- Name: st_valuepercent(text, text, integer, boolean, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION st_valuepercent(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalue double precision, roundto double precision DEFAULT 0) RETURNS double precision
    LANGUAGE sql STABLE STRICT
    AS $_$ SELECT (_st_valuecount($1, $2, $3, $4, ARRAY[$5]::double precision[], $6)).percent $_$;


ALTER FUNCTION public.st_valuepercent(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalue double precision, roundto double precision) OWNER TO postgres;

--
-- Name: unlockrows(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION unlockrows(text) RETURNS integer
    LANGUAGE plpgsql STRICT
    AS $_$ 
DECLARE
	ret int;
BEGIN

	IF NOT LongTransactionsEnabled() THEN
		RAISE EXCEPTION 'Long transaction support disabled, use EnableLongTransaction() to enable.';
	END IF;

	EXECUTE 'DELETE FROM authorization_table where authid = ' ||
		quote_literal($1);

	GET DIAGNOSTICS ret = ROW_COUNT;

	RETURN ret;
END;
$_$;


ALTER FUNCTION public.unlockrows(text) OWNER TO postgres;

--
-- Name: updategeometrysrid(character varying, character varying, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION updategeometrysrid(character varying, character varying, integer) RETURNS text
    LANGUAGE plpgsql STRICT
    AS $_$
DECLARE
	ret  text;
BEGIN
	SELECT UpdateGeometrySRID('','',$1,$2,$3) into ret;
	RETURN ret;
END;
$_$;


ALTER FUNCTION public.updategeometrysrid(character varying, character varying, integer) OWNER TO postgres;

--
-- Name: updategeometrysrid(character varying, character varying, character varying, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION updategeometrysrid(character varying, character varying, character varying, integer) RETURNS text
    LANGUAGE plpgsql STRICT
    AS $_$
DECLARE
	ret  text;
BEGIN
	SELECT UpdateGeometrySRID('',$1,$2,$3,$4) into ret;
	RETURN ret;
END;
$_$;


ALTER FUNCTION public.updategeometrysrid(character varying, character varying, character varying, integer) OWNER TO postgres;

--
-- Name: updategeometrysrid(character varying, character varying, character varying, character varying, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION updategeometrysrid(catalogn_name character varying, schema_name character varying, table_name character varying, column_name character varying, new_srid_in integer) RETURNS text
    LANGUAGE plpgsql STRICT
    AS $$
DECLARE
	myrec RECORD;
	okay boolean;
	cname varchar;
	real_schema name;
	unknown_srid integer;
	new_srid integer := new_srid_in;

BEGIN


	-- Find, check or fix schema_name
	IF ( schema_name != '' ) THEN
		okay = false;

		FOR myrec IN SELECT nspname FROM pg_namespace WHERE text(nspname) = schema_name LOOP
			okay := true;
		END LOOP;

		IF ( okay <> true ) THEN
			RAISE EXCEPTION 'Invalid schema name';
		ELSE
			real_schema = schema_name;
		END IF;
	ELSE
		SELECT INTO real_schema current_schema()::text;
	END IF;

	-- Ensure that column_name is in geometry_columns
	okay = false;
	FOR myrec IN SELECT type, coord_dimension FROM geometry_columns WHERE f_table_schema = text(real_schema) and f_table_name = table_name and f_geometry_column = column_name LOOP
		okay := true;
	END LOOP;
	IF (NOT okay) THEN
		RAISE EXCEPTION 'column not found in geometry_columns table';
		RETURN false;
	END IF;

	-- Ensure that new_srid is valid
	IF ( new_srid > 0 ) THEN
		IF ( SELECT count(*) = 0 from spatial_ref_sys where srid = new_srid ) THEN
			RAISE EXCEPTION 'invalid SRID: % not found in spatial_ref_sys', new_srid;
			RETURN false;
		END IF;
	ELSE
		unknown_srid := ST_SRID('POINT EMPTY'::geometry);
		IF ( new_srid != unknown_srid ) THEN
			new_srid := unknown_srid;
			RAISE NOTICE 'SRID value % converted to the officially unknown SRID value %', new_srid_in, new_srid;
		END IF;
	END IF;

	IF postgis_constraint_srid(schema_name, table_name, column_name) IS NOT NULL THEN 
	-- srid was enforced with constraints before, keep it that way.
        -- Make up constraint name
        cname = 'enforce_srid_'  || column_name;
    
        -- Drop enforce_srid constraint
        EXECUTE 'ALTER TABLE ' || quote_ident(real_schema) ||
            '.' || quote_ident(table_name) ||
            ' DROP constraint ' || quote_ident(cname);
    
        -- Update geometries SRID
        EXECUTE 'UPDATE ' || quote_ident(real_schema) ||
            '.' || quote_ident(table_name) ||
            ' SET ' || quote_ident(column_name) ||
            ' = ST_SetSRID(' || quote_ident(column_name) ||
            ', ' || new_srid::text || ')';
            
        -- Reset enforce_srid constraint
        EXECUTE 'ALTER TABLE ' || quote_ident(real_schema) ||
            '.' || quote_ident(table_name) ||
            ' ADD constraint ' || quote_ident(cname) ||
            ' CHECK (st_srid(' || quote_ident(column_name) ||
            ') = ' || new_srid::text || ')';
    ELSE 
        -- We will use typmod to enforce if no srid constraints
        -- We are using postgis_type_name to lookup the new name 
        -- (in case Paul changes his mind and flips geometry_columns to return old upper case name) 
        EXECUTE 'ALTER TABLE ' || quote_ident(real_schema) || '.' || quote_ident(table_name) || 
        ' ALTER COLUMN ' || quote_ident(column_name) || ' TYPE  geometry(' || postgis_type_name(myrec.type, myrec.coord_dimension, true) || ', ' || new_srid::text || ') USING ST_SetSRID(' || quote_ident(column_name) || ',' || new_srid::text || ');' ;
    END IF;

	RETURN real_schema || '.' || table_name || '.' || column_name ||' SRID changed to ' || new_srid::text;

END;
$$;


ALTER FUNCTION public.updategeometrysrid(catalogn_name character varying, schema_name character varying, table_name character varying, column_name character varying, new_srid_in integer) OWNER TO postgres;

--
-- Name: btree_geography_ops; Type: OPERATOR FAMILY; Schema: public; Owner: postgres
--

CREATE OPERATOR FAMILY btree_geography_ops USING btree;


ALTER OPERATOR FAMILY public.btree_geography_ops USING btree OWNER TO postgres;

--
-- Name: btree_geometry_ops; Type: OPERATOR FAMILY; Schema: public; Owner: postgres
--

CREATE OPERATOR FAMILY btree_geometry_ops USING btree;


ALTER OPERATOR FAMILY public.btree_geometry_ops USING btree OWNER TO postgres;

--
-- Name: gist_geography_ops; Type: OPERATOR FAMILY; Schema: public; Owner: postgres
--

CREATE OPERATOR FAMILY gist_geography_ops USING gist;


ALTER OPERATOR FAMILY public.gist_geography_ops USING gist OWNER TO postgres;

--
-- Name: gist_geometry_ops_2d; Type: OPERATOR FAMILY; Schema: public; Owner: postgres
--

CREATE OPERATOR FAMILY gist_geometry_ops_2d USING gist;


ALTER OPERATOR FAMILY public.gist_geometry_ops_2d USING gist OWNER TO postgres;

--
-- Name: gist_geometry_ops_nd; Type: OPERATOR FAMILY; Schema: public; Owner: postgres
--

CREATE OPERATOR FAMILY gist_geometry_ops_nd USING gist;


ALTER OPERATOR FAMILY public.gist_geometry_ops_nd USING gist OWNER TO postgres;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: address; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE address (
    city character varying(15)
);


ALTER TABLE public.address OWNER TO postgres;

--
-- Name: customer; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE customer (
    customer_id numeric(5,0) NOT NULL,
    cust_name character varying(30) NOT NULL,
    city character varying(15),
    grade numeric(3,0) DEFAULT 0,
    salesman_id numeric(5,0) NOT NULL
);


ALTER TABLE public.customer OWNER TO postgres;

--
-- Name: agentview; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW agentview AS
 SELECT customer.customer_id,
    customer.cust_name,
    customer.city,
    customer.grade,
    customer.salesman_id
   FROM customer;


ALTER TABLE public.agentview OWNER TO postgres;

--
-- Name: bh; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE bh (
    name character varying(20) NOT NULL,
    emp_id integer NOT NULL,
    process character varying(20)
);


ALTER TABLE public.bh OWNER TO postgres;

--
-- Name: c; Type: TABLE; Schema: public; Owner: user3; Tablespace: 
--

CREATE TABLE c (
    com_name character(20),
    pro_name character(25),
    pro_price numeric(8,2)
);


ALTER TABLE public.c OWNER TO user3;

--
-- Name: casino; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE casino (
    pricerange numeric(6,0) NOT NULL,
    events character varying(50),
    location character varying(40) NOT NULL,
    casino character varying(75) NOT NULL
);


ALTER TABLE public.casino OWNER TO postgres;

--
-- Name: col1; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE col1 (
    "?column?" integer
);


ALTER TABLE public.col1 OWNER TO postgres;

--
-- Name: company_mast; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE company_mast (
    com_id integer NOT NULL,
    com_name character(20) NOT NULL
);


ALTER TABLE public.company_mast OWNER TO postgres;

--
-- Name: countries; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE countries (
    country_id character varying(2) NOT NULL,
    country_name character varying(40) DEFAULT NULL::character varying,
    region_id numeric(10,0) DEFAULT NULL::numeric
);


ALTER TABLE public.countries OWNER TO postgres;

--
-- Name: customer_backup; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE customer_backup (
    customer_id numeric(5,0),
    cust_name character varying(30),
    city character varying(15),
    grade numeric(3,0),
    salesman_id numeric(5,0)
);


ALTER TABLE public.customer_backup OWNER TO postgres;

--
-- Name: customergradelevels; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW customergradelevels AS
 SELECT DISTINCT customer.grade,
    count(*) AS count
   FROM customer
  GROUP BY customer.grade;


ALTER TABLE public.customergradelevels OWNER TO postgres;

--
-- Name: customergradelevels2; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW customergradelevels2 AS
 SELECT DISTINCT customer.grade,
    count(*) AS count
   FROM customer
  WHERE (customer.grade IS NOT NULL)
  GROUP BY customer.grade;


ALTER TABLE public.customergradelevels2 OWNER TO postgres;

--
-- Name: departments; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE departments (
    department_id numeric(4,0) NOT NULL,
    department_name character varying(30) NOT NULL,
    manager_id numeric(6,0) DEFAULT NULL::numeric,
    location_id numeric(4,0) DEFAULT NULL::numeric
);


ALTER TABLE public.departments OWNER TO postgres;

--
-- Name: elephants; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE elephants (
    id integer NOT NULL,
    name text,
    date date DEFAULT now()
);


ALTER TABLE public.elephants OWNER TO postgres;

--
-- Name: emp; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE emp (
    ename character varying(13),
    salary numeric(6,0),
    eid numeric(3,0) NOT NULL
);


ALTER TABLE public.emp OWNER TO postgres;

--
-- Name: emp_department; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE emp_department (
    dpt_code integer NOT NULL,
    dpt_name character(15) NOT NULL,
    dpt_allotment integer NOT NULL
);


ALTER TABLE public.emp_department OWNER TO postgres;

--
-- Name: emp_details; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE emp_details (
    emp_idno integer NOT NULL,
    emp_fname character(15) NOT NULL,
    emp_lname character(15) NOT NULL,
    emp_dept integer NOT NULL
);


ALTER TABLE public.emp_details OWNER TO postgres;

--
-- Name: employee; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE employee (
    empno integer,
    ename character varying(20)
);


ALTER TABLE public.employee OWNER TO postgres;

--
-- Name: employees; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE employees (
    employee_id numeric(6,0) DEFAULT 0::numeric NOT NULL,
    first_name character varying(20) DEFAULT NULL::character varying,
    last_name character varying(25) NOT NULL,
    email character varying(25) NOT NULL,
    phone_number character varying(20) DEFAULT NULL::character varying,
    hire_date date NOT NULL,
    job_id character varying(10) NOT NULL,
    salary numeric(8,2) DEFAULT NULL::numeric,
    commission_pct numeric(2,2) DEFAULT NULL::numeric,
    manager_id numeric(6,0) DEFAULT NULL::numeric,
    department_id numeric(4,0) DEFAULT NULL::numeric
);


ALTER TABLE public.employees OWNER TO postgres;

--
-- Name: game_scores; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE game_scores (
    id integer NOT NULL,
    name text,
    score integer
);


ALTER TABLE public.game_scores OWNER TO postgres;

--
-- Name: grade; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE grade (
    city character varying(15)
);


ALTER TABLE public.grade OWNER TO postgres;

--
-- Name: grade_customer; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW grade_customer AS
 SELECT customer.grade,
    count(customer.customer_id) AS count
   FROM customer
  GROUP BY customer.grade;


ALTER TABLE public.grade_customer OWNER TO postgres;

--
-- Name: grade_customer1; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW grade_customer1 AS
 SELECT customer.grade,
    count(*) AS number
   FROM customer
  GROUP BY customer.grade;


ALTER TABLE public.grade_customer1 OWNER TO postgres;

--
-- Name: grades; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE grades (
    id integer NOT NULL,
    grade_1 integer,
    grade_2 integer,
    grade_3 integer
);


ALTER TABLE public.grades OWNER TO postgres;

--
-- Name: hello; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE hello (
    number_one integer,
    number_two integer,
    number_three integer
);


ALTER TABLE public.hello OWNER TO postgres;

--
-- Name: hello1_1122; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE hello1_1122 (
    abc integer
);


ALTER TABLE public.hello1_1122 OWNER TO postgres;

--
-- Name: hello1_12; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE hello1_12 (
    abc integer
);


ALTER TABLE public.hello1_12 OWNER TO postgres;

--
-- Name: hello_12; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE hello_12 (
    abc integer
);


ALTER TABLE public.hello_12 OWNER TO postgres;

--
-- Name: item_mast; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE item_mast (
    pro_id integer NOT NULL,
    pro_name character(25) NOT NULL,
    pro_price numeric(8,2) NOT NULL,
    pro_com integer NOT NULL
);


ALTER TABLE public.item_mast OWNER TO postgres;

--
-- Name: job_grades; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE job_grades (
    grade_level character(2) NOT NULL,
    lowest_sal integer,
    highest_sal integer
);


ALTER TABLE public.job_grades OWNER TO postgres;

--
-- Name: job_history; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE job_history (
    employee_id numeric(6,0) NOT NULL,
    start_date date NOT NULL,
    end_date date NOT NULL,
    job_id character varying(10) NOT NULL,
    department_id numeric(4,0) DEFAULT NULL::numeric
);


ALTER TABLE public.job_history OWNER TO postgres;

--
-- Name: jobs; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE jobs (
    job_id character varying(10) DEFAULT ''::character varying NOT NULL,
    job_title character varying(35) NOT NULL,
    min_salary numeric(6,0) DEFAULT NULL::numeric,
    max_salary numeric(6,0) DEFAULT NULL::numeric
);


ALTER TABLE public.jobs OWNER TO postgres;

--
-- Name: locations; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE locations (
    location_id numeric(4,0) DEFAULT 0::numeric NOT NULL,
    street_address character varying(40) DEFAULT NULL::character varying,
    postal_code character varying(12) DEFAULT NULL::character varying,
    city character varying(30) NOT NULL,
    state_province character varying(25) DEFAULT NULL::character varying,
    country_id character varying(2) DEFAULT NULL::character varying
);


ALTER TABLE public.locations OWNER TO postgres;

--
-- Name: maxim00; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE maxim00 (
    num integer,
    name character varying(10)
);


ALTER TABLE public.maxim00 OWNER TO postgres;

--
-- Name: maximum; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE maximum (
    num integer,
    name character varying(10)
);


ALTER TABLE public.maximum OWNER TO postgres;

--
-- Name: maximum00; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE maximum00 (
    num integer,
    name character varying(10)
);


ALTER TABLE public.maximum00 OWNER TO postgres;

--
-- Name: maximum899; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE maximum899 (
    num integer,
    name character varying(10)
);


ALTER TABLE public.maximum899 OWNER TO postgres;

--
-- Name: mytest; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE mytest (
    ord_num numeric(6,0) NOT NULL,
    ord_amount numeric(12,2),
    ord_date date NOT NULL,
    cust_code character(6) NOT NULL,
    agent_code character(6) NOT NULL
);


ALTER TABLE public.mytest OWNER TO postgres;

--
-- Name: mytest1; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE mytest1 (
    ord_num numeric(6,0) NOT NULL,
    ord_amount numeric(12,2),
    ord_date date NOT NULL,
    cust_code character(6) NOT NULL,
    agent_code character(6) NOT NULL
);


ALTER TABLE public.mytest1 OWNER TO postgres;

--
-- Name: salesman; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE salesman (
    salesman_id numeric(5,0) NOT NULL,
    name character varying(30) NOT NULL,
    city character varying(15),
    commission numeric(5,2)
);


ALTER TABLE public.salesman OWNER TO postgres;

--
-- Name: myworkstuff; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW myworkstuff AS
 SELECT salesman.salesman_id,
    salesman.name,
    salesman.city
   FROM salesman;


ALTER TABLE public.myworkstuff OWNER TO postgres;

--
-- Name: myworkstuffs; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW myworkstuffs AS
 SELECT salesman.salesman_id,
    salesman.name,
    salesman.city
   FROM salesman
  WHERE ((salesman.city)::text = 'New York'::text);


ALTER TABLE public.myworkstuffs OWNER TO postgres;

--
-- Name: new; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE new (
    city character varying(15)
);


ALTER TABLE public.new OWNER TO postgres;

--
-- Name: new123; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE new123 (
    "Customer" character varying(30),
    city character varying(15),
    "Salesman" character varying(30),
    commission numeric(5,2)
);


ALTER TABLE public.new123 OWNER TO postgres;

--
-- Name: new_table; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE new_table (
    salesman_id numeric(5,0),
    name character varying(30),
    city character varying(15),
    commission numeric(5,2)
);


ALTER TABLE public.new_table OWNER TO postgres;

--
-- Name: newtab; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE newtab (
    ord_no numeric(5,0),
    purch_amt numeric(8,2),
    ord_date date,
    customer_id numeric(5,0),
    salesman_id numeric(5,0)
);


ALTER TABLE public.newtab OWNER TO postgres;

--
-- Name: newyorksalesman; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW newyorksalesman AS
 SELECT salesman.salesman_id,
    salesman.name,
    salesman.city,
    salesman.commission
   FROM salesman
  WHERE ((salesman.city)::text = 'new york'::text);


ALTER TABLE public.newyorksalesman OWNER TO postgres;

--
-- Name: newyorksalesman2; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW newyorksalesman2 AS
 SELECT salesman.salesman_id,
    salesman.name,
    salesman.city,
    salesman.commission
   FROM salesman
  WHERE ((salesman.city)::text = 'rome'::text);


ALTER TABLE public.newyorksalesman2 OWNER TO postgres;

--
-- Name: newyorksalesman3; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW newyorksalesman3 AS
 SELECT salesman.salesman_id,
    salesman.name,
    salesman.city,
    salesman.commission
   FROM salesman
  WHERE ((salesman.city)::text = 'Rome'::text);


ALTER TABLE public.newyorksalesman3 OWNER TO postgres;

--
-- Name: newyorkstaff; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW newyorkstaff AS
 SELECT salesman.salesman_id,
    salesman.name,
    salesman.city,
    salesman.commission
   FROM salesman
  WHERE ((salesman.city)::text = 'New York'::text);


ALTER TABLE public.newyorkstaff OWNER TO postgres;

--
-- Name: nobel_win; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE nobel_win (
    year integer,
    subject character(25),
    winner character(45),
    country character(25),
    category character(25)
);


ALTER TABLE public.nobel_win OWNER TO postgres;

--
-- Name: orders; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE orders (
    ord_no numeric(5,0) NOT NULL,
    purch_amt numeric(8,2) DEFAULT 0,
    ord_date date,
    customer_id numeric(5,0) NOT NULL,
    salesman_id numeric(5,0) NOT NULL
);


ALTER TABLE public.orders OWNER TO postgres;

--
-- Name: norders; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW norders AS
 SELECT salesman.name,
    avg(orders.purch_amt) AS avg,
    sum(orders.purch_amt) AS sum
   FROM salesman,
    orders
  WHERE (salesman.salesman_id = orders.salesman_id)
  GROUP BY salesman.name;


ALTER TABLE public.norders OWNER TO postgres;

--
-- Name: nros; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE nros (
    uno integer,
    dos integer
);


ALTER TABLE public.nros OWNER TO postgres;

--
-- Name: nuevo; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE nuevo (
    city character varying(15)
);


ALTER TABLE public.nuevo OWNER TO postgres;

--
-- Name: numbers; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE numbers (
    one integer,
    two integer,
    three integer
);


ALTER TABLE public.numbers OWNER TO postgres;

--
-- Name: numeri; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE numeri (
    id integer,
    data date,
    decimali real
);


ALTER TABLE public.numeri OWNER TO postgres;

--
-- Name: numeros; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE numeros (
    uno integer,
    dos integer
);


ALTER TABLE public.numeros OWNER TO postgres;

--
-- Name: odr; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW odr AS
 SELECT orders.ord_no
   FROM orders
  WHERE ((orders.ord_no >= (70002)::numeric) AND (orders.ord_no <= (70008)::numeric));


ALTER TABLE public.odr OWNER TO postgres;

--
-- Name: orozco; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE orozco (
    city character varying(15)
);


ALTER TABLE public.orozco OWNER TO postgres;

--
-- Name: partest1; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE partest1 (
    ord_num numeric(6,0) NOT NULL,
    ord_amount numeric(12,2),
    ord_date date NOT NULL,
    cust_code character(6) NOT NULL,
    agent_code character(6) NOT NULL
);


ALTER TABLE public.partest1 OWNER TO postgres;

--
-- Name: participant; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE participant (
    participant_id integer NOT NULL,
    part_name character varying(20) NOT NULL
);


ALTER TABLE public.participant OWNER TO postgres;

--
-- Name: participants; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE participants (
    participant_id integer NOT NULL,
    part_name character varying(20) NOT NULL
);


ALTER TABLE public.participants OWNER TO postgres;

--
-- Name: persons; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE persons (
    personid integer,
    lastname character varying(255),
    firstname character varying(255),
    address character varying(255),
    city character varying(255)
);


ALTER TABLE public.persons OWNER TO postgres;

--
-- Name: raster_overviews; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW raster_overviews AS
 SELECT current_database() AS o_table_catalog,
    n.nspname AS o_table_schema,
    c.relname AS o_table_name,
    a.attname AS o_raster_column,
    current_database() AS r_table_catalog,
    (split_part(split_part(s.consrc, '''::name'::text, 1), ''''::text, 2))::name AS r_table_schema,
    (split_part(split_part(s.consrc, '''::name'::text, 2), ''''::text, 2))::name AS r_table_name,
    (split_part(split_part(s.consrc, '''::name'::text, 3), ''''::text, 2))::name AS r_raster_column,
    (btrim(split_part(s.consrc, ','::text, 2)))::integer AS overview_factor
   FROM pg_class c,
    pg_attribute a,
    pg_type t,
    pg_namespace n,
    pg_constraint s
  WHERE ((((((((((t.typname = 'raster'::name) AND (a.attisdropped = false)) AND (a.atttypid = t.oid)) AND (a.attrelid = c.oid)) AND (c.relnamespace = n.oid)) AND ((c.relkind = 'r'::"char") OR (c.relkind = 'v'::"char"))) AND (s.connamespace = n.oid)) AND (s.conrelid = c.oid)) AND (s.consrc ~~ '%_overview_constraint(%'::text)) AND (NOT pg_is_other_temp_schema(c.relnamespace)));


ALTER TABLE public.raster_overviews OWNER TO postgres;

--
-- Name: regions; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE regions (
    region_id numeric(10,0) NOT NULL,
    region_name character(25)
);


ALTER TABLE public.regions OWNER TO postgres;

--
-- Name: related; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE related (
    city character varying(15)
);


ALTER TABLE public.related OWNER TO postgres;

--
-- Name: rightjoins; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW rightjoins AS
 SELECT t1.customer_id,
    t1.grade,
    t2.salesman_id
   FROM (customer t1
     RIGHT JOIN orders t2 ON ((t1.customer_id = t2.customer_id)))
  WHERE (t1.grade IS NOT NULL)
  ORDER BY t1.customer_id;


ALTER TABLE public.rightjoins OWNER TO postgres;

--
-- Name: salesdetail; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW salesdetail AS
 SELECT salesman.salesman_id,
    salesman.city,
    salesman.name
   FROM salesman;


ALTER TABLE public.salesdetail OWNER TO postgres;

--
-- Name: salesman_detail; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW salesman_detail AS
 SELECT salesman.salesman_id,
    salesman.city,
    salesman.name
   FROM salesman;


ALTER TABLE public.salesman_detail OWNER TO postgres;

--
-- Name: salesman_do1304; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE salesman_do1304 (
    salesman_id character varying(20),
    name character varying(40),
    city character varying(30),
    commission character varying(10)
);


ALTER TABLE public.salesman_do1304 OWNER TO postgres;

--
-- Name: salesman_example; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW salesman_example AS
 SELECT salesman.salesman_id,
    salesman.name,
    salesman.city
   FROM salesman;


ALTER TABLE public.salesman_example OWNER TO postgres;

--
-- Name: salesman_ny; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW salesman_ny AS
 SELECT salesman.salesman_id,
    salesman.city,
    salesman.commission
   FROM salesman
  WHERE (((salesman.city)::text = 'New York'::text) AND (salesman.commission > 0.13));


ALTER TABLE public.salesman_ny OWNER TO postgres;

--
-- Name: salesmandetail; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW salesmandetail AS
 SELECT salesman.salesman_id,
    salesman.city,
    salesman.name
   FROM salesman;


ALTER TABLE public.salesmandetail OWNER TO postgres;

--
-- Name: salesown; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW salesown AS
 SELECT salesman.salesman_id,
    salesman.name,
    salesman.city
   FROM salesman;


ALTER TABLE public.salesown OWNER TO postgres;

--
-- Name: sample_table; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE sample_table (
    salesman_id character(4),
    name character varying(20),
    city character varying(20),
    commission character(10)
);


ALTER TABLE public.sample_table OWNER TO postgres;

--
-- Name: scores; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE scores (
    id integer NOT NULL,
    score integer
);


ALTER TABLE public.scores OWNER TO postgres;

--
-- Name: statements; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE statements (
    name text
);


ALTER TABLE public.statements OWNER TO postgres;

--
-- Name: student; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE student (
    roll integer,
    name character varying
);


ALTER TABLE public.student OWNER TO postgres;

--
-- Name: student1; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE student1 (
    roll integer,
    name character varying
);


ALTER TABLE public.student1 OWNER TO postgres;

--
-- Name: sum; Type: TABLE; Schema: public; Owner: user3; Tablespace: 
--

CREATE TABLE sum (
    "?column?" integer
);


ALTER TABLE public.sum OWNER TO user3;

--
-- Name: sybba; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE sybba (
    ord_num numeric(6,0) NOT NULL,
    ord_amount numeric(12,2),
    ord_date date NOT NULL,
    cust_code character(6) NOT NULL,
    agent_code character(6) NOT NULL
);


ALTER TABLE public.sybba OWNER TO postgres;

--
-- Name: temp; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE temp (
    customer_id numeric(5,0),
    cust_name character varying(30),
    city character varying(15),
    grade numeric(3,0),
    salesman_id numeric(5,0)
);


ALTER TABLE public.temp OWNER TO postgres;

--
-- Name: temp_table; Type: TABLE; Schema: public; Owner: user3; Tablespace: 
--

CREATE TABLE temp_table (
    employee_id numeric(6,0),
    first_name character varying(20),
    last_name character varying(25),
    email character varying(25),
    phone_number character varying(20),
    hire_date date,
    job_id character varying(10),
    salary numeric(8,2),
    commission_pct numeric(2,2),
    manager_id numeric(6,0)
);


ALTER TABLE public.temp_table OWNER TO user3;

--
-- Name: tempa; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE tempa (
    customer_id numeric(5,0),
    cust_name character varying(30),
    city character varying(15),
    grade numeric(3,0),
    salesman_id numeric(5,0)
);


ALTER TABLE public.tempa OWNER TO postgres;

--
-- Name: tempcustomer; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE tempcustomer (
    customer_id numeric(5,0),
    cust_name character varying(30),
    city character varying(15),
    grade numeric(3,0),
    salesman_id numeric(5,0)
);


ALTER TABLE public.tempcustomer OWNER TO postgres;

--
-- Name: temphi; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE temphi (
    salesman_id numeric(5,0),
    name character varying(30),
    city character varying(15),
    commission numeric(5,2)
);


ALTER TABLE public.temphi OWNER TO postgres;

--
-- Name: tempp; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE tempp (
    customer_id numeric(5,0),
    cust_name character varying(30),
    city character varying(15),
    grade numeric(3,0),
    salesman_id numeric(5,0)
);


ALTER TABLE public.tempp OWNER TO postgres;

--
-- Name: tempp11; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE tempp11 (
    customer_id numeric(5,0),
    cust_name character varying(30),
    city character varying(15),
    grade numeric(3,0),
    salesman_id numeric(5,0)
);


ALTER TABLE public.tempp11 OWNER TO postgres;

--
-- Name: tempsalesman; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE tempsalesman (
    salesman_id numeric(5,0),
    name character varying(30),
    city character varying(15),
    commission numeric(5,2)
);


ALTER TABLE public.tempsalesman OWNER TO postgres;

--
-- Name: temptable; Type: TABLE; Schema: public; Owner: user3; Tablespace: 
--

CREATE TABLE temptable (
    dpt_code integer,
    dpt_name character(15),
    dpt_allotment integer
);


ALTER TABLE public.temptable OWNER TO user3;

--
-- Name: testtable; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE testtable (
    col1 character varying(30) NOT NULL
);


ALTER TABLE public.testtable OWNER TO postgres;

--
-- Name: TABLE testtable; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE testtable IS 'a temporary table for some queries ';


--
-- Name: testtesing; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW testtesing AS
 SELECT salesman.salesman_id,
    salesman.name,
    salesman.city
   FROM salesman
  WHERE ((salesman.city)::text = 'New York'::text);


ALTER TABLE public.testtesing OWNER TO postgres;

--
-- Name: testtest; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW testtest AS
 SELECT salesman.salesman_id,
    salesman.name,
    salesman.city
   FROM salesman;


ALTER TABLE public.testtest OWNER TO postgres;

--
-- Name: trenta; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE trenta (
    numeri integer
);


ALTER TABLE public.trenta OWNER TO postgres;

--
-- Name: v1; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW v1 AS
 SELECT o.ord_no,
    c.cust_name,
    s.name
   FROM ((orders o
     JOIN customer c ON ((o.customer_id = c.customer_id)))
     JOIN salesman s ON ((o.salesman_id = s.salesman_id)));


ALTER TABLE public.v1 OWNER TO postgres;

--
-- Name: view; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW view AS
 SELECT salesman.salesman_id,
    salesman.name,
    salesman.city
   FROM salesman;


ALTER TABLE public.view OWNER TO postgres;

--
-- Name: vowl; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE vowl (
    cust_name character varying(30),
    "substring" text
);


ALTER TABLE public.vowl OWNER TO postgres;

--
-- Name: zebras; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE zebras (
    id integer NOT NULL,
    score integer,
    date date DEFAULT now()
);


ALTER TABLE public.zebras OWNER TO postgres;

--
-- Data for Name: address; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY address (city) FROM stdin;
New York
New York
Moncow
California
London
Paris
Berlin
London
\.


--
-- Data for Name: bh; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY bh (name, emp_id, process) FROM stdin;
Pandey	333445	Mobile
Bhupinder	301144	Mobile
Kapil	301146	Mobile
Sanjay	301147	Mobile
Manjeet	301145	Mobile
\.


--
-- Data for Name: c; Type: TABLE DATA; Schema: public; Owner: user3
--

COPY c (com_name, pro_name, pro_price) FROM stdin;
Asus                	Mother Board             	3200.00
Epsion              	Refill cartridge         	350.00
Epsion              	Printer                  	2600.00
Frontech            	Key Board                	450.00
Frontech            	Speaker                  	550.00
iBall               	Mouse                    	250.00
iBall               	CD drive                 	800.00
iBall               	DVD drive                	900.00
Samsung             	Monitor                  	5000.00
Zebronics           	ZIP drive                	250.00
\.


--
-- Data for Name: casino; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY casino (pricerange, events, location, casino) FROM stdin;
\.


--
-- Data for Name: col1; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY col1 ("?column?") FROM stdin;
1
\.


--
-- Data for Name: company_mast; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY company_mast (com_id, com_name) FROM stdin;
11	Samsung             
12	iBall               
13	Epsion              
14	Zebronics           
15	Asus                
16	Frontech            
\.


--
-- Data for Name: countries; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY countries (country_id, country_name, region_id) FROM stdin;
AR	Argentina	2
AU	Australia	3
BE	Belgium	1
BR	Brazil	2
CA	Canada	2
CH	Switzerland	1
CN	China	3
DE	Germany	1
DK	Denmark	1
EG	Egypt	4
FR	France	1
HK	HongKong	3
IL	Israel	4
IN	India	3
IT	Italy	1
JP	Japan	3
KW	Kuwait	4
MX	Mexico	2
NG	Nigeria	4
NL	Netherlands	1
SG	Singapore	3
UK	United Kingdom	1
US	United States of America	2
ZM	Zambia	4
ZW	Zimbabwe	4
\.


--
-- Data for Name: customer; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY customer (customer_id, cust_name, city, grade, salesman_id) FROM stdin;
3002	Nick Rimando	New York	100	5001
3007	Brad Davis	New York	200	5001
3005	Graham Zusi	California	200	5002
3008	Julian Green	London	300	5002
3004	Fabian Johnson	Paris	300	5006
3009	Geoff Cameron	Berlin	100	5003
3001	Brad Guzan	London	\N	5005
3003	Jozy Altidor	Moscow	200	5007
\.


--
-- Data for Name: customer_backup; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY customer_backup (customer_id, cust_name, city, grade, salesman_id) FROM stdin;
3002	Nick Rimando	New York	100	5001
3007	Brad Davis	New York	200	5001
3003	Jozy Altidor	Moncow	200	5007
3005	Graham Zusi	California	200	5002
3008	Julian Green	London	300	5002
3004	Fabian Johnson	Paris	300	5006
3009	Geoff Cameron	Berlin	100	5003
3001	Brad Guzan	London	\N	5005
\.


--
-- Data for Name: departments; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY departments (department_id, department_name, manager_id, location_id) FROM stdin;
10	Administration	200	1700
20	Marketing	201	1800
30	Purchasing	114	1700
40	Human Resources	203	2400
50	Shipping	121	1500
60	IT	103	1400
70	Public Relations	204	2700
80	Sales	145	2500
90	Executive	100	1700
100	Finance	108	1700
110	Accounting	205	1700
120	Treasury	0	1700
130	Corporate Tax	0	1700
140	Control And Credit	0	1700
150	Shareholder Services	0	1700
160	Benefits	0	1700
170	Manufacturing	0	1700
180	Construction	0	1700
190	Contracting	0	1700
200	Operations	0	1700
210	IT Support	0	1700
220	NOC	0	1700
230	IT Helpdesk	0	1700
240	Government Sales	0	1700
250	Retail Sales	0	1700
260	Recruiting	0	1700
270	Payroll	0	1700
\.


--
-- Data for Name: elephants; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY elephants (id, name, date) FROM stdin;
1	\N	2015-12-15
2	\N	2015-12-15
\.


--
-- Data for Name: emp; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY emp (ename, salary, eid) FROM stdin;
\.


--
-- Data for Name: emp_department; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY emp_department (dpt_code, dpt_name, dpt_allotment) FROM stdin;
57	IT             	65000
63	Finance        	15000
47	HR             	240000
27	RD             	55000
89	QC             	75000
\.


--
-- Data for Name: emp_details; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY emp_details (emp_idno, emp_fname, emp_lname, emp_dept) FROM stdin;
631548	Alan           	Snappy         	27
839139	Maria          	Foster         	57
127323	Michale        	Robbin         	57
526689	Carlos         	Snares         	63
843795	Enric          	Dosio          	57
328717	Jhon           	Snares         	63
444527	Joseph         	Dosni          	47
659831	Zanifer        	Emily          	47
847674	Kuleswar       	Sitaraman      	57
748681	Henrey         	Gabriel        	47
555935	Alex           	Manuel         	57
539569	George         	Mardy          	27
733843	Mario          	Saule          	63
\.


--
-- Data for Name: employee; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY employee (empno, ename) FROM stdin;
\.


--
-- Data for Name: employees; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY employees (employee_id, first_name, last_name, email, phone_number, hire_date, job_id, salary, commission_pct, manager_id, department_id) FROM stdin;
145	John	Russell	JRUSSEL	011.44.1344.429268	1987-08-01	SA_MAN	14000.00	0.40	100	80
146	Karen	Partners	KPARTNER	011.44.1344.467268	1987-08-02	SA_MAN	13500.00	0.30	100	80
147	Alberto	Errazuriz	AERRAZUR	011.44.1344.429278	1987-08-03	SA_MAN	12000.00	0.30	100	80
148	Gerald	Cambrault	GCAMBRAU	011.44.1344.619268	1987-08-04	SA_MAN	11000.00	0.30	100	80
149	Eleni	Zlotkey	EZLOTKEY	011.44.1344.429018	1987-08-05	SA_MAN	10500.00	0.20	100	80
150	Peter	Tucker	PTUCKER	011.44.1344.129268	1987-08-06	SA_REP	10000.00	0.30	145	80
151	David	Bernstein	DBERNSTE	011.44.1344.345268	1987-08-07	SA_REP	9500.00	0.25	145	80
152	Peter	Hall	PHALL	011.44.1344.478968	1987-08-08	SA_REP	9000.00	0.25	145	80
153	Christopher	Olsen	COLSEN	011.44.1344.498718	1987-08-09	SA_REP	8000.00	0.20	145	80
154	Nanette	Cambrault	NCAMBRAU	011.44.1344.987668	1987-08-10	SA_REP	7500.00	0.20	145	80
155	Oliver	Tuvault	OTUVAULT	011.44.1344.486508	1987-08-11	SA_REP	7000.00	0.15	145	80
156	Janette	King	JKING	011.44.1345.429268	1987-08-12	SA_REP	10000.00	0.35	146	80
157	Patrick	Sully	PSULLY	011.44.1345.929268	1987-08-13	SA_REP	9500.00	0.35	146	80
158	Allan	McEwen	AMCEWEN	011.44.1345.829268	1987-08-14	SA_REP	9000.00	0.35	146	80
159	Lindsey	Smith	LSMITH	011.44.1345.729268	1987-08-15	SA_REP	8000.00	0.30	146	80
160	Louise	Doran	LDORAN	011.44.1345.629268	1987-08-16	SA_REP	7500.00	0.30	146	80
161	Sarath	Sewall	SSEWALL	011.44.1345.529268	1987-08-17	SA_REP	7000.00	0.25	146	80
162	Clara	Vishney	CVISHNEY	011.44.1346.129268	1987-08-18	SA_REP	10500.00	0.25	147	80
163	Danielle	Greene	DGREENE	011.44.1346.229268	1987-08-19	SA_REP	9500.00	0.15	147	80
164	Mattea	Marvins	MMARVINS	011.44.1346.329268	1987-08-20	SA_REP	7200.00	0.10	147	80
165	David	Lee	DLEE	011.44.1346.529268	1987-08-21	SA_REP	6800.00	0.10	147	80
166	Sundar	Ande	SANDE	011.44.1346.629268	1987-08-22	SA_REP	6400.00	0.10	147	80
167	Amit	Banda	ABANDA	011.44.1346.729268	1987-08-23	SA_REP	6200.00	0.10	147	80
168	Lisa	Ozer	LOZER	011.44.1343.929268	1987-08-24	SA_REP	11500.00	0.25	148	80
169	Harrison	Bloom	HBLOOM	011.44.1343.829268	1987-08-25	SA_REP	10000.00	0.20	148	80
170	Tayler	Fox	TFOX	011.44.1343.729268	1987-08-26	SA_REP	9600.00	0.20	148	80
171	William	Smith	WSMITH	011.44.1343.629268	1987-08-27	SA_REP	7400.00	0.15	148	80
172	Elizabeth	Bates	EBATES	011.44.1343.529268	1987-08-28	SA_REP	7300.00	0.15	148	80
173	Sundita	Kumar	SKUMAR	011.44.1343.329268	1987-08-29	SA_REP	6100.00	0.10	148	80
174	Ellen	Abel	EABEL	011.44.1644.429267	1987-08-30	SA_REP	11000.00	0.30	149	80
175	Alyssa	Hutton	AHUTTON	011.44.1644.429266	1987-08-31	SA_REP	8800.00	0.25	149	80
176	Jonathon	Taylor	JTAYLOR	011.44.1644.429265	1987-09-01	SA_REP	8600.00	0.20	149	80
177	Jack	Livingston	JLIVINGS	011.44.1644.429264	1987-09-02	SA_REP	8400.00	0.20	149	80
179	Charles	Johnson	CJOHNSON	011.44.1644.429262	1987-09-04	SA_REP	6200.00	0.10	149	80
178	Kimberely	Grant	KGRANT	011.44.1644.429263	1987-09-03	SA_REP	7000.00	0.15	149	\N
101	Neena	Kochhar	NKOCHHAR	515.123.4568	1987-06-18	AD_VP	17000.00	\N	100	90
102	Lex	De Haan	LDEHAAN	515.123.4569	1987-06-19	AD_VP	17000.00	\N	100	90
103	Alexander	Hunold	AHUNOLD	590.423.4567	1987-06-20	IT_PROG	9000.00	\N	102	60
104	Bruce	Ernst	BERNST	590.423.4568	1987-06-21	IT_PROG	6000.00	\N	103	60
105	David	Austin	DAUSTIN	590.423.4569	1987-06-22	IT_PROG	4800.00	\N	103	60
106	Valli	Pataballa	VPATABAL	590.423.4560	1987-06-23	IT_PROG	4800.00	\N	103	60
107	Diana	Lorentz	DLORENTZ	590.423.5567	1987-06-24	IT_PROG	4200.00	\N	103	60
108	Nancy	Greenberg	NGREENBE	515.124.4569	1987-06-25	FI_MGR	12000.00	\N	101	100
109	Daniel	Faviet	DFAVIET	515.124.4169	1987-06-26	FI_ACCOUNT	9000.00	\N	108	100
110	John	Chen	JCHEN	515.124.4269	1987-06-27	FI_ACCOUNT	8200.00	\N	108	100
111	Ismael	Sciarra	ISCIARRA	515.124.4369	1987-06-28	FI_ACCOUNT	7700.00	\N	108	100
112	Jose Manuel	Urman	JMURMAN	515.124.4469	1987-06-29	FI_ACCOUNT	7800.00	\N	108	100
113	Luis	Popp	LPOPP	515.124.4567	1987-06-30	FI_ACCOUNT	6900.00	\N	108	100
114	Den	Raphaely	DRAPHEAL	515.127.4561	1987-07-01	PU_MAN	11000.00	\N	100	30
115	Alexander	Khoo	AKHOO	515.127.4562	1987-07-02	PU_CLERK	3100.00	\N	114	30
116	Shelli	Baida	SBAIDA	515.127.4563	1987-07-03	PU_CLERK	2900.00	\N	114	30
117	Sigal	Tobias	STOBIAS	515.127.4564	1987-07-04	PU_CLERK	2800.00	\N	114	30
118	Guy	Himuro	GHIMURO	515.127.4565	1987-07-05	PU_CLERK	2600.00	\N	114	30
119	Karen	Colmenares	KCOLMENA	515.127.4566	1987-07-06	PU_CLERK	2500.00	\N	114	30
120	Matthew	Weiss	MWEISS	650.123.1234	1987-07-07	ST_MAN	8000.00	\N	100	50
121	Adam	Fripp	AFRIPP	650.123.2234	1987-07-08	ST_MAN	8200.00	\N	100	50
122	Payam	Kaufling	PKAUFLIN	650.123.3234	1987-07-09	ST_MAN	7900.00	\N	100	50
123	Shanta	Vollman	SVOLLMAN	650.123.4234	1987-07-10	ST_MAN	6500.00	\N	100	50
124	Kevin	Mourgos	KMOURGOS	650.123.5234	1987-07-11	ST_MAN	5800.00	\N	100	50
125	Julia	Nayer	JNAYER	650.124.1214	1987-07-12	ST_CLERK	3200.00	\N	120	50
126	Irene	Mikkilineni	IMIKKILI	650.124.1224	1987-07-13	ST_CLERK	2700.00	\N	120	50
127	James	Landry	JLANDRY	650.124.1334	1987-07-14	ST_CLERK	2400.00	\N	120	50
128	Steven	Markle	SMARKLE	650.124.1434	1987-07-15	ST_CLERK	2200.00	\N	120	50
129	Laura	Bissot	LBISSOT	650.124.5234	1987-07-16	ST_CLERK	3300.00	\N	121	50
130	Mozhe	Atkinson	MATKINSO	650.124.6234	1987-07-17	ST_CLERK	2800.00	\N	121	50
131	James	Marlow	JAMRLOW	650.124.7234	1987-07-18	ST_CLERK	2500.00	\N	121	50
132	TJ	Olson	TJOLSON	650.124.8234	1987-07-19	ST_CLERK	2100.00	\N	121	50
133	Jason	Mallin	JMALLIN	650.127.1934	1987-07-20	ST_CLERK	3300.00	\N	122	50
134	Michael	Rogers	MROGERS	650.127.1834	1987-07-21	ST_CLERK	2900.00	\N	122	50
135	Ki	Gee	KGEE	650.127.1734	1987-07-22	ST_CLERK	2400.00	\N	122	50
136	Hazel	Philtanker	HPHILTAN	650.127.1634	1987-07-23	ST_CLERK	2200.00	\N	122	50
137	Renske	Ladwig	RLADWIG	650.121.1234	1987-07-24	ST_CLERK	3600.00	\N	123	50
138	Stephen	Stiles	SSTILES	650.121.2034	1987-07-25	ST_CLERK	3200.00	\N	123	50
139	John	Seo	JSEO	650.121.2019	1987-07-26	ST_CLERK	2700.00	\N	123	50
140	Joshua	Patel	JPATEL	650.121.1834	1987-07-27	ST_CLERK	2500.00	\N	123	50
141	Trenna	Rajs	TRAJS	650.121.8009	1987-07-28	ST_CLERK	3500.00	\N	124	50
142	Curtis	Davies	CDAVIES	650.121.2994	1987-07-29	ST_CLERK	3100.00	\N	124	50
143	Randall	Matos	RMATOS	650.121.2874	1987-07-30	ST_CLERK	2600.00	\N	124	50
144	Peter	Vargas	PVARGAS	650.121.2004	1987-07-31	ST_CLERK	2500.00	\N	124	50
180	Winston	Taylor	WTAYLOR	650.507.9876	1987-09-05	SH_CLERK	3200.00	\N	120	50
100	Steven	King	SKING	515.123.4567	1987-06-17	AD_PRES	24000.00	\N	\N	90
181	Jean	Fleaur	JFLEAUR	650.507.9877	1987-09-06	SH_CLERK	3100.00	\N	120	50
182	Martha	Sullivan	MSULLIVA	650.507.9878	1987-09-07	SH_CLERK	2500.00	\N	120	50
183	Girard	Geoni	GGEONI	650.507.9879	1987-09-08	SH_CLERK	2800.00	\N	120	50
184	Nandita	Sarchand	NSARCHAN	650.509.1876	1987-09-09	SH_CLERK	4200.00	\N	121	50
185	Alexis	Bull	ABULL	650.509.2876	1987-09-10	SH_CLERK	4100.00	\N	121	50
186	Julia	Dellinger	JDELLING	650.509.3876	1987-09-11	SH_CLERK	3400.00	\N	121	50
187	Anthony	Cabrio	ACABRIO	650.509.4876	1987-09-12	SH_CLERK	3000.00	\N	121	50
188	Kelly	Chung	KCHUNG	650.505.1876	1987-09-13	SH_CLERK	3800.00	\N	122	50
189	Jennifer	Dilly	JDILLY	650.505.2876	1987-09-14	SH_CLERK	3600.00	\N	122	50
190	Timothy	Gates	TGATES	650.505.3876	1987-09-15	SH_CLERK	2900.00	\N	122	50
191	Randall	Perkins	RPERKINS	650.505.4876	1987-09-16	SH_CLERK	2500.00	\N	122	50
192	Sarah	Bell	SBELL	650.501.1876	1987-09-17	SH_CLERK	4000.00	\N	123	50
193	Britney	Everett	BEVERETT	650.501.2876	1987-09-18	SH_CLERK	3900.00	\N	123	50
194	Samuel	McCain	SMCCAIN	650.501.3876	1987-09-19	SH_CLERK	3200.00	\N	123	50
195	Vance	Jones	VJONES	650.501.4876	1987-09-20	SH_CLERK	2800.00	\N	123	50
196	Alana	Walsh	AWALSH	650.507.9811	1987-09-21	SH_CLERK	3100.00	\N	124	50
197	Kevin	Feeney	KFEENEY	650.507.9822	1987-09-22	SH_CLERK	3000.00	\N	124	50
198	Donald	OConnell	DOCONNEL	650.507.9833	1987-09-23	SH_CLERK	2600.00	\N	124	50
199	Douglas	Grant	DGRANT	650.507.9844	1987-09-24	SH_CLERK	2600.00	\N	124	50
200	Jennifer	Whalen	JWHALEN	515.123.4444	1987-09-25	AD_ASST	4400.00	\N	101	10
201	Michael	Hartstein	MHARTSTE	515.123.5555	1987-09-26	MK_MAN	13000.00	\N	100	20
202	Pat	Fay	PFAY	603.123.6666	1987-09-27	MK_REP	6000.00	\N	201	20
203	Susan	Mavris	SMAVRIS	515.123.7777	1987-09-28	HR_REP	6500.00	\N	101	40
204	Hermann	Baer	HBAER	515.123.8888	1987-09-29	PR_REP	10000.00	\N	101	70
205	Shelley	Higgins	SHIGGINS	515.123.8080	1987-09-30	AC_MGR	12000.00	\N	101	110
206	William	Gietz	WGIETZ	515.123.8181	1987-10-01	AC_ACCOUNT	8300.00	\N	205	110
\.


--
-- Data for Name: game_scores; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY game_scores (id, name, score) FROM stdin;
1	James	90
2	James	55
3	James	150
4	James	50
5	Mary	110
6	Mary	160
7	Ron	120
8	Ron	90
9	Ron	200
\.


--
-- Data for Name: grade; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY grade (city) FROM stdin;
New York
New York
Moncow
California
London
Paris
Berlin
London
\.


--
-- Data for Name: grades; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY grades (id, grade_1, grade_2, grade_3) FROM stdin;
1	75	25	80
2	85	85	60
3	70	75	65
\.


--
-- Data for Name: hello; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY hello (number_one, number_two, number_three) FROM stdin;
\.


--
-- Data for Name: hello1_1122; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY hello1_1122 (abc) FROM stdin;
\.


--
-- Data for Name: hello1_12; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY hello1_12 (abc) FROM stdin;
\.


--
-- Data for Name: hello_12; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY hello_12 (abc) FROM stdin;
\.


--
-- Data for Name: item_mast; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY item_mast (pro_id, pro_name, pro_price, pro_com) FROM stdin;
101	Mother Board             	3200.00	15
102	Key Board                	450.00	16
103	ZIP drive                	250.00	14
104	Speaker                  	550.00	16
105	Monitor                  	5000.00	11
106	DVD drive                	900.00	12
107	CD drive                 	800.00	12
108	Printer                  	2600.00	13
109	Refill cartridge         	350.00	13
110	Mouse                    	250.00	12
\.


--
-- Data for Name: job_grades; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY job_grades (grade_level, lowest_sal, highest_sal) FROM stdin;
A 	1000	2999
B 	3000	5999
C 	6000	9999
D 	10000	14999
E 	15000	24999
F 	25000	40000
\.


--
-- Data for Name: job_history; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY job_history (employee_id, start_date, end_date, job_id, department_id) FROM stdin;
102	1993-01-13	1998-07-24	IT_PROG	60
101	1989-09-21	1993-10-27	AC_ACCOUNT	110
101	1993-10-28	1997-03-15	AC_MGR	110
201	1996-02-17	1999-12-19	MK_REP	20
114	1998-03-24	1999-12-31	ST_CLERK	50
122	1999-01-01	1999-12-31	ST_CLERK	50
200	1987-09-17	1993-06-17	AD_ASST	90
176	1998-03-24	1998-12-31	SA_REP	80
176	1999-01-01	1999-12-31	SA_MAN	80
200	1994-07-01	1998-12-31	AC_ACCOUNT	90
\.


--
-- Data for Name: jobs; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY jobs (job_id, job_title, min_salary, max_salary) FROM stdin;
AD_PRES	President	20000	40000
AD_VP	Administration Vice President	15000	30000
AD_ASST	Administration Assistant	3000	6000
FI_MGR	Finance Manager	8200	16000
FI_ACCOUNT	Accountant	4200	9000
AC_MGR	Accounting Manager	8200	16000
AC_ACCOUNT	Public Accountant	4200	9000
SA_MAN	Sales Manager	10000	20000
SA_REP	Sales Representative	6000	12000
PU_MAN	Purchasing Manager	8000	15000
PU_CLERK	Purchasing Clerk	2500	5500
ST_MAN	Stock Manager	5500	8500
ST_CLERK	Stock Clerk	2000	5000
SH_CLERK	Shipping Clerk	2500	5500
IT_PROG	Programmer	4000	10000
MK_MAN	Marketing Manager	9000	15000
MK_REP	Marketing Representative	4000	9000
HR_REP	Human Resources Representative	4000	9000
PR_REP	Public Relations Representative	4500	10500
\.


--
-- Data for Name: locations; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY locations (location_id, street_address, postal_code, city, state_province, country_id) FROM stdin;
1000	1297 Via Cola di Rie	989	Roma		IT
1100	93091 Calle della Testa	10934	Venice		IT
1200	2017 Shinjuku-ku	1689	Tokyo	Tokyo Prefecture	JP
1300	9450 Kamiya-cho	6823	Hiroshima		JP
1400	2014 Jabberwocky Rd	26192	Southlake	Texas	US
1500	2011 Interiors Blvd	99236	South San Francisco	California	US
1600	2007 Zagora St	50090	South Brunswick	New Jersey	US
1700	2004 Charade Rd	98199	Seattle	Washington	US
1800	147 Spadina Ave	M5V 2L7	Toronto	Ontario	CA
1900	6092 Boxwood St	YSW 9T2	Whitehorse	Yukon	CA
2000	40-5-12 Laogianggen	190518	Beijing		CN
2100	1298 Vileparle (E)	490231	Bombay	Maharashtra	IN
2200	12-98 Victoria Street	2901	Sydney	New South Wales	AU
2300	198 Clementi North	540198	Singapore		SG
2400	8204 Arthur St		London		UK
2500	"Magdalen Centre	 The Oxford 	OX9 9ZB	Oxford	Ox
2600	9702 Chester Road	9629850293	Stretford	Manchester	UK
2700	Schwanthalerstr. 7031	80925	Munich	Bavaria	DE
2800	Rua Frei Caneca 1360	01307-002	Sao Paulo	Sao Paulo	BR
2900	20 Rue des Corps-Saints	1730	Geneva	Geneve	CH
3000	Murtenstrasse 921	3095	Bern	BE	CH
3100	Pieter Breughelstraat 837	3029SK	Utrecht	Utrecht	NL
3200	Mariano Escobedo 9991	11932	Mexico City	"Distrito Federal	"
\.


--
-- Data for Name: maxim00; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY maxim00 (num, name) FROM stdin;
\.


--
-- Data for Name: maximum; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY maximum (num, name) FROM stdin;
\.


--
-- Data for Name: maximum00; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY maximum00 (num, name) FROM stdin;
\.


--
-- Data for Name: maximum899; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY maximum899 (num, name) FROM stdin;
\.


--
-- Data for Name: mytest; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY mytest (ord_num, ord_amount, ord_date, cust_code, agent_code) FROM stdin;
\.


--
-- Data for Name: mytest1; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY mytest1 (ord_num, ord_amount, ord_date, cust_code, agent_code) FROM stdin;
\.


--
-- Data for Name: new; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY new (city) FROM stdin;
New York
\.


--
-- Data for Name: new123; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY new123 ("Customer", city, "Salesman", commission) FROM stdin;
Nick Rimando	New York	James Hoog	0.15
Graham Zusi	California	Nail Knite	0.13
Brad Guzan	London	Pit Alex	0.11
Fabian Johns	Paris	Mc Lyon	0.14
Brad Davis	New York	James Hoog	0.15
Geoff Camero	Berlin	Lauson Hen	0.12
Julian Green	London	Nail Knite	0.13
Jozy Altidor	Moncow	Paul Adam	0.13
\.


--
-- Data for Name: new_table; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY new_table (salesman_id, name, city, commission) FROM stdin;
5002	Nail Knite	Paris	0.13
5005	Pit Alex	London	0.11
5006	Mc Lyon	Paris	0.14
5003	Lauson Hense	\N	0.12
5007	Paul Adam	Rome	0.13
\.


--
-- Data for Name: newtab; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY newtab (ord_no, purch_amt, ord_date, customer_id, salesman_id) FROM stdin;
70009	270.65	2012-09-10	3001	5005
70002	65.26	2012-10-05	3002	5001
70004	110.50	2012-08-17	3009	5003
70005	2400.60	2012-07-27	3007	5001
70008	5760.00	2012-09-10	3002	5001
70010	1983.43	2012-10-10	3004	5006
70003	2480.40	2012-10-10	3009	5003
70011	75.29	2012-08-17	3003	5007
70013	3045.60	2012-04-25	3002	5001
70001	150.50	2012-10-05	3005	5002
70007	948.50	2012-09-10	3005	5002
70012	250.45	2012-06-27	3008	5002
\.


--
-- Data for Name: nobel_win; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY nobel_win (year, subject, winner, country, category) FROM stdin;
1970	Physics                  	Hannes Alfven                                	Sweden                   	Scientist                
1970	Physics                  	Louis Neel                                   	France                   	Scientist                
1970	Chemistry                	Luis Federico Leloir                         	France                   	Scientist                
1970	Physiology               	Julius Axelrod                               	USA                      	Scientist                
1970	Physiology               	Ulf von Euler                                	Sweden                   	Scientist                
1970	Physiology               	Bernard Katz                                 	Germany                  	Scientist                
1970	Literature               	Aleksandr Solzhenitsyn                       	Russia                   	Linguist                 
1970	Economics                	Paul Samuelson                               	USA                      	Economist                
1971	Physics                  	Dennis Gabor                                 	Hungary                  	Scientist                
1971	Chemistry                	Gerhard Herzberg                             	Germany                  	Scientist                
1971	Peace                    	Willy Brandt                                 	Germany                  	Chancellor               
1971	Literature               	Pablo Neruda                                 	Chile                    	Linguist                 
1971	Economics                	Simon Kuznets                                	Russia                   	Economist                
1978	Peace                    	Anwar al-Sadat                               	Egypt                    	President                
1978	Peace                    	Menachem Begin                               	Israel                   	Prime Minister           
1994	Peace                    	Yitzhak Rabin                                	Israel                   	Prime Minister           
1987	Physics                  	Johannes Georg Bednorz                       	Germany                  	Scientist                
1987	Chemistry                	Donald J. Cram                               	USA                      	Scientist                
1987	Chemistry                	Jean-Marie Lehn                              	France                   	Scientist                
1987	Physiology               	Susumu Tonegawa                              	Japan                    	Scientist                
1987	Literature               	Joseph Brodsky                               	Russia                   	Linguist                 
1987	Economics                	Robert Solow                                 	USA                      	Economist                
1994	Literature               	Kenzaburo Oe                                 	Japan                    	Linguist                 
1994	Economics                	Reinhard Selten                              	Germany                  	Economist                
\.


--
-- Data for Name: nros; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY nros (uno, dos) FROM stdin;
\.


--
-- Data for Name: nuevo; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY nuevo (city) FROM stdin;
New York
\.


--
-- Data for Name: numbers; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY numbers (one, two, three) FROM stdin;
\.


--
-- Data for Name: numeri; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY numeri (id, data, decimali) FROM stdin;
\.


--
-- Data for Name: numeros; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY numeros (uno, dos) FROM stdin;
\.


--
-- Data for Name: orders; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY orders (ord_no, purch_amt, ord_date, customer_id, salesman_id) FROM stdin;
70009	270.65	2012-09-10	3001	5005
70002	65.26	2012-10-05	3002	5001
70004	110.50	2012-08-17	3009	5003
70005	2400.60	2012-07-27	3007	5001
70008	5760.00	2012-09-10	3002	5001
70010	1983.43	2012-10-10	3004	5006
70003	2480.40	2012-10-10	3009	5003
70011	75.29	2012-08-17	3003	5007
70013	3045.60	2012-04-25	3002	5001
70001	150.50	2012-10-05	3005	5002
70007	948.50	2012-09-10	3005	5002
70012	250.45	2012-06-27	3008	5002
\.


--
-- Data for Name: orozco; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY orozco (city) FROM stdin;
New York
\.


--
-- Data for Name: partest1; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY partest1 (ord_num, ord_amount, ord_date, cust_code, agent_code) FROM stdin;
\.


--
-- Data for Name: participant; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY participant (participant_id, part_name) FROM stdin;
\.


--
-- Data for Name: participants; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY participants (participant_id, part_name) FROM stdin;
\.


--
-- Data for Name: persons; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY persons (personid, lastname, firstname, address, city) FROM stdin;
\.


--
-- Data for Name: regions; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY regions (region_id, region_name) FROM stdin;
1	Europe                   
2	Americas                 
3	Asia                     
4	Middle East and Africa   
\.


--
-- Data for Name: related; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY related (city) FROM stdin;
New York
\.


--
-- Data for Name: salesman; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY salesman (salesman_id, name, city, commission) FROM stdin;
5001	James Hoog	New York	0.15
5002	Nail Knite	Paris	0.13
5005	Pit Alex	London	0.11
5006	Mc Lyon	Paris	0.14
5007	Paul Adam	Rome	0.13
5003	Lauson Hen	San Jose	0.12
\.


--
-- Data for Name: salesman_do1304; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY salesman_do1304 (salesman_id, name, city, commission) FROM stdin;
\.


--
-- Data for Name: sample_table; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY sample_table (salesman_id, name, city, commission) FROM stdin;
\.


--
-- Data for Name: scores; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY scores (id, score) FROM stdin;
1	100
\.


--
-- Data for Name: statements; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY statements (name) FROM stdin;
This is SQL Exercise, Practice and Solution
\.


--
-- Data for Name: student; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY student (roll, name) FROM stdin;
\.


--
-- Data for Name: student1; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY student1 (roll, name) FROM stdin;
\.


--
-- Data for Name: sum; Type: TABLE DATA; Schema: public; Owner: user3
--

COPY sum ("?column?") FROM stdin;
25
\.


--
-- Data for Name: sybba; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY sybba (ord_num, ord_amount, ord_date, cust_code, agent_code) FROM stdin;
\.


--
-- Data for Name: temp; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY temp (customer_id, cust_name, city, grade, salesman_id) FROM stdin;
3002	Nick Rimando	New York	100	5001
3007	Brad Davis	New York	200	5001
3003	Jozy Altidor	Moncow	200	5007
3005	Graham Zusi	California	200	5002
3008	Julian Green	London	300	5002
3004	Fabian Johnson	Paris	300	5006
3009	Geoff Cameron	Berlin	100	5003
3001	Brad Guzan	London	\N	5005
\.


--
-- Data for Name: temp_table; Type: TABLE DATA; Schema: public; Owner: user3
--

COPY temp_table (employee_id, first_name, last_name, email, phone_number, hire_date, job_id, salary, commission_pct, manager_id) FROM stdin;
145	John	Russell	JRUSSEL	011.44.1344.429268	1987-08-01	SA_MAN	14000.00	0.40	100
146	Karen	Partners	KPARTNER	011.44.1344.467268	1987-08-02	SA_MAN	13500.00	0.30	100
147	Alberto	Errazuriz	AERRAZUR	011.44.1344.429278	1987-08-03	SA_MAN	12000.00	0.30	100
148	Gerald	Cambrault	GCAMBRAU	011.44.1344.619268	1987-08-04	SA_MAN	11000.00	0.30	100
149	Eleni	Zlotkey	EZLOTKEY	011.44.1344.429018	1987-08-05	SA_MAN	10500.00	0.20	100
150	Peter	Tucker	PTUCKER	011.44.1344.129268	1987-08-06	SA_REP	10000.00	0.30	145
151	David	Bernstein	DBERNSTE	011.44.1344.345268	1987-08-07	SA_REP	9500.00	0.25	145
152	Peter	Hall	PHALL	011.44.1344.478968	1987-08-08	SA_REP	9000.00	0.25	145
153	Christopher	Olsen	COLSEN	011.44.1344.498718	1987-08-09	SA_REP	8000.00	0.20	145
154	Nanette	Cambrault	NCAMBRAU	011.44.1344.987668	1987-08-10	SA_REP	7500.00	0.20	145
155	Oliver	Tuvault	OTUVAULT	011.44.1344.486508	1987-08-11	SA_REP	7000.00	0.15	145
156	Janette	King	JKING	011.44.1345.429268	1987-08-12	SA_REP	10000.00	0.35	146
157	Patrick	Sully	PSULLY	011.44.1345.929268	1987-08-13	SA_REP	9500.00	0.35	146
158	Allan	McEwen	AMCEWEN	011.44.1345.829268	1987-08-14	SA_REP	9000.00	0.35	146
159	Lindsey	Smith	LSMITH	011.44.1345.729268	1987-08-15	SA_REP	8000.00	0.30	146
160	Louise	Doran	LDORAN	011.44.1345.629268	1987-08-16	SA_REP	7500.00	0.30	146
161	Sarath	Sewall	SSEWALL	011.44.1345.529268	1987-08-17	SA_REP	7000.00	0.25	146
162	Clara	Vishney	CVISHNEY	011.44.1346.129268	1987-08-18	SA_REP	10500.00	0.25	147
163	Danielle	Greene	DGREENE	011.44.1346.229268	1987-08-19	SA_REP	9500.00	0.15	147
164	Mattea	Marvins	MMARVINS	011.44.1346.329268	1987-08-20	SA_REP	7200.00	0.10	147
165	David	Lee	DLEE	011.44.1346.529268	1987-08-21	SA_REP	6800.00	0.10	147
166	Sundar	Ande	SANDE	011.44.1346.629268	1987-08-22	SA_REP	6400.00	0.10	147
167	Amit	Banda	ABANDA	011.44.1346.729268	1987-08-23	SA_REP	6200.00	0.10	147
168	Lisa	Ozer	LOZER	011.44.1343.929268	1987-08-24	SA_REP	11500.00	0.25	148
169	Harrison	Bloom	HBLOOM	011.44.1343.829268	1987-08-25	SA_REP	10000.00	0.20	148
170	Tayler	Fox	TFOX	011.44.1343.729268	1987-08-26	SA_REP	9600.00	0.20	148
171	William	Smith	WSMITH	011.44.1343.629268	1987-08-27	SA_REP	7400.00	0.15	148
172	Elizabeth	Bates	EBATES	011.44.1343.529268	1987-08-28	SA_REP	7300.00	0.15	148
173	Sundita	Kumar	SKUMAR	011.44.1343.329268	1987-08-29	SA_REP	6100.00	0.10	148
174	Ellen	Abel	EABEL	011.44.1644.429267	1987-08-30	SA_REP	11000.00	0.30	149
175	Alyssa	Hutton	AHUTTON	011.44.1644.429266	1987-08-31	SA_REP	8800.00	0.25	149
176	Jonathon	Taylor	JTAYLOR	011.44.1644.429265	1987-09-01	SA_REP	8600.00	0.20	149
177	Jack	Livingston	JLIVINGS	011.44.1644.429264	1987-09-02	SA_REP	8400.00	0.20	149
179	Charles	Johnson	CJOHNSON	011.44.1644.429262	1987-09-04	SA_REP	6200.00	0.10	149
178	Kimberely	Grant	KGRANT	011.44.1644.429263	1987-09-03	SA_REP	7000.00	0.15	149
101	Neena	Kochhar	NKOCHHAR	515.123.4568	1987-06-18	AD_VP	17000.00	\N	100
102	Lex	De Haan	LDEHAAN	515.123.4569	1987-06-19	AD_VP	17000.00	\N	100
103	Alexander	Hunold	AHUNOLD	590.423.4567	1987-06-20	IT_PROG	9000.00	\N	102
104	Bruce	Ernst	BERNST	590.423.4568	1987-06-21	IT_PROG	6000.00	\N	103
105	David	Austin	DAUSTIN	590.423.4569	1987-06-22	IT_PROG	4800.00	\N	103
106	Valli	Pataballa	VPATABAL	590.423.4560	1987-06-23	IT_PROG	4800.00	\N	103
107	Diana	Lorentz	DLORENTZ	590.423.5567	1987-06-24	IT_PROG	4200.00	\N	103
108	Nancy	Greenberg	NGREENBE	515.124.4569	1987-06-25	FI_MGR	12000.00	\N	101
109	Daniel	Faviet	DFAVIET	515.124.4169	1987-06-26	FI_ACCOUNT	9000.00	\N	108
110	John	Chen	JCHEN	515.124.4269	1987-06-27	FI_ACCOUNT	8200.00	\N	108
111	Ismael	Sciarra	ISCIARRA	515.124.4369	1987-06-28	FI_ACCOUNT	7700.00	\N	108
112	Jose Manuel	Urman	JMURMAN	515.124.4469	1987-06-29	FI_ACCOUNT	7800.00	\N	108
113	Luis	Popp	LPOPP	515.124.4567	1987-06-30	FI_ACCOUNT	6900.00	\N	108
114	Den	Raphaely	DRAPHEAL	515.127.4561	1987-07-01	PU_MAN	11000.00	\N	100
115	Alexander	Khoo	AKHOO	515.127.4562	1987-07-02	PU_CLERK	3100.00	\N	114
116	Shelli	Baida	SBAIDA	515.127.4563	1987-07-03	PU_CLERK	2900.00	\N	114
117	Sigal	Tobias	STOBIAS	515.127.4564	1987-07-04	PU_CLERK	2800.00	\N	114
118	Guy	Himuro	GHIMURO	515.127.4565	1987-07-05	PU_CLERK	2600.00	\N	114
119	Karen	Colmenares	KCOLMENA	515.127.4566	1987-07-06	PU_CLERK	2500.00	\N	114
120	Matthew	Weiss	MWEISS	650.123.1234	1987-07-07	ST_MAN	8000.00	\N	100
121	Adam	Fripp	AFRIPP	650.123.2234	1987-07-08	ST_MAN	8200.00	\N	100
122	Payam	Kaufling	PKAUFLIN	650.123.3234	1987-07-09	ST_MAN	7900.00	\N	100
123	Shanta	Vollman	SVOLLMAN	650.123.4234	1987-07-10	ST_MAN	6500.00	\N	100
124	Kevin	Mourgos	KMOURGOS	650.123.5234	1987-07-11	ST_MAN	5800.00	\N	100
125	Julia	Nayer	JNAYER	650.124.1214	1987-07-12	ST_CLERK	3200.00	\N	120
126	Irene	Mikkilineni	IMIKKILI	650.124.1224	1987-07-13	ST_CLERK	2700.00	\N	120
127	James	Landry	JLANDRY	650.124.1334	1987-07-14	ST_CLERK	2400.00	\N	120
128	Steven	Markle	SMARKLE	650.124.1434	1987-07-15	ST_CLERK	2200.00	\N	120
129	Laura	Bissot	LBISSOT	650.124.5234	1987-07-16	ST_CLERK	3300.00	\N	121
130	Mozhe	Atkinson	MATKINSO	650.124.6234	1987-07-17	ST_CLERK	2800.00	\N	121
131	James	Marlow	JAMRLOW	650.124.7234	1987-07-18	ST_CLERK	2500.00	\N	121
132	TJ	Olson	TJOLSON	650.124.8234	1987-07-19	ST_CLERK	2100.00	\N	121
133	Jason	Mallin	JMALLIN	650.127.1934	1987-07-20	ST_CLERK	3300.00	\N	122
134	Michael	Rogers	MROGERS	650.127.1834	1987-07-21	ST_CLERK	2900.00	\N	122
135	Ki	Gee	KGEE	650.127.1734	1987-07-22	ST_CLERK	2400.00	\N	122
136	Hazel	Philtanker	HPHILTAN	650.127.1634	1987-07-23	ST_CLERK	2200.00	\N	122
137	Renske	Ladwig	RLADWIG	650.121.1234	1987-07-24	ST_CLERK	3600.00	\N	123
138	Stephen	Stiles	SSTILES	650.121.2034	1987-07-25	ST_CLERK	3200.00	\N	123
139	John	Seo	JSEO	650.121.2019	1987-07-26	ST_CLERK	2700.00	\N	123
140	Joshua	Patel	JPATEL	650.121.1834	1987-07-27	ST_CLERK	2500.00	\N	123
141	Trenna	Rajs	TRAJS	650.121.8009	1987-07-28	ST_CLERK	3500.00	\N	124
142	Curtis	Davies	CDAVIES	650.121.2994	1987-07-29	ST_CLERK	3100.00	\N	124
143	Randall	Matos	RMATOS	650.121.2874	1987-07-30	ST_CLERK	2600.00	\N	124
144	Peter	Vargas	PVARGAS	650.121.2004	1987-07-31	ST_CLERK	2500.00	\N	124
180	Winston	Taylor	WTAYLOR	650.507.9876	1987-09-05	SH_CLERK	3200.00	\N	120
100	Steven	King	SKING	515.123.4567	1987-06-17	AD_PRES	24000.00	\N	\N
181	Jean	Fleaur	JFLEAUR	650.507.9877	1987-09-06	SH_CLERK	3100.00	\N	120
182	Martha	Sullivan	MSULLIVA	650.507.9878	1987-09-07	SH_CLERK	2500.00	\N	120
183	Girard	Geoni	GGEONI	650.507.9879	1987-09-08	SH_CLERK	2800.00	\N	120
184	Nandita	Sarchand	NSARCHAN	650.509.1876	1987-09-09	SH_CLERK	4200.00	\N	121
185	Alexis	Bull	ABULL	650.509.2876	1987-09-10	SH_CLERK	4100.00	\N	121
186	Julia	Dellinger	JDELLING	650.509.3876	1987-09-11	SH_CLERK	3400.00	\N	121
187	Anthony	Cabrio	ACABRIO	650.509.4876	1987-09-12	SH_CLERK	3000.00	\N	121
188	Kelly	Chung	KCHUNG	650.505.1876	1987-09-13	SH_CLERK	3800.00	\N	122
189	Jennifer	Dilly	JDILLY	650.505.2876	1987-09-14	SH_CLERK	3600.00	\N	122
190	Timothy	Gates	TGATES	650.505.3876	1987-09-15	SH_CLERK	2900.00	\N	122
191	Randall	Perkins	RPERKINS	650.505.4876	1987-09-16	SH_CLERK	2500.00	\N	122
192	Sarah	Bell	SBELL	650.501.1876	1987-09-17	SH_CLERK	4000.00	\N	123
193	Britney	Everett	BEVERETT	650.501.2876	1987-09-18	SH_CLERK	3900.00	\N	123
194	Samuel	McCain	SMCCAIN	650.501.3876	1987-09-19	SH_CLERK	3200.00	\N	123
195	Vance	Jones	VJONES	650.501.4876	1987-09-20	SH_CLERK	2800.00	\N	123
196	Alana	Walsh	AWALSH	650.507.9811	1987-09-21	SH_CLERK	3100.00	\N	124
197	Kevin	Feeney	KFEENEY	650.507.9822	1987-09-22	SH_CLERK	3000.00	\N	124
198	Donald	OConnell	DOCONNEL	650.507.9833	1987-09-23	SH_CLERK	2600.00	\N	124
199	Douglas	Grant	DGRANT	650.507.9844	1987-09-24	SH_CLERK	2600.00	\N	124
200	Jennifer	Whalen	JWHALEN	515.123.4444	1987-09-25	AD_ASST	4400.00	\N	101
201	Michael	Hartstein	MHARTSTE	515.123.5555	1987-09-26	MK_MAN	13000.00	\N	100
202	Pat	Fay	PFAY	603.123.6666	1987-09-27	MK_REP	6000.00	\N	201
203	Susan	Mavris	SMAVRIS	515.123.7777	1987-09-28	HR_REP	6500.00	\N	101
204	Hermann	Baer	HBAER	515.123.8888	1987-09-29	PR_REP	10000.00	\N	101
205	Shelley	Higgins	SHIGGINS	515.123.8080	1987-09-30	AC_MGR	12000.00	\N	101
206	William	Gietz	WGIETZ	515.123.8181	1987-10-01	AC_ACCOUNT	8300.00	\N	205
\.


--
-- Data for Name: tempa; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY tempa (customer_id, cust_name, city, grade, salesman_id) FROM stdin;
3002	Nick Rimando	New York	100	5001
3005	Graham Zusi	California	200	5002
3001	Brad Guzan	London	100	5005
3004	Fabian Johns	Paris	300	5006
3007	Brad Davis	New York	200	5001
3009	Geoff Camero	Berlin	100	5003
3008	Julian Green	London	300	5002
3003	Jozy Altidor	Moncow	200	5007
\.


--
-- Data for Name: tempcustomer; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY tempcustomer (customer_id, cust_name, city, grade, salesman_id) FROM stdin;
3002	Nick Rimando	New York	100	5001
3005	Graham Zusi	California	200	5002
3001	Brad Guzan	London	100	5005
3004	Fabian Johns	Paris	300	5006
3007	Brad Davis	New York	200	5001
3009	Geoff Camero	Berlin	100	5003
3008	Julian Green	London	300	5002
3003	Jozy Altidor	Moncow	200	5007
\.


--
-- Data for Name: temphi; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY temphi (salesman_id, name, city, commission) FROM stdin;
5001	James Hoog	New York	0.15
5002	Nail Knite	Paris	0.13
5005	Pit Alex	London	0.11
5006	Mc Lyon	Paris	0.14
5003	Lauson Hen	San Jose	0.12
5007	Paul Adam	Rome	0.13
\.


--
-- Data for Name: tempp; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY tempp (customer_id, cust_name, city, grade, salesman_id) FROM stdin;
3002	Nick Rimando	New York	100	5001
3007	Brad Davis	New York	200	5001
3003	Jozy Altidor	Moncow	200	5007
3005	Graham Zusi	California	200	5002
3008	Julian Green	London	300	5002
3004	Fabian Johnson	Paris	300	5006
3009	Geoff Cameron	Berlin	100	5003
3001	Brad Guzan	London	\N	5005
\.


--
-- Data for Name: tempp11; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY tempp11 (customer_id, cust_name, city, grade, salesman_id) FROM stdin;
3002	Nick Rimando	New York	100	5001
3007	Brad Davis	New York	200	5001
3003	Jozy Altidor	Moncow	200	5007
3005	Graham Zusi	California	200	5002
3008	Julian Green	London	300	5002
3004	Fabian Johnson	Paris	300	5006
3009	Geoff Cameron	Berlin	100	5003
3001	Brad Guzan	London	\N	5005
\.


--
-- Data for Name: tempsalesman; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY tempsalesman (salesman_id, name, city, commission) FROM stdin;
5001	James Hoog	New York	0.15
5002	Nail Knite	Paris	0.13
5005	Pit Alex	London	0.11
5006	Mc Lyon	Paris	0.14
5003	Lauson Hen	San Jose	0.12
5007	Paul Adam	Rome	0.13
\.


--
-- Data for Name: temptable; Type: TABLE DATA; Schema: public; Owner: user3
--

COPY temptable (dpt_code, dpt_name, dpt_allotment) FROM stdin;
57	IT             	65000
63	Finance        	15000
47	HR             	240000
27	RD             	55000
89	QC             	75000
\.


--
-- Data for Name: testtable; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY testtable (col1) FROM stdin;
A001/DJ-402\\44_/100/2015
A001_\\DJ-402\\44_/100/2015
A001_DJ-402-2014-2015
A002_DJ-401-2014-2015
A001/DJ_401
A001/DJ_402\\44
A001/DJ_402\\44\\2015
A001/DJ-402%45\\2015/200
A001/DJ_402\\45\\2015%100
A001/DJ_402%45\\2015/300
A001/DJ-402\\44
\.


--
-- Data for Name: trenta; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY trenta (numeri) FROM stdin;
\.


--
-- Data for Name: vowl; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY vowl (cust_name, "substring") FROM stdin;
Nick Rimando	o
Graham Zusi	i
Brad Guzan	n
Fabian Johns	s
Brad Davis	s
Geoff Camero	o
Julian Green	n
Jozy Altidor	r
\.


--
-- Data for Name: zebras; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY zebras (id, score, date) FROM stdin;
1	100	2015-12-15
3	230	2015-12-15
\.


--
-- Name: casino_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY casino
    ADD CONSTRAINT casino_pkey PRIMARY KEY (casino);


--
-- Name: company_mast_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY company_mast
    ADD CONSTRAINT company_mast_pkey PRIMARY KEY (com_id);


--
-- Name: countries_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY countries
    ADD CONSTRAINT countries_pkey PRIMARY KEY (country_id);


--
-- Name: customer_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY customer
    ADD CONSTRAINT customer_pkey PRIMARY KEY (customer_id);


--
-- Name: departments_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY departments
    ADD CONSTRAINT departments_pkey PRIMARY KEY (department_id);


--
-- Name: elephants_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY elephants
    ADD CONSTRAINT elephants_pkey PRIMARY KEY (id);


--
-- Name: emp_department_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY emp_department
    ADD CONSTRAINT emp_department_pkey PRIMARY KEY (dpt_code);


--
-- Name: emp_details_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY emp_details
    ADD CONSTRAINT emp_details_pkey PRIMARY KEY (emp_idno);


--
-- Name: emp_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY emp
    ADD CONSTRAINT emp_pk PRIMARY KEY (eid);


--
-- Name: employees_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY employees
    ADD CONSTRAINT employees_pkey PRIMARY KEY (employee_id);


--
-- Name: game_scores_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY game_scores
    ADD CONSTRAINT game_scores_pkey PRIMARY KEY (id);


--
-- Name: grades_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY grades
    ADD CONSTRAINT grades_pkey PRIMARY KEY (id);


--
-- Name: item_mast_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY item_mast
    ADD CONSTRAINT item_mast_pkey PRIMARY KEY (pro_id);


--
-- Name: job_grades_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY job_grades
    ADD CONSTRAINT job_grades_pkey PRIMARY KEY (grade_level);


--
-- Name: job_history_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY job_history
    ADD CONSTRAINT job_history_pkey PRIMARY KEY (employee_id, start_date);


--
-- Name: jobs_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY jobs
    ADD CONSTRAINT jobs_pkey PRIMARY KEY (job_id);


--
-- Name: locations_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY locations
    ADD CONSTRAINT locations_pkey PRIMARY KEY (location_id);


--
-- Name: mytest1_ord_num_key; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY mytest1
    ADD CONSTRAINT mytest1_ord_num_key UNIQUE (ord_num);


--
-- Name: mytest_ord_num_key; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY mytest
    ADD CONSTRAINT mytest_ord_num_key UNIQUE (ord_num);


--
-- Name: orders_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY orders
    ADD CONSTRAINT orders_pkey PRIMARY KEY (ord_no);


--
-- Name: partest1_ord_num_key; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY partest1
    ADD CONSTRAINT partest1_ord_num_key UNIQUE (ord_num);


--
-- Name: regions_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY regions
    ADD CONSTRAINT regions_pkey PRIMARY KEY (region_id);


--
-- Name: salesman_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY salesman
    ADD CONSTRAINT salesman_pkey PRIMARY KEY (salesman_id);


--
-- Name: scores_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY scores
    ADD CONSTRAINT scores_pkey PRIMARY KEY (id);


--
-- Name: sybba_ord_num_key; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY sybba
    ADD CONSTRAINT sybba_ord_num_key UNIQUE (ord_num);


--
-- Name: zebras_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY zebras
    ADD CONSTRAINT zebras_pkey PRIMARY KEY (id);


--
-- Name: countries_region_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY countries
    ADD CONSTRAINT countries_region_id_fkey FOREIGN KEY (region_id) REFERENCES regions(region_id);


--
-- Name: customer_id_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY orders
    ADD CONSTRAINT customer_id_fk FOREIGN KEY (customer_id) REFERENCES customer(customer_id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: emp_details_emp_dept_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY emp_details
    ADD CONSTRAINT emp_details_emp_dept_fkey FOREIGN KEY (emp_dept) REFERENCES emp_department(dpt_code);


--
-- Name: item_mast_pro_com_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY item_mast
    ADD CONSTRAINT item_mast_pro_com_fkey FOREIGN KEY (pro_com) REFERENCES company_mast(com_id);


--
-- Name: salesman_id_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY customer
    ADD CONSTRAINT salesman_id_fk FOREIGN KEY (salesman_id) REFERENCES salesman(salesman_id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: salesman_id_fk2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY orders
    ADD CONSTRAINT salesman_id_fk2 FOREIGN KEY (salesman_id) REFERENCES salesman(salesman_id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT USAGE ON SCHEMA public TO user3;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- Name: address; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE address FROM PUBLIC;
REVOKE ALL ON TABLE address FROM postgres;
GRANT ALL ON TABLE address TO postgres;
GRANT SELECT ON TABLE address TO student;
GRANT SELECT ON TABLE address TO user1;
GRANT SELECT ON TABLE address TO user3;


--
-- Name: customer; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE customer FROM PUBLIC;
REVOKE ALL ON TABLE customer FROM postgres;
GRANT ALL ON TABLE customer TO postgres;
GRANT SELECT ON TABLE customer TO student;
GRANT SELECT ON TABLE customer TO user1;
GRANT SELECT ON TABLE customer TO user3;


--
-- Name: agentview; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE agentview FROM PUBLIC;
REVOKE ALL ON TABLE agentview FROM postgres;
GRANT ALL ON TABLE agentview TO postgres;
GRANT SELECT ON TABLE agentview TO student;
GRANT SELECT ON TABLE agentview TO user1;
GRANT SELECT ON TABLE agentview TO user3;


--
-- Name: bh; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE bh FROM PUBLIC;
REVOKE ALL ON TABLE bh FROM postgres;
GRANT ALL ON TABLE bh TO postgres;
GRANT SELECT ON TABLE bh TO student;
GRANT SELECT ON TABLE bh TO user1;
GRANT SELECT ON TABLE bh TO user3;


--
-- Name: casino; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE casino FROM PUBLIC;
REVOKE ALL ON TABLE casino FROM postgres;
GRANT ALL ON TABLE casino TO postgres;
GRANT SELECT ON TABLE casino TO student;
GRANT SELECT ON TABLE casino TO user1;
GRANT SELECT ON TABLE casino TO user3;


--
-- Name: col1; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE col1 FROM PUBLIC;
REVOKE ALL ON TABLE col1 FROM postgres;
GRANT ALL ON TABLE col1 TO postgres;
GRANT SELECT ON TABLE col1 TO student;
GRANT SELECT ON TABLE col1 TO user1;
GRANT SELECT ON TABLE col1 TO user3;


--
-- Name: company_mast; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE company_mast FROM PUBLIC;
REVOKE ALL ON TABLE company_mast FROM postgres;
GRANT ALL ON TABLE company_mast TO postgres;
GRANT SELECT ON TABLE company_mast TO student;
GRANT SELECT ON TABLE company_mast TO user1;
GRANT SELECT ON TABLE company_mast TO user3;


--
-- Name: countries; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE countries FROM PUBLIC;
REVOKE ALL ON TABLE countries FROM postgres;
GRANT ALL ON TABLE countries TO postgres;
GRANT SELECT ON TABLE countries TO user3;


--
-- Name: customer_backup; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE customer_backup FROM PUBLIC;
REVOKE ALL ON TABLE customer_backup FROM postgres;
GRANT ALL ON TABLE customer_backup TO postgres;
GRANT SELECT ON TABLE customer_backup TO student;
GRANT SELECT ON TABLE customer_backup TO user1;
GRANT SELECT ON TABLE customer_backup TO user3;


--
-- Name: customergradelevels; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE customergradelevels FROM PUBLIC;
REVOKE ALL ON TABLE customergradelevels FROM postgres;
GRANT ALL ON TABLE customergradelevels TO postgres;
GRANT SELECT ON TABLE customergradelevels TO student;
GRANT SELECT ON TABLE customergradelevels TO user1;
GRANT SELECT ON TABLE customergradelevels TO user3;


--
-- Name: customergradelevels2; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE customergradelevels2 FROM PUBLIC;
REVOKE ALL ON TABLE customergradelevels2 FROM postgres;
GRANT ALL ON TABLE customergradelevels2 TO postgres;
GRANT SELECT ON TABLE customergradelevels2 TO student;
GRANT SELECT ON TABLE customergradelevels2 TO user1;
GRANT SELECT ON TABLE customergradelevels2 TO user3;


--
-- Name: departments; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE departments FROM PUBLIC;
REVOKE ALL ON TABLE departments FROM postgres;
GRANT ALL ON TABLE departments TO postgres;
GRANT SELECT ON TABLE departments TO user3;


--
-- Name: elephants; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE elephants FROM PUBLIC;
REVOKE ALL ON TABLE elephants FROM postgres;
GRANT ALL ON TABLE elephants TO postgres;
GRANT SELECT ON TABLE elephants TO student;
GRANT SELECT ON TABLE elephants TO user1;
GRANT SELECT ON TABLE elephants TO user3;


--
-- Name: emp; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE emp FROM PUBLIC;
REVOKE ALL ON TABLE emp FROM postgres;
GRANT ALL ON TABLE emp TO postgres;
GRANT SELECT ON TABLE emp TO student;
GRANT SELECT ON TABLE emp TO user1;
GRANT SELECT ON TABLE emp TO user3;


--
-- Name: emp_department; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE emp_department FROM PUBLIC;
REVOKE ALL ON TABLE emp_department FROM postgres;
GRANT ALL ON TABLE emp_department TO postgres;
GRANT SELECT ON TABLE emp_department TO student;
GRANT SELECT ON TABLE emp_department TO user1;
GRANT SELECT ON TABLE emp_department TO user3;


--
-- Name: emp_details; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE emp_details FROM PUBLIC;
REVOKE ALL ON TABLE emp_details FROM postgres;
GRANT ALL ON TABLE emp_details TO postgres;
GRANT SELECT ON TABLE emp_details TO student;
GRANT SELECT ON TABLE emp_details TO user1;
GRANT SELECT ON TABLE emp_details TO user3;


--
-- Name: employee; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE employee FROM PUBLIC;
REVOKE ALL ON TABLE employee FROM postgres;
GRANT ALL ON TABLE employee TO postgres;
GRANT SELECT ON TABLE employee TO student;
GRANT SELECT ON TABLE employee TO user1;
GRANT SELECT ON TABLE employee TO user3;


--
-- Name: employees; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE employees FROM PUBLIC;
REVOKE ALL ON TABLE employees FROM postgres;
GRANT ALL ON TABLE employees TO postgres;
GRANT SELECT ON TABLE employees TO user3;


--
-- Name: game_scores; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE game_scores FROM PUBLIC;
REVOKE ALL ON TABLE game_scores FROM postgres;
GRANT ALL ON TABLE game_scores TO postgres;
GRANT SELECT ON TABLE game_scores TO student;
GRANT SELECT ON TABLE game_scores TO user1;
GRANT SELECT ON TABLE game_scores TO user3;


--
-- Name: grade; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE grade FROM PUBLIC;
REVOKE ALL ON TABLE grade FROM postgres;
GRANT ALL ON TABLE grade TO postgres;
GRANT SELECT ON TABLE grade TO student;
GRANT SELECT ON TABLE grade TO user1;
GRANT SELECT ON TABLE grade TO user3;


--
-- Name: grade_customer; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE grade_customer FROM PUBLIC;
REVOKE ALL ON TABLE grade_customer FROM postgres;
GRANT ALL ON TABLE grade_customer TO postgres;
GRANT SELECT ON TABLE grade_customer TO student;
GRANT SELECT ON TABLE grade_customer TO user1;
GRANT SELECT ON TABLE grade_customer TO user3;


--
-- Name: grade_customer1; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE grade_customer1 FROM PUBLIC;
REVOKE ALL ON TABLE grade_customer1 FROM postgres;
GRANT ALL ON TABLE grade_customer1 TO postgres;
GRANT SELECT ON TABLE grade_customer1 TO student;
GRANT SELECT ON TABLE grade_customer1 TO user1;
GRANT SELECT ON TABLE grade_customer1 TO user3;


--
-- Name: grades; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE grades FROM PUBLIC;
REVOKE ALL ON TABLE grades FROM postgres;
GRANT ALL ON TABLE grades TO postgres;
GRANT SELECT ON TABLE grades TO student;
GRANT SELECT ON TABLE grades TO user1;
GRANT SELECT ON TABLE grades TO user3;


--
-- Name: hello; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE hello FROM PUBLIC;
REVOKE ALL ON TABLE hello FROM postgres;
GRANT ALL ON TABLE hello TO postgres;
GRANT SELECT ON TABLE hello TO student;
GRANT SELECT ON TABLE hello TO user1;
GRANT SELECT ON TABLE hello TO user3;


--
-- Name: hello1_1122; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE hello1_1122 FROM PUBLIC;
REVOKE ALL ON TABLE hello1_1122 FROM postgres;
GRANT ALL ON TABLE hello1_1122 TO postgres;
GRANT SELECT ON TABLE hello1_1122 TO student;
GRANT SELECT ON TABLE hello1_1122 TO user1;
GRANT SELECT ON TABLE hello1_1122 TO user3;


--
-- Name: hello1_12; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE hello1_12 FROM PUBLIC;
REVOKE ALL ON TABLE hello1_12 FROM postgres;
GRANT ALL ON TABLE hello1_12 TO postgres;
GRANT SELECT ON TABLE hello1_12 TO student;
GRANT SELECT ON TABLE hello1_12 TO user1;
GRANT SELECT ON TABLE hello1_12 TO user3;


--
-- Name: hello_12; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE hello_12 FROM PUBLIC;
REVOKE ALL ON TABLE hello_12 FROM postgres;
GRANT ALL ON TABLE hello_12 TO postgres;
GRANT SELECT ON TABLE hello_12 TO student;
GRANT SELECT ON TABLE hello_12 TO user1;
GRANT SELECT ON TABLE hello_12 TO user3;


--
-- Name: item_mast; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE item_mast FROM PUBLIC;
REVOKE ALL ON TABLE item_mast FROM postgres;
GRANT ALL ON TABLE item_mast TO postgres;
GRANT SELECT ON TABLE item_mast TO student;
GRANT SELECT ON TABLE item_mast TO user1;
GRANT SELECT ON TABLE item_mast TO user3;


--
-- Name: job_grades; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE job_grades FROM PUBLIC;
REVOKE ALL ON TABLE job_grades FROM postgres;
GRANT ALL ON TABLE job_grades TO postgres;
GRANT SELECT ON TABLE job_grades TO student;
GRANT SELECT ON TABLE job_grades TO user1;
GRANT SELECT ON TABLE job_grades TO user3;


--
-- Name: job_history; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE job_history FROM PUBLIC;
REVOKE ALL ON TABLE job_history FROM postgres;
GRANT ALL ON TABLE job_history TO postgres;
GRANT SELECT ON TABLE job_history TO user3;


--
-- Name: jobs; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE jobs FROM PUBLIC;
REVOKE ALL ON TABLE jobs FROM postgres;
GRANT ALL ON TABLE jobs TO postgres;
GRANT SELECT ON TABLE jobs TO user3;


--
-- Name: locations; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE locations FROM PUBLIC;
REVOKE ALL ON TABLE locations FROM postgres;
GRANT ALL ON TABLE locations TO postgres;
GRANT SELECT ON TABLE locations TO user3;


--
-- Name: maxim00; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE maxim00 FROM PUBLIC;
REVOKE ALL ON TABLE maxim00 FROM postgres;
GRANT ALL ON TABLE maxim00 TO postgres;
GRANT SELECT ON TABLE maxim00 TO student;
GRANT SELECT ON TABLE maxim00 TO user1;
GRANT SELECT ON TABLE maxim00 TO user3;


--
-- Name: maximum; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE maximum FROM PUBLIC;
REVOKE ALL ON TABLE maximum FROM postgres;
GRANT ALL ON TABLE maximum TO postgres;
GRANT SELECT ON TABLE maximum TO student;
GRANT SELECT ON TABLE maximum TO user1;
GRANT SELECT ON TABLE maximum TO user3;


--
-- Name: maximum00; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE maximum00 FROM PUBLIC;
REVOKE ALL ON TABLE maximum00 FROM postgres;
GRANT ALL ON TABLE maximum00 TO postgres;
GRANT SELECT ON TABLE maximum00 TO student;
GRANT SELECT ON TABLE maximum00 TO user1;
GRANT SELECT ON TABLE maximum00 TO user3;


--
-- Name: maximum899; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE maximum899 FROM PUBLIC;
REVOKE ALL ON TABLE maximum899 FROM postgres;
GRANT ALL ON TABLE maximum899 TO postgres;
GRANT SELECT ON TABLE maximum899 TO student;
GRANT SELECT ON TABLE maximum899 TO user1;
GRANT SELECT ON TABLE maximum899 TO user3;


--
-- Name: mytest; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE mytest FROM PUBLIC;
REVOKE ALL ON TABLE mytest FROM postgres;
GRANT ALL ON TABLE mytest TO postgres;
GRANT SELECT ON TABLE mytest TO student;
GRANT SELECT ON TABLE mytest TO user1;
GRANT SELECT ON TABLE mytest TO user3;


--
-- Name: mytest1; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE mytest1 FROM PUBLIC;
REVOKE ALL ON TABLE mytest1 FROM postgres;
GRANT ALL ON TABLE mytest1 TO postgres;
GRANT SELECT ON TABLE mytest1 TO student;
GRANT SELECT ON TABLE mytest1 TO user1;
GRANT SELECT ON TABLE mytest1 TO user3;


--
-- Name: salesman; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE salesman FROM PUBLIC;
REVOKE ALL ON TABLE salesman FROM postgres;
GRANT ALL ON TABLE salesman TO postgres;
GRANT SELECT ON TABLE salesman TO student;
GRANT SELECT ON TABLE salesman TO user1;
GRANT SELECT ON TABLE salesman TO user3;


--
-- Name: myworkstuff; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE myworkstuff FROM PUBLIC;
REVOKE ALL ON TABLE myworkstuff FROM postgres;
GRANT ALL ON TABLE myworkstuff TO postgres;
GRANT SELECT ON TABLE myworkstuff TO student;
GRANT SELECT ON TABLE myworkstuff TO user1;
GRANT SELECT ON TABLE myworkstuff TO user3;


--
-- Name: myworkstuffs; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE myworkstuffs FROM PUBLIC;
REVOKE ALL ON TABLE myworkstuffs FROM postgres;
GRANT ALL ON TABLE myworkstuffs TO postgres;
GRANT SELECT ON TABLE myworkstuffs TO student;
GRANT SELECT ON TABLE myworkstuffs TO user1;
GRANT SELECT ON TABLE myworkstuffs TO user3;


--
-- Name: new; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE new FROM PUBLIC;
REVOKE ALL ON TABLE new FROM postgres;
GRANT ALL ON TABLE new TO postgres;
GRANT SELECT ON TABLE new TO student;
GRANT SELECT ON TABLE new TO user1;
GRANT SELECT ON TABLE new TO user3;


--
-- Name: new123; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE new123 FROM PUBLIC;
REVOKE ALL ON TABLE new123 FROM postgres;
GRANT ALL ON TABLE new123 TO postgres;
GRANT SELECT ON TABLE new123 TO student;
GRANT SELECT ON TABLE new123 TO user1;
GRANT SELECT ON TABLE new123 TO user3;


--
-- Name: new_table; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE new_table FROM PUBLIC;
REVOKE ALL ON TABLE new_table FROM postgres;
GRANT ALL ON TABLE new_table TO postgres;
GRANT SELECT ON TABLE new_table TO student;
GRANT SELECT ON TABLE new_table TO user1;
GRANT SELECT ON TABLE new_table TO user3;


--
-- Name: newtab; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE newtab FROM PUBLIC;
REVOKE ALL ON TABLE newtab FROM postgres;
GRANT ALL ON TABLE newtab TO postgres;
GRANT SELECT ON TABLE newtab TO student;
GRANT SELECT ON TABLE newtab TO user1;
GRANT SELECT ON TABLE newtab TO user3;


--
-- Name: newyorksalesman; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE newyorksalesman FROM PUBLIC;
REVOKE ALL ON TABLE newyorksalesman FROM postgres;
GRANT ALL ON TABLE newyorksalesman TO postgres;
GRANT SELECT ON TABLE newyorksalesman TO student;
GRANT SELECT ON TABLE newyorksalesman TO user1;
GRANT SELECT ON TABLE newyorksalesman TO user3;


--
-- Name: newyorksalesman2; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE newyorksalesman2 FROM PUBLIC;
REVOKE ALL ON TABLE newyorksalesman2 FROM postgres;
GRANT ALL ON TABLE newyorksalesman2 TO postgres;
GRANT SELECT ON TABLE newyorksalesman2 TO student;
GRANT SELECT ON TABLE newyorksalesman2 TO user1;
GRANT SELECT ON TABLE newyorksalesman2 TO user3;


--
-- Name: newyorksalesman3; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE newyorksalesman3 FROM PUBLIC;
REVOKE ALL ON TABLE newyorksalesman3 FROM postgres;
GRANT ALL ON TABLE newyorksalesman3 TO postgres;
GRANT SELECT ON TABLE newyorksalesman3 TO student;
GRANT SELECT ON TABLE newyorksalesman3 TO user1;
GRANT SELECT ON TABLE newyorksalesman3 TO user3;


--
-- Name: newyorkstaff; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE newyorkstaff FROM PUBLIC;
REVOKE ALL ON TABLE newyorkstaff FROM postgres;
GRANT ALL ON TABLE newyorkstaff TO postgres;
GRANT SELECT ON TABLE newyorkstaff TO student;
GRANT SELECT ON TABLE newyorkstaff TO user1;
GRANT SELECT ON TABLE newyorkstaff TO user3;


--
-- Name: nobel_win; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE nobel_win FROM PUBLIC;
REVOKE ALL ON TABLE nobel_win FROM postgres;
GRANT ALL ON TABLE nobel_win TO postgres;
GRANT SELECT ON TABLE nobel_win TO student;
GRANT SELECT ON TABLE nobel_win TO user1;
GRANT SELECT ON TABLE nobel_win TO user3;


--
-- Name: orders; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE orders FROM PUBLIC;
REVOKE ALL ON TABLE orders FROM postgres;
GRANT ALL ON TABLE orders TO postgres;
GRANT SELECT ON TABLE orders TO student;
GRANT SELECT ON TABLE orders TO user1;
GRANT SELECT ON TABLE orders TO user3;


--
-- Name: norders; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE norders FROM PUBLIC;
REVOKE ALL ON TABLE norders FROM postgres;
GRANT ALL ON TABLE norders TO postgres;
GRANT SELECT ON TABLE norders TO student;
GRANT SELECT ON TABLE norders TO user1;
GRANT SELECT ON TABLE norders TO user3;


--
-- Name: nros; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE nros FROM PUBLIC;
REVOKE ALL ON TABLE nros FROM postgres;
GRANT ALL ON TABLE nros TO postgres;
GRANT SELECT ON TABLE nros TO student;
GRANT SELECT ON TABLE nros TO user1;
GRANT SELECT ON TABLE nros TO user3;


--
-- Name: nuevo; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE nuevo FROM PUBLIC;
REVOKE ALL ON TABLE nuevo FROM postgres;
GRANT ALL ON TABLE nuevo TO postgres;
GRANT SELECT ON TABLE nuevo TO student;
GRANT SELECT ON TABLE nuevo TO user1;
GRANT SELECT ON TABLE nuevo TO user3;


--
-- Name: numbers; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE numbers FROM PUBLIC;
REVOKE ALL ON TABLE numbers FROM postgres;
GRANT ALL ON TABLE numbers TO postgres;
GRANT SELECT ON TABLE numbers TO student;
GRANT SELECT ON TABLE numbers TO user1;
GRANT SELECT ON TABLE numbers TO user3;


--
-- Name: numeri; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE numeri FROM PUBLIC;
REVOKE ALL ON TABLE numeri FROM postgres;
GRANT ALL ON TABLE numeri TO postgres;
GRANT SELECT ON TABLE numeri TO student;
GRANT SELECT ON TABLE numeri TO user1;
GRANT SELECT ON TABLE numeri TO user3;


--
-- Name: numeros; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE numeros FROM PUBLIC;
REVOKE ALL ON TABLE numeros FROM postgres;
GRANT ALL ON TABLE numeros TO postgres;
GRANT SELECT ON TABLE numeros TO student;
GRANT SELECT ON TABLE numeros TO user1;
GRANT SELECT ON TABLE numeros TO user3;


--
-- Name: odr; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE odr FROM PUBLIC;
REVOKE ALL ON TABLE odr FROM postgres;
GRANT ALL ON TABLE odr TO postgres;
GRANT SELECT ON TABLE odr TO student;
GRANT SELECT ON TABLE odr TO user1;
GRANT SELECT ON TABLE odr TO user3;


--
-- Name: orozco; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE orozco FROM PUBLIC;
REVOKE ALL ON TABLE orozco FROM postgres;
GRANT ALL ON TABLE orozco TO postgres;
GRANT SELECT ON TABLE orozco TO student;
GRANT SELECT ON TABLE orozco TO user1;
GRANT SELECT ON TABLE orozco TO user3;


--
-- Name: partest1; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE partest1 FROM PUBLIC;
REVOKE ALL ON TABLE partest1 FROM postgres;
GRANT ALL ON TABLE partest1 TO postgres;
GRANT SELECT ON TABLE partest1 TO student;
GRANT SELECT ON TABLE partest1 TO user1;
GRANT SELECT ON TABLE partest1 TO user3;


--
-- Name: participant; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE participant FROM PUBLIC;
REVOKE ALL ON TABLE participant FROM postgres;
GRANT ALL ON TABLE participant TO postgres;
GRANT SELECT ON TABLE participant TO student;
GRANT SELECT ON TABLE participant TO user1;
GRANT SELECT ON TABLE participant TO user3;


--
-- Name: participants; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE participants FROM PUBLIC;
REVOKE ALL ON TABLE participants FROM postgres;
GRANT ALL ON TABLE participants TO postgres;
GRANT SELECT ON TABLE participants TO student;
GRANT SELECT ON TABLE participants TO user1;
GRANT SELECT ON TABLE participants TO user3;


--
-- Name: persons; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE persons FROM PUBLIC;
REVOKE ALL ON TABLE persons FROM postgres;
GRANT ALL ON TABLE persons TO postgres;
GRANT SELECT ON TABLE persons TO student;
GRANT SELECT ON TABLE persons TO user1;
GRANT SELECT ON TABLE persons TO user3;


--
-- Name: raster_overviews; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE raster_overviews FROM PUBLIC;
REVOKE ALL ON TABLE raster_overviews FROM postgres;
GRANT ALL ON TABLE raster_overviews TO postgres;
GRANT SELECT ON TABLE raster_overviews TO student;
GRANT SELECT ON TABLE raster_overviews TO user1;
GRANT SELECT ON TABLE raster_overviews TO user3;


--
-- Name: regions; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE regions FROM PUBLIC;
REVOKE ALL ON TABLE regions FROM postgres;
GRANT ALL ON TABLE regions TO postgres;
GRANT SELECT ON TABLE regions TO user3;


--
-- Name: related; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE related FROM PUBLIC;
REVOKE ALL ON TABLE related FROM postgres;
GRANT ALL ON TABLE related TO postgres;
GRANT SELECT ON TABLE related TO student;
GRANT SELECT ON TABLE related TO user1;
GRANT SELECT ON TABLE related TO user3;


--
-- Name: rightjoins; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE rightjoins FROM PUBLIC;
REVOKE ALL ON TABLE rightjoins FROM postgres;
GRANT ALL ON TABLE rightjoins TO postgres;
GRANT SELECT ON TABLE rightjoins TO student;
GRANT SELECT ON TABLE rightjoins TO user1;
GRANT SELECT ON TABLE rightjoins TO user3;


--
-- Name: salesdetail; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE salesdetail FROM PUBLIC;
REVOKE ALL ON TABLE salesdetail FROM postgres;
GRANT ALL ON TABLE salesdetail TO postgres;
GRANT SELECT ON TABLE salesdetail TO student;
GRANT SELECT ON TABLE salesdetail TO user1;
GRANT SELECT ON TABLE salesdetail TO user3;


--
-- Name: salesman_detail; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE salesman_detail FROM PUBLIC;
REVOKE ALL ON TABLE salesman_detail FROM postgres;
GRANT ALL ON TABLE salesman_detail TO postgres;
GRANT SELECT ON TABLE salesman_detail TO student;
GRANT SELECT ON TABLE salesman_detail TO user1;
GRANT SELECT ON TABLE salesman_detail TO user3;


--
-- Name: salesman_do1304; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE salesman_do1304 FROM PUBLIC;
REVOKE ALL ON TABLE salesman_do1304 FROM postgres;
GRANT ALL ON TABLE salesman_do1304 TO postgres;
GRANT SELECT ON TABLE salesman_do1304 TO student;
GRANT SELECT ON TABLE salesman_do1304 TO user1;
GRANT SELECT ON TABLE salesman_do1304 TO user3;


--
-- Name: salesman_example; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE salesman_example FROM PUBLIC;
REVOKE ALL ON TABLE salesman_example FROM postgres;
GRANT ALL ON TABLE salesman_example TO postgres;
GRANT SELECT ON TABLE salesman_example TO student;
GRANT SELECT ON TABLE salesman_example TO user1;
GRANT SELECT ON TABLE salesman_example TO user3;


--
-- Name: salesman_ny; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE salesman_ny FROM PUBLIC;
REVOKE ALL ON TABLE salesman_ny FROM postgres;
GRANT ALL ON TABLE salesman_ny TO postgres;
GRANT SELECT ON TABLE salesman_ny TO student;
GRANT SELECT ON TABLE salesman_ny TO user1;
GRANT SELECT ON TABLE salesman_ny TO user3;


--
-- Name: salesmandetail; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE salesmandetail FROM PUBLIC;
REVOKE ALL ON TABLE salesmandetail FROM postgres;
GRANT ALL ON TABLE salesmandetail TO postgres;
GRANT SELECT ON TABLE salesmandetail TO student;
GRANT SELECT ON TABLE salesmandetail TO user1;
GRANT SELECT ON TABLE salesmandetail TO user3;


--
-- Name: salesown; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE salesown FROM PUBLIC;
REVOKE ALL ON TABLE salesown FROM postgres;
GRANT ALL ON TABLE salesown TO postgres;
GRANT SELECT ON TABLE salesown TO student;
GRANT SELECT ON TABLE salesown TO user1;
GRANT SELECT ON TABLE salesown TO user3;


--
-- Name: sample_table; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE sample_table FROM PUBLIC;
REVOKE ALL ON TABLE sample_table FROM postgres;
GRANT ALL ON TABLE sample_table TO postgres;
GRANT SELECT ON TABLE sample_table TO student;
GRANT SELECT ON TABLE sample_table TO user1;
GRANT SELECT ON TABLE sample_table TO user3;


--
-- Name: scores; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE scores FROM PUBLIC;
REVOKE ALL ON TABLE scores FROM postgres;
GRANT ALL ON TABLE scores TO postgres;
GRANT SELECT ON TABLE scores TO student;
GRANT SELECT ON TABLE scores TO user1;
GRANT SELECT ON TABLE scores TO user3;


--
-- Name: statements; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE statements FROM PUBLIC;
REVOKE ALL ON TABLE statements FROM postgres;
GRANT ALL ON TABLE statements TO postgres;
GRANT SELECT ON TABLE statements TO student;
GRANT SELECT ON TABLE statements TO user1;
GRANT SELECT ON TABLE statements TO user3;


--
-- Name: student; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE student FROM PUBLIC;
REVOKE ALL ON TABLE student FROM postgres;
GRANT ALL ON TABLE student TO postgres;
GRANT SELECT ON TABLE student TO student;
GRANT SELECT ON TABLE student TO user1;
GRANT SELECT ON TABLE student TO user3;


--
-- Name: student1; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE student1 FROM PUBLIC;
REVOKE ALL ON TABLE student1 FROM postgres;
GRANT ALL ON TABLE student1 TO postgres;
GRANT SELECT ON TABLE student1 TO student;
GRANT SELECT ON TABLE student1 TO user1;
GRANT SELECT ON TABLE student1 TO user3;


--
-- Name: sybba; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE sybba FROM PUBLIC;
REVOKE ALL ON TABLE sybba FROM postgres;
GRANT ALL ON TABLE sybba TO postgres;
GRANT SELECT ON TABLE sybba TO student;
GRANT SELECT ON TABLE sybba TO user1;
GRANT SELECT ON TABLE sybba TO user3;


--
-- Name: temp; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE temp FROM PUBLIC;
REVOKE ALL ON TABLE temp FROM postgres;
GRANT ALL ON TABLE temp TO postgres;
GRANT SELECT ON TABLE temp TO student;
GRANT SELECT ON TABLE temp TO user1;
GRANT SELECT ON TABLE temp TO user3;


--
-- Name: tempa; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE tempa FROM PUBLIC;
REVOKE ALL ON TABLE tempa FROM postgres;
GRANT ALL ON TABLE tempa TO postgres;
GRANT SELECT ON TABLE tempa TO student;
GRANT SELECT ON TABLE tempa TO user1;
GRANT SELECT ON TABLE tempa TO user3;


--
-- Name: tempcustomer; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE tempcustomer FROM PUBLIC;
REVOKE ALL ON TABLE tempcustomer FROM postgres;
GRANT ALL ON TABLE tempcustomer TO postgres;
GRANT SELECT ON TABLE tempcustomer TO student;
GRANT SELECT ON TABLE tempcustomer TO user1;
GRANT SELECT ON TABLE tempcustomer TO user3;


--
-- Name: temphi; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE temphi FROM PUBLIC;
REVOKE ALL ON TABLE temphi FROM postgres;
GRANT ALL ON TABLE temphi TO postgres;
GRANT SELECT ON TABLE temphi TO student;
GRANT SELECT ON TABLE temphi TO user1;
GRANT SELECT ON TABLE temphi TO user3;


--
-- Name: tempp; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE tempp FROM PUBLIC;
REVOKE ALL ON TABLE tempp FROM postgres;
GRANT ALL ON TABLE tempp TO postgres;
GRANT SELECT ON TABLE tempp TO student;
GRANT SELECT ON TABLE tempp TO user1;
GRANT SELECT ON TABLE tempp TO user3;


--
-- Name: tempp11; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE tempp11 FROM PUBLIC;
REVOKE ALL ON TABLE tempp11 FROM postgres;
GRANT ALL ON TABLE tempp11 TO postgres;
GRANT SELECT ON TABLE tempp11 TO student;
GRANT SELECT ON TABLE tempp11 TO user1;
GRANT SELECT ON TABLE tempp11 TO user3;


--
-- Name: tempsalesman; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE tempsalesman FROM PUBLIC;
REVOKE ALL ON TABLE tempsalesman FROM postgres;
GRANT ALL ON TABLE tempsalesman TO postgres;
GRANT SELECT ON TABLE tempsalesman TO student;
GRANT SELECT ON TABLE tempsalesman TO user1;
GRANT SELECT ON TABLE tempsalesman TO user3;


--
-- Name: testtable; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE testtable FROM PUBLIC;
REVOKE ALL ON TABLE testtable FROM postgres;
GRANT ALL ON TABLE testtable TO postgres;
GRANT SELECT ON TABLE testtable TO student;
GRANT SELECT ON TABLE testtable TO user1;
GRANT SELECT ON TABLE testtable TO user3;


--
-- Name: testtesing; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE testtesing FROM PUBLIC;
REVOKE ALL ON TABLE testtesing FROM postgres;
GRANT ALL ON TABLE testtesing TO postgres;
GRANT SELECT ON TABLE testtesing TO student;
GRANT SELECT ON TABLE testtesing TO user1;
GRANT SELECT ON TABLE testtesing TO user3;


--
-- Name: testtest; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE testtest FROM PUBLIC;
REVOKE ALL ON TABLE testtest FROM postgres;
GRANT ALL ON TABLE testtest TO postgres;
GRANT SELECT ON TABLE testtest TO student;
GRANT SELECT ON TABLE testtest TO user1;
GRANT SELECT ON TABLE testtest TO user3;


--
-- Name: trenta; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE trenta FROM PUBLIC;
REVOKE ALL ON TABLE trenta FROM postgres;
GRANT ALL ON TABLE trenta TO postgres;
GRANT SELECT ON TABLE trenta TO student;
GRANT SELECT ON TABLE trenta TO user1;
GRANT SELECT ON TABLE trenta TO user3;


--
-- Name: v1; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE v1 FROM PUBLIC;
REVOKE ALL ON TABLE v1 FROM postgres;
GRANT ALL ON TABLE v1 TO postgres;
GRANT SELECT ON TABLE v1 TO student;
GRANT SELECT ON TABLE v1 TO user1;
GRANT SELECT ON TABLE v1 TO user3;


--
-- Name: view; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE view FROM PUBLIC;
REVOKE ALL ON TABLE view FROM postgres;
GRANT ALL ON TABLE view TO postgres;
GRANT SELECT ON TABLE view TO student;
GRANT SELECT ON TABLE view TO user1;
GRANT SELECT ON TABLE view TO user3;


--
-- Name: vowl; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE vowl FROM PUBLIC;
REVOKE ALL ON TABLE vowl FROM postgres;
GRANT ALL ON TABLE vowl TO postgres;
GRANT SELECT ON TABLE vowl TO student;
GRANT SELECT ON TABLE vowl TO user1;
GRANT SELECT ON TABLE vowl TO user3;


--
-- Name: zebras; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE zebras FROM PUBLIC;
REVOKE ALL ON TABLE zebras FROM postgres;
GRANT ALL ON TABLE zebras TO postgres;
GRANT SELECT ON TABLE zebras TO student;
GRANT SELECT ON TABLE zebras TO user1;
GRANT SELECT ON TABLE zebras TO user3;


--
-- Name: DEFAULT PRIVILEGES FOR TABLES; Type: DEFAULT ACL; Schema: public; Owner: postgres
--

ALTER DEFAULT PRIVILEGES FOR ROLE postgres IN SCHEMA public REVOKE ALL ON TABLES  FROM PUBLIC;
ALTER DEFAULT PRIVILEGES FOR ROLE postgres IN SCHEMA public REVOKE ALL ON TABLES  FROM postgres;
ALTER DEFAULT PRIVILEGES FOR ROLE postgres IN SCHEMA public GRANT SELECT ON TABLES  TO student;
ALTER DEFAULT PRIVILEGES FOR ROLE postgres IN SCHEMA public GRANT SELECT ON TABLES  TO user1;


--
-- PostgreSQL database dump complete
--

